(function(){"use strict";var Vn={exports:{}},Uu={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hc;function Ho(){if(hc)return Uu;hc=1;var A=Symbol.for("react.transitional.element"),Sl=Symbol.for("react.fragment");function B(h,tl,Tl){var rl=null;if(Tl!==void 0&&(rl=""+Tl),tl.key!==void 0&&(rl=""+tl.key),"key"in tl){Tl={};for(var Hl in tl)Hl!=="key"&&(Tl[Hl]=tl[Hl])}else Tl=tl;return tl=Tl.ref,{$$typeof:A,type:h,key:rl,ref:tl!==void 0?tl:null,props:Tl}}return Uu.Fragment=Sl,Uu.jsx=B,Uu.jsxs=B,Uu}var gc;function Ro(){return gc||(gc=1,Vn.exports=Ho()),Vn.exports}var x=Ro(),Ln={exports:{}},xu={},Kn={exports:{}},Jn={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Sc;function No(){return Sc||(Sc=1,(function(A){function Sl(S,p){var H=S.length;S.push(p);l:for(;0<H;){var ul=H-1>>>1,ol=S[ul];if(0<tl(ol,p))S[ul]=p,S[H]=ol,H=ul;else break l}}function B(S){return S.length===0?null:S[0]}function h(S){if(S.length===0)return null;var p=S[0],H=S.pop();if(H!==p){S[0]=H;l:for(var ul=0,ol=S.length,d=ol>>>1;ul<d;){var T=2*(ul+1)-1,_=S[T],D=T+1,X=S[D];if(0>tl(_,H))D<ol&&0>tl(X,_)?(S[ul]=X,S[D]=H,ul=D):(S[ul]=_,S[T]=H,ul=T);else if(D<ol&&0>tl(X,H))S[ul]=X,S[D]=H,ul=D;else break l}}return p}function tl(S,p){var H=S.sortIndex-p.sortIndex;return H!==0?H:S.id-p.id}if(A.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var Tl=performance;A.unstable_now=function(){return Tl.now()}}else{var rl=Date,Hl=rl.now();A.unstable_now=function(){return rl.now()-Hl}}var R=[],E=[],F=1,C=null,il=3,Ll=!1,Cl=!1,Rl=!1,gt=!1,Kl=typeof setTimeout=="function"?setTimeout:null,et=typeof clearTimeout=="function"?clearTimeout:null,vl=typeof setImmediate<"u"?setImmediate:null;function El(S){for(var p=B(E);p!==null;){if(p.callback===null)h(E);else if(p.startTime<=S)h(E),p.sortIndex=p.expirationTime,Sl(R,p);else break;p=B(E)}}function nt(S){if(Rl=!1,El(S),!Cl)if(B(R)!==null)Cl=!0,Jl||(Jl=!0,jl());else{var p=B(E);p!==null&&$(nt,p.startTime-S)}}var Jl=!1,V=-1,wl=5,kl=-1;function Pt(){return gt?!0:!(A.unstable_now()-kl<wl)}function al(){if(gt=!1,Jl){var S=A.unstable_now();kl=S;var p=!0;try{l:{Cl=!1,Rl&&(Rl=!1,et(V),V=-1),Ll=!0;var H=il;try{t:{for(El(S),C=B(R);C!==null&&!(C.expirationTime>S&&Pt());){var ul=C.callback;if(typeof ul=="function"){C.callback=null,il=C.priorityLevel;var ol=ul(C.expirationTime<=S);if(S=A.unstable_now(),typeof ol=="function"){C.callback=ol,El(S),p=!0;break t}C===B(R)&&h(R),El(S)}else h(R);C=B(R)}if(C!==null)p=!0;else{var d=B(E);d!==null&&$(nt,d.startTime-S),p=!1}}break l}finally{C=null,il=H,Ll=!1}p=void 0}}finally{p?jl():Jl=!1}}}var jl;if(typeof vl=="function")jl=function(){vl(al)};else if(typeof MessageChannel<"u"){var xt=new MessageChannel,O=xt.port2;xt.port1.onmessage=al,jl=function(){O.postMessage(null)}}else jl=function(){Kl(al,0)};function $(S,p){V=Kl(function(){S(A.unstable_now())},p)}A.unstable_IdlePriority=5,A.unstable_ImmediatePriority=1,A.unstable_LowPriority=4,A.unstable_NormalPriority=3,A.unstable_Profiling=null,A.unstable_UserBlockingPriority=2,A.unstable_cancelCallback=function(S){S.callback=null},A.unstable_forceFrameRate=function(S){0>S||125<S?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):wl=0<S?Math.floor(1e3/S):5},A.unstable_getCurrentPriorityLevel=function(){return il},A.unstable_next=function(S){switch(il){case 1:case 2:case 3:var p=3;break;default:p=il}var H=il;il=p;try{return S()}finally{il=H}},A.unstable_requestPaint=function(){gt=!0},A.unstable_runWithPriority=function(S,p){switch(S){case 1:case 2:case 3:case 4:case 5:break;default:S=3}var H=il;il=S;try{return p()}finally{il=H}},A.unstable_scheduleCallback=function(S,p,H){var ul=A.unstable_now();switch(typeof H=="object"&&H!==null?(H=H.delay,H=typeof H=="number"&&0<H?ul+H:ul):H=ul,S){case 1:var ol=-1;break;case 2:ol=250;break;case 5:ol=1073741823;break;case 4:ol=1e4;break;default:ol=5e3}return ol=H+ol,S={id:F++,callback:p,priorityLevel:S,startTime:H,expirationTime:ol,sortIndex:-1},H>ul?(S.sortIndex=H,Sl(E,S),B(R)===null&&S===B(E)&&(Rl?(et(V),V=-1):Rl=!0,$(nt,H-ul))):(S.sortIndex=ol,Sl(R,S),Cl||Ll||(Cl=!0,Jl||(Jl=!0,jl()))),S},A.unstable_shouldYield=Pt,A.unstable_wrapCallback=function(S){var p=il;return function(){var H=il;il=p;try{return S.apply(this,arguments)}finally{il=H}}}})(Jn)),Jn}var rc;function Bo(){return rc||(rc=1,Kn.exports=No()),Kn.exports}var wn={exports:{}},Y={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var bc;function Co(){if(bc)return Y;bc=1;var A=Symbol.for("react.transitional.element"),Sl=Symbol.for("react.portal"),B=Symbol.for("react.fragment"),h=Symbol.for("react.strict_mode"),tl=Symbol.for("react.profiler"),Tl=Symbol.for("react.consumer"),rl=Symbol.for("react.context"),Hl=Symbol.for("react.forward_ref"),R=Symbol.for("react.suspense"),E=Symbol.for("react.memo"),F=Symbol.for("react.lazy"),C=Symbol.for("react.activity"),il=Symbol.iterator;function Ll(d){return d===null||typeof d!="object"?null:(d=il&&d[il]||d["@@iterator"],typeof d=="function"?d:null)}var Cl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Rl=Object.assign,gt={};function Kl(d,T,_){this.props=d,this.context=T,this.refs=gt,this.updater=_||Cl}Kl.prototype.isReactComponent={},Kl.prototype.setState=function(d,T){if(typeof d!="object"&&typeof d!="function"&&d!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,d,T,"setState")},Kl.prototype.forceUpdate=function(d){this.updater.enqueueForceUpdate(this,d,"forceUpdate")};function et(){}et.prototype=Kl.prototype;function vl(d,T,_){this.props=d,this.context=T,this.refs=gt,this.updater=_||Cl}var El=vl.prototype=new et;El.constructor=vl,Rl(El,Kl.prototype),El.isPureReactComponent=!0;var nt=Array.isArray;function Jl(){}var V={H:null,A:null,T:null,S:null},wl=Object.prototype.hasOwnProperty;function kl(d,T,_){var D=_.ref;return{$$typeof:A,type:d,key:T,ref:D!==void 0?D:null,props:_}}function Pt(d,T){return kl(d.type,T,d.props)}function al(d){return typeof d=="object"&&d!==null&&d.$$typeof===A}function jl(d){var T={"=":"=0",":":"=2"};return"$"+d.replace(/[=:]/g,function(_){return T[_]})}var xt=/\/+/g;function O(d,T){return typeof d=="object"&&d!==null&&d.key!=null?jl(""+d.key):T.toString(36)}function $(d){switch(d.status){case"fulfilled":return d.value;case"rejected":throw d.reason;default:switch(typeof d.status=="string"?d.then(Jl,Jl):(d.status="pending",d.then(function(T){d.status==="pending"&&(d.status="fulfilled",d.value=T)},function(T){d.status==="pending"&&(d.status="rejected",d.reason=T)})),d.status){case"fulfilled":return d.value;case"rejected":throw d.reason}}throw d}function S(d,T,_,D,X){var L=typeof d;(L==="undefined"||L==="boolean")&&(d=null);var el=!1;if(d===null)el=!0;else switch(L){case"bigint":case"string":case"number":el=!0;break;case"object":switch(d.$$typeof){case A:case Sl:el=!0;break;case F:return el=d._init,S(el(d._payload),T,_,D,X)}}if(el)return X=X(d),el=D===""?"."+O(d,0):D,nt(X)?(_="",el!=null&&(_=el.replace(xt,"$&/")+"/"),S(X,T,_,"",function(Hu){return Hu})):X!=null&&(al(X)&&(X=Pt(X,_+(X.key==null||d&&d.key===X.key?"":(""+X.key).replace(xt,"$&/")+"/")+el)),T.push(X)),1;el=0;var Wl=D===""?".":D+":";if(nt(d))for(var Al=0;Al<d.length;Al++)D=d[Al],L=Wl+O(D,Al),el+=S(D,T,_,L,X);else if(Al=Ll(d),typeof Al=="function")for(d=Al.call(d),Al=0;!(D=d.next()).done;)D=D.value,L=Wl+O(D,Al++),el+=S(D,T,_,L,X);else if(L==="object"){if(typeof d.then=="function")return S($(d),T,_,D,X);throw T=String(d),Error("Objects are not valid as a React child (found: "+(T==="[object Object]"?"object with keys {"+Object.keys(d).join(", ")+"}":T)+"). If you meant to render a collection of children, use an array instead.")}return el}function p(d,T,_){if(d==null)return d;var D=[],X=0;return S(d,D,"","",function(L){return T.call(_,L,X++)}),D}function H(d){if(d._status===-1){var T=d._result;T=T(),T.then(function(_){(d._status===0||d._status===-1)&&(d._status=1,d._result=_)},function(_){(d._status===0||d._status===-1)&&(d._status=2,d._result=_)}),d._status===-1&&(d._status=0,d._result=T)}if(d._status===1)return d._result.default;throw d._result}var ul=typeof reportError=="function"?reportError:function(d){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var T=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof d=="object"&&d!==null&&typeof d.message=="string"?String(d.message):String(d),error:d});if(!window.dispatchEvent(T))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",d);return}console.error(d)},ol={map:p,forEach:function(d,T,_){p(d,function(){T.apply(this,arguments)},_)},count:function(d){var T=0;return p(d,function(){T++}),T},toArray:function(d){return p(d,function(T){return T})||[]},only:function(d){if(!al(d))throw Error("React.Children.only expected to receive a single React element child.");return d}};return Y.Activity=C,Y.Children=ol,Y.Component=Kl,Y.Fragment=B,Y.Profiler=tl,Y.PureComponent=vl,Y.StrictMode=h,Y.Suspense=R,Y.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=V,Y.__COMPILER_RUNTIME={__proto__:null,c:function(d){return V.H.useMemoCache(d)}},Y.cache=function(d){return function(){return d.apply(null,arguments)}},Y.cacheSignal=function(){return null},Y.cloneElement=function(d,T,_){if(d==null)throw Error("The argument must be a React element, but you passed "+d+".");var D=Rl({},d.props),X=d.key;if(T!=null)for(L in T.key!==void 0&&(X=""+T.key),T)!wl.call(T,L)||L==="key"||L==="__self"||L==="__source"||L==="ref"&&T.ref===void 0||(D[L]=T[L]);var L=arguments.length-2;if(L===1)D.children=_;else if(1<L){for(var el=Array(L),Wl=0;Wl<L;Wl++)el[Wl]=arguments[Wl+2];D.children=el}return kl(d.type,X,D)},Y.createContext=function(d){return d={$$typeof:rl,_currentValue:d,_currentValue2:d,_threadCount:0,Provider:null,Consumer:null},d.Provider=d,d.Consumer={$$typeof:Tl,_context:d},d},Y.createElement=function(d,T,_){var D,X={},L=null;if(T!=null)for(D in T.key!==void 0&&(L=""+T.key),T)wl.call(T,D)&&D!=="key"&&D!=="__self"&&D!=="__source"&&(X[D]=T[D]);var el=arguments.length-2;if(el===1)X.children=_;else if(1<el){for(var Wl=Array(el),Al=0;Al<el;Al++)Wl[Al]=arguments[Al+2];X.children=Wl}if(d&&d.defaultProps)for(D in el=d.defaultProps,el)X[D]===void 0&&(X[D]=el[D]);return kl(d,L,X)},Y.createRef=function(){return{current:null}},Y.forwardRef=function(d){return{$$typeof:Hl,render:d}},Y.isValidElement=al,Y.lazy=function(d){return{$$typeof:F,_payload:{_status:-1,_result:d},_init:H}},Y.memo=function(d,T){return{$$typeof:E,type:d,compare:T===void 0?null:T}},Y.startTransition=function(d){var T=V.T,_={};V.T=_;try{var D=d(),X=V.S;X!==null&&X(_,D),typeof D=="object"&&D!==null&&typeof D.then=="function"&&D.then(Jl,ul)}catch(L){ul(L)}finally{T!==null&&_.types!==null&&(T.types=_.types),V.T=T}},Y.unstable_useCacheRefresh=function(){return V.H.useCacheRefresh()},Y.use=function(d){return V.H.use(d)},Y.useActionState=function(d,T,_){return V.H.useActionState(d,T,_)},Y.useCallback=function(d,T){return V.H.useCallback(d,T)},Y.useContext=function(d){return V.H.useContext(d)},Y.useDebugValue=function(){},Y.useDeferredValue=function(d,T){return V.H.useDeferredValue(d,T)},Y.useEffect=function(d,T){return V.H.useEffect(d,T)},Y.useEffectEvent=function(d){return V.H.useEffectEvent(d)},Y.useId=function(){return V.H.useId()},Y.useImperativeHandle=function(d,T,_){return V.H.useImperativeHandle(d,T,_)},Y.useInsertionEffect=function(d,T){return V.H.useInsertionEffect(d,T)},Y.useLayoutEffect=function(d,T){return V.H.useLayoutEffect(d,T)},Y.useMemo=function(d,T){return V.H.useMemo(d,T)},Y.useOptimistic=function(d,T){return V.H.useOptimistic(d,T)},Y.useReducer=function(d,T,_){return V.H.useReducer(d,T,_)},Y.useRef=function(d){return V.H.useRef(d)},Y.useState=function(d){return V.H.useState(d)},Y.useSyncExternalStore=function(d,T,_){return V.H.useSyncExternalStore(d,T,_)},Y.useTransition=function(){return V.H.useTransition()},Y.version="19.2.4",Y}var zc;function Wn(){return zc||(zc=1,wn.exports=Co()),wn.exports}var $n={exports:{}},Zl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tc;function jo(){if(Tc)return Zl;Tc=1;var A=Wn();function Sl(R){var E="https://react.dev/errors/"+R;if(1<arguments.length){E+="?args[]="+encodeURIComponent(arguments[1]);for(var F=2;F<arguments.length;F++)E+="&args[]="+encodeURIComponent(arguments[F])}return"Minified React error #"+R+"; visit "+E+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function B(){}var h={d:{f:B,r:function(){throw Error(Sl(522))},D:B,C:B,L:B,m:B,X:B,S:B,M:B},p:0,findDOMNode:null},tl=Symbol.for("react.portal");function Tl(R,E,F){var C=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:tl,key:C==null?null:""+C,children:R,containerInfo:E,implementation:F}}var rl=A.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function Hl(R,E){if(R==="font")return"";if(typeof E=="string")return E==="use-credentials"?E:""}return Zl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=h,Zl.createPortal=function(R,E){var F=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!E||E.nodeType!==1&&E.nodeType!==9&&E.nodeType!==11)throw Error(Sl(299));return Tl(R,E,null,F)},Zl.flushSync=function(R){var E=rl.T,F=h.p;try{if(rl.T=null,h.p=2,R)return R()}finally{rl.T=E,h.p=F,h.d.f()}},Zl.preconnect=function(R,E){typeof R=="string"&&(E?(E=E.crossOrigin,E=typeof E=="string"?E==="use-credentials"?E:"":void 0):E=null,h.d.C(R,E))},Zl.prefetchDNS=function(R){typeof R=="string"&&h.d.D(R)},Zl.preinit=function(R,E){if(typeof R=="string"&&E&&typeof E.as=="string"){var F=E.as,C=Hl(F,E.crossOrigin),il=typeof E.integrity=="string"?E.integrity:void 0,Ll=typeof E.fetchPriority=="string"?E.fetchPriority:void 0;F==="style"?h.d.S(R,typeof E.precedence=="string"?E.precedence:void 0,{crossOrigin:C,integrity:il,fetchPriority:Ll}):F==="script"&&h.d.X(R,{crossOrigin:C,integrity:il,fetchPriority:Ll,nonce:typeof E.nonce=="string"?E.nonce:void 0})}},Zl.preinitModule=function(R,E){if(typeof R=="string")if(typeof E=="object"&&E!==null){if(E.as==null||E.as==="script"){var F=Hl(E.as,E.crossOrigin);h.d.M(R,{crossOrigin:F,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0})}}else E==null&&h.d.M(R)},Zl.preload=function(R,E){if(typeof R=="string"&&typeof E=="object"&&E!==null&&typeof E.as=="string"){var F=E.as,C=Hl(F,E.crossOrigin);h.d.L(R,F,{crossOrigin:C,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0,type:typeof E.type=="string"?E.type:void 0,fetchPriority:typeof E.fetchPriority=="string"?E.fetchPriority:void 0,referrerPolicy:typeof E.referrerPolicy=="string"?E.referrerPolicy:void 0,imageSrcSet:typeof E.imageSrcSet=="string"?E.imageSrcSet:void 0,imageSizes:typeof E.imageSizes=="string"?E.imageSizes:void 0,media:typeof E.media=="string"?E.media:void 0})}},Zl.preloadModule=function(R,E){if(typeof R=="string")if(E){var F=Hl(E.as,E.crossOrigin);h.d.m(R,{as:typeof E.as=="string"&&E.as!=="script"?E.as:void 0,crossOrigin:F,integrity:typeof E.integrity=="string"?E.integrity:void 0})}else h.d.m(R)},Zl.requestFormReset=function(R){h.d.r(R)},Zl.unstable_batchedUpdates=function(R,E){return R(E)},Zl.useFormState=function(R,E,F){return rl.H.useFormState(R,E,F)},Zl.useFormStatus=function(){return rl.H.useHostTransitionStatus()},Zl.version="19.2.4",Zl}var Ec;function qo(){if(Ec)return $n.exports;Ec=1;function A(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(A)}catch(Sl){console.error(Sl)}}return A(),$n.exports=jo(),$n.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Ac;function Yo(){if(Ac)return xu;Ac=1;var A=Bo(),Sl=Wn(),B=qo();function h(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var a=2;a<arguments.length;a++)t+="&args[]="+encodeURIComponent(arguments[a])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function tl(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function Tl(l){var t=l,a=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(a=t.return),l=t.return;while(l)}return t.tag===3?a:null}function rl(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function Hl(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function R(l){if(Tl(l)!==l)throw Error(h(188))}function E(l){var t=l.alternate;if(!t){if(t=Tl(l),t===null)throw Error(h(188));return t!==l?null:l}for(var a=l,u=t;;){var e=a.return;if(e===null)break;var n=e.alternate;if(n===null){if(u=e.return,u!==null){a=u;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===a)return R(e),l;if(n===u)return R(e),t;n=n.sibling}throw Error(h(188))}if(a.return!==u.return)a=e,u=n;else{for(var f=!1,i=e.child;i;){if(i===a){f=!0,a=e,u=n;break}if(i===u){f=!0,u=e,a=n;break}i=i.sibling}if(!f){for(i=n.child;i;){if(i===a){f=!0,a=n,u=e;break}if(i===u){f=!0,u=n,a=e;break}i=i.sibling}if(!f)throw Error(h(189))}}if(a.alternate!==u)throw Error(h(190))}if(a.tag!==3)throw Error(h(188));return a.stateNode.current===a?l:t}function F(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=F(l),t!==null)return t;l=l.sibling}return null}var C=Object.assign,il=Symbol.for("react.element"),Ll=Symbol.for("react.transitional.element"),Cl=Symbol.for("react.portal"),Rl=Symbol.for("react.fragment"),gt=Symbol.for("react.strict_mode"),Kl=Symbol.for("react.profiler"),et=Symbol.for("react.consumer"),vl=Symbol.for("react.context"),El=Symbol.for("react.forward_ref"),nt=Symbol.for("react.suspense"),Jl=Symbol.for("react.suspense_list"),V=Symbol.for("react.memo"),wl=Symbol.for("react.lazy"),kl=Symbol.for("react.activity"),Pt=Symbol.for("react.memo_cache_sentinel"),al=Symbol.iterator;function jl(l){return l===null||typeof l!="object"?null:(l=al&&l[al]||l["@@iterator"],typeof l=="function"?l:null)}var xt=Symbol.for("react.client.reference");function O(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===xt?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Rl:return"Fragment";case Kl:return"Profiler";case gt:return"StrictMode";case nt:return"Suspense";case Jl:return"SuspenseList";case kl:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case Cl:return"Portal";case vl:return l.displayName||"Context";case et:return(l._context.displayName||"Context")+".Consumer";case El:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case V:return t=l.displayName||null,t!==null?t:O(l.type)||"Memo";case wl:t=l._payload,l=l._init;try{return O(l(t))}catch{}}return null}var $=Array.isArray,S=Sl.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,p=B.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,H={pending:!1,data:null,method:null,action:null},ul=[],ol=-1;function d(l){return{current:l}}function T(l){0>ol||(l.current=ul[ol],ul[ol]=null,ol--)}function _(l,t){ol++,ul[ol]=l.current,l.current=t}var D=d(null),X=d(null),L=d(null),el=d(null);function Wl(l,t){switch(_(L,t),_(X,l),_(D,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?P0(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=P0(t),l=lo(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}T(D),_(D,l)}function Al(){T(D),T(X),T(L)}function Hu(l){l.memoizedState!==null&&_(el,l);var t=D.current,a=lo(t,l.type);t!==a&&(_(X,l),_(D,a))}function pe(l){X.current===l&&(T(D),T(X)),el.current===l&&(T(el),ze._currentValue=H)}var kn,Uc;function _a(l){if(kn===void 0)try{throw Error()}catch(a){var t=a.stack.trim().match(/\n( *(at )?)/);kn=t&&t[1]||"",Uc=-1<a.stack.indexOf(`
    at`)?" (<anonymous>)":-1<a.stack.indexOf("@")?"@unknown:0:0":""}return`
`+kn+l+Uc}var Fn=!1;function In(l,t){if(!l||Fn)return"";Fn=!0;var a=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var u={DetermineComponentFrameRoot:function(){try{if(t){var z=function(){throw Error()};if(Object.defineProperty(z.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(z,[])}catch(g){var m=g}Reflect.construct(l,[],z)}else{try{z.call()}catch(g){m=g}l.call(z.prototype)}}else{try{throw Error()}catch(g){m=g}(z=l())&&typeof z.catch=="function"&&z.catch(function(){})}}catch(g){if(g&&m&&typeof g.stack=="string")return[g.stack,m.stack]}return[null,null]}};u.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(u.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(u.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=u.DetermineComponentFrameRoot(),f=n[0],i=n[1];if(f&&i){var c=f.split(`
`),v=i.split(`
`);for(e=u=0;u<c.length&&!c[u].includes("DetermineComponentFrameRoot");)u++;for(;e<v.length&&!v[e].includes("DetermineComponentFrameRoot");)e++;if(u===c.length||e===v.length)for(u=c.length-1,e=v.length-1;1<=u&&0<=e&&c[u]!==v[e];)e--;for(;1<=u&&0<=e;u--,e--)if(c[u]!==v[e]){if(u!==1||e!==1)do if(u--,e--,0>e||c[u]!==v[e]){var r=`
`+c[u].replace(" at new "," at ");return l.displayName&&r.includes("<anonymous>")&&(r=r.replace("<anonymous>",l.displayName)),r}while(1<=u&&0<=e);break}}}finally{Fn=!1,Error.prepareStackTrace=a}return(a=l?l.displayName||l.name:"")?_a(a):""}function Ko(l,t){switch(l.tag){case 26:case 27:case 5:return _a(l.type);case 16:return _a("Lazy");case 13:return l.child!==t&&t!==null?_a("Suspense Fallback"):_a("Suspense");case 19:return _a("SuspenseList");case 0:case 15:return In(l.type,!1);case 11:return In(l.type.render,!1);case 1:return In(l.type,!0);case 31:return _a("Activity");default:return""}}function xc(l){try{var t="",a=null;do t+=Ko(l,a),a=l,l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}var Pn=Object.prototype.hasOwnProperty,lf=A.unstable_scheduleCallback,tf=A.unstable_cancelCallback,Jo=A.unstable_shouldYield,wo=A.unstable_requestPaint,ft=A.unstable_now,Wo=A.unstable_getCurrentPriorityLevel,Hc=A.unstable_ImmediatePriority,Rc=A.unstable_UserBlockingPriority,_e=A.unstable_NormalPriority,$o=A.unstable_LowPriority,Nc=A.unstable_IdlePriority,ko=A.log,Fo=A.unstable_setDisableYieldValue,Ru=null,it=null;function la(l){if(typeof ko=="function"&&Fo(l),it&&typeof it.setStrictMode=="function")try{it.setStrictMode(Ru,l)}catch{}}var ct=Math.clz32?Math.clz32:ly,Io=Math.log,Po=Math.LN2;function ly(l){return l>>>=0,l===0?32:31-(Io(l)/Po|0)|0}var Oe=256,Me=262144,De=4194304;function Oa(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Ue(l,t,a){var u=l.pendingLanes;if(u===0)return 0;var e=0,n=l.suspendedLanes,f=l.pingedLanes;l=l.warmLanes;var i=u&134217727;return i!==0?(u=i&~n,u!==0?e=Oa(u):(f&=i,f!==0?e=Oa(f):a||(a=i&~l,a!==0&&(e=Oa(a))))):(i=u&~n,i!==0?e=Oa(i):f!==0?e=Oa(f):a||(a=u&~l,a!==0&&(e=Oa(a)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,a=t&-t,n>=a||n===32&&(a&4194048)!==0)?t:e}function Nu(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function ty(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Bc(){var l=De;return De<<=1,(De&62914560)===0&&(De=4194304),l}function af(l){for(var t=[],a=0;31>a;a++)t.push(l);return t}function Bu(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function ay(l,t,a,u,e,n){var f=l.pendingLanes;l.pendingLanes=a,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=a,l.entangledLanes&=a,l.errorRecoveryDisabledLanes&=a,l.shellSuspendCounter=0;var i=l.entanglements,c=l.expirationTimes,v=l.hiddenUpdates;for(a=f&~a;0<a;){var r=31-ct(a),z=1<<r;i[r]=0,c[r]=-1;var m=v[r];if(m!==null)for(v[r]=null,r=0;r<m.length;r++){var g=m[r];g!==null&&(g.lane&=-536870913)}a&=~z}u!==0&&Cc(l,u,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(f&~t))}function Cc(l,t,a){l.pendingLanes|=t,l.suspendedLanes&=~t;var u=31-ct(t);l.entangledLanes|=t,l.entanglements[u]=l.entanglements[u]|1073741824|a&261930}function jc(l,t){var a=l.entangledLanes|=t;for(l=l.entanglements;a;){var u=31-ct(a),e=1<<u;e&t|l[u]&t&&(l[u]|=t),a&=~e}}function qc(l,t){var a=t&-t;return a=(a&42)!==0?1:uf(a),(a&(l.suspendedLanes|t))!==0?0:a}function uf(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function ef(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Yc(){var l=p.p;return l!==0?l:(l=window.event,l===void 0?32:po(l.type))}function Gc(l,t){var a=p.p;try{return p.p=l,t()}finally{p.p=a}}var ta=Math.random().toString(36).slice(2),ql="__reactFiber$"+ta,Fl="__reactProps$"+ta,Ka="__reactContainer$"+ta,nf="__reactEvents$"+ta,uy="__reactListeners$"+ta,ey="__reactHandles$"+ta,Xc="__reactResources$"+ta,Cu="__reactMarker$"+ta;function ff(l){delete l[ql],delete l[Fl],delete l[nf],delete l[uy],delete l[ey]}function Ja(l){var t=l[ql];if(t)return t;for(var a=l.parentNode;a;){if(t=a[Ka]||a[ql]){if(a=t.alternate,t.child!==null||a!==null&&a.child!==null)for(l=io(l);l!==null;){if(a=l[ql])return a;l=io(l)}return t}l=a,a=l.parentNode}return null}function wa(l){if(l=l[ql]||l[Ka]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function ju(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(h(33))}function Wa(l){var t=l[Xc];return t||(t=l[Xc]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Nl(l){l[Cu]=!0}var Qc=new Set,Zc={};function Ma(l,t){$a(l,t),$a(l+"Capture",t)}function $a(l,t){for(Zc[l]=t,l=0;l<t.length;l++)Qc.add(t[l])}var ny=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Vc={},Lc={};function fy(l){return Pn.call(Lc,l)?!0:Pn.call(Vc,l)?!1:ny.test(l)?Lc[l]=!0:(Vc[l]=!0,!1)}function xe(l,t,a){if(fy(t))if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var u=t.toLowerCase().slice(0,5);if(u!=="data-"&&u!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+a)}}function He(l,t,a){if(a===null)l.removeAttribute(t);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+a)}}function Ct(l,t,a,u){if(u===null)l.removeAttribute(a);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(a);return}l.setAttributeNS(t,a,""+u)}}function St(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Kc(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function iy(l,t,a){var u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(f){a=""+f,n.call(this,f)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(f){a=""+f},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function cf(l){if(!l._valueTracker){var t=Kc(l)?"checked":"value";l._valueTracker=iy(l,t,""+l[t])}}function Jc(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var a=t.getValue(),u="";return l&&(u=Kc(l)?l.checked?"true":"false":l.value),l=u,l!==a?(t.setValue(l),!0):!1}function Re(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var cy=/[\n"\\]/g;function rt(l){return l.replace(cy,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function sf(l,t,a,u,e,n,f,i){l.name="",f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.type=f:l.removeAttribute("type"),t!=null?f==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+St(t)):l.value!==""+St(t)&&(l.value=""+St(t)):f!=="submit"&&f!=="reset"||l.removeAttribute("value"),t!=null?df(l,f,St(t)):a!=null?df(l,f,St(a)):u!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),i!=null&&typeof i!="function"&&typeof i!="symbol"&&typeof i!="boolean"?l.name=""+St(i):l.removeAttribute("name")}function wc(l,t,a,u,e,n,f,i){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||a!=null){if(!(n!=="submit"&&n!=="reset"||t!=null)){cf(l);return}a=a!=null?""+St(a):"",t=t!=null?""+St(t):a,i||t===l.value||(l.value=t),l.defaultValue=t}u=u??e,u=typeof u!="function"&&typeof u!="symbol"&&!!u,l.checked=i?l.checked:!!u,l.defaultChecked=!!u,f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(l.name=f),cf(l)}function df(l,t,a){t==="number"&&Re(l.ownerDocument)===l||l.defaultValue===""+a||(l.defaultValue=""+a)}function ka(l,t,a,u){if(l=l.options,t){t={};for(var e=0;e<a.length;e++)t["$"+a[e]]=!0;for(a=0;a<l.length;a++)e=t.hasOwnProperty("$"+l[a].value),l[a].selected!==e&&(l[a].selected=e),e&&u&&(l[a].defaultSelected=!0)}else{for(a=""+St(a),t=null,e=0;e<l.length;e++){if(l[e].value===a){l[e].selected=!0,u&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Wc(l,t,a){if(t!=null&&(t=""+St(t),t!==l.value&&(l.value=t),a==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=a!=null?""+St(a):""}function $c(l,t,a,u){if(t==null){if(u!=null){if(a!=null)throw Error(h(92));if($(u)){if(1<u.length)throw Error(h(93));u=u[0]}a=u}a==null&&(a=""),t=a}a=St(t),l.defaultValue=a,u=l.textContent,u===a&&u!==""&&u!==null&&(l.value=u),cf(l)}function Fa(l,t){if(t){var a=l.firstChild;if(a&&a===l.lastChild&&a.nodeType===3){a.nodeValue=t;return}}l.textContent=t}var sy=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function kc(l,t,a){var u=t.indexOf("--")===0;a==null||typeof a=="boolean"||a===""?u?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":u?l.setProperty(t,a):typeof a!="number"||a===0||sy.has(t)?t==="float"?l.cssFloat=a:l[t]=(""+a).trim():l[t]=a+"px"}function Fc(l,t,a){if(t!=null&&typeof t!="object")throw Error(h(62));if(l=l.style,a!=null){for(var u in a)!a.hasOwnProperty(u)||t!=null&&t.hasOwnProperty(u)||(u.indexOf("--")===0?l.setProperty(u,""):u==="float"?l.cssFloat="":l[u]="");for(var e in t)u=t[e],t.hasOwnProperty(e)&&a[e]!==u&&kc(l,e,u)}else for(var n in t)t.hasOwnProperty(n)&&kc(l,n,t[n])}function of(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var dy=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),oy=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ne(l){return oy.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function jt(){}var yf=null;function vf(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Ia=null,Pa=null;function Ic(l){var t=wa(l);if(t&&(l=t.stateNode)){var a=l[Fl]||null;l:switch(l=t.stateNode,t.type){case"input":if(sf(l,a.value,a.defaultValue,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name),t=a.name,a.type==="radio"&&t!=null){for(a=l;a.parentNode;)a=a.parentNode;for(a=a.querySelectorAll('input[name="'+rt(""+t)+'"][type="radio"]'),t=0;t<a.length;t++){var u=a[t];if(u!==l&&u.form===l.form){var e=u[Fl]||null;if(!e)throw Error(h(90));sf(u,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<a.length;t++)u=a[t],u.form===l.form&&Jc(u)}break l;case"textarea":Wc(l,a.value,a.defaultValue);break l;case"select":t=a.value,t!=null&&ka(l,!!a.multiple,t,!1)}}}var mf=!1;function Pc(l,t,a){if(mf)return l(t,a);mf=!0;try{var u=l(t);return u}finally{if(mf=!1,(Ia!==null||Pa!==null)&&(Tn(),Ia&&(t=Ia,l=Pa,Pa=Ia=null,Ic(t),l)))for(t=0;t<l.length;t++)Ic(l[t])}}function qu(l,t){var a=l.stateNode;if(a===null)return null;var u=a[Fl]||null;if(u===null)return null;a=u[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(u=!u.disabled)||(l=l.type,u=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!u;break l;default:l=!1}if(l)return null;if(a&&typeof a!="function")throw Error(h(231,t,typeof a));return a}var qt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),hf=!1;if(qt)try{var Yu={};Object.defineProperty(Yu,"passive",{get:function(){hf=!0}}),window.addEventListener("test",Yu,Yu),window.removeEventListener("test",Yu,Yu)}catch{hf=!1}var aa=null,gf=null,Be=null;function ls(){if(Be)return Be;var l,t=gf,a=t.length,u,e="value"in aa?aa.value:aa.textContent,n=e.length;for(l=0;l<a&&t[l]===e[l];l++);var f=a-l;for(u=1;u<=f&&t[a-u]===e[n-u];u++);return Be=e.slice(l,1<u?1-u:void 0)}function Ce(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function je(){return!0}function ts(){return!1}function Il(l){function t(a,u,e,n,f){this._reactName=a,this._targetInst=e,this.type=u,this.nativeEvent=n,this.target=f,this.currentTarget=null;for(var i in l)l.hasOwnProperty(i)&&(a=l[i],this[i]=a?a(n):n[i]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?je:ts,this.isPropagationStopped=ts,this}return C(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():typeof a.returnValue!="unknown"&&(a.returnValue=!1),this.isDefaultPrevented=je)},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():typeof a.cancelBubble!="unknown"&&(a.cancelBubble=!0),this.isPropagationStopped=je)},persist:function(){},isPersistent:je}),t}var Da={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},qe=Il(Da),Gu=C({},Da,{view:0,detail:0}),yy=Il(Gu),Sf,rf,Xu,Ye=C({},Gu,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:zf,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Xu&&(Xu&&l.type==="mousemove"?(Sf=l.screenX-Xu.screenX,rf=l.screenY-Xu.screenY):rf=Sf=0,Xu=l),Sf)},movementY:function(l){return"movementY"in l?l.movementY:rf}}),as=Il(Ye),vy=C({},Ye,{dataTransfer:0}),my=Il(vy),hy=C({},Gu,{relatedTarget:0}),bf=Il(hy),gy=C({},Da,{animationName:0,elapsedTime:0,pseudoElement:0}),Sy=Il(gy),ry=C({},Da,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),by=Il(ry),zy=C({},Da,{data:0}),us=Il(zy),Ty={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Ey={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Ay={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function py(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=Ay[l])?!!t[l]:!1}function zf(){return py}var _y=C({},Gu,{key:function(l){if(l.key){var t=Ty[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Ce(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Ey[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:zf,charCode:function(l){return l.type==="keypress"?Ce(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Ce(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Oy=Il(_y),My=C({},Ye,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),es=Il(My),Dy=C({},Gu,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:zf}),Uy=Il(Dy),xy=C({},Da,{propertyName:0,elapsedTime:0,pseudoElement:0}),Hy=Il(xy),Ry=C({},Ye,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Ny=Il(Ry),By=C({},Da,{newState:0,oldState:0}),Cy=Il(By),jy=[9,13,27,32],Tf=qt&&"CompositionEvent"in window,Qu=null;qt&&"documentMode"in document&&(Qu=document.documentMode);var qy=qt&&"TextEvent"in window&&!Qu,ns=qt&&(!Tf||Qu&&8<Qu&&11>=Qu),fs=" ",is=!1;function cs(l,t){switch(l){case"keyup":return jy.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ss(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var lu=!1;function Yy(l,t){switch(l){case"compositionend":return ss(t);case"keypress":return t.which!==32?null:(is=!0,fs);case"textInput":return l=t.data,l===fs&&is?null:l;default:return null}}function Gy(l,t){if(lu)return l==="compositionend"||!Tf&&cs(l,t)?(l=ls(),Be=gf=aa=null,lu=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return ns&&t.locale!=="ko"?null:t.data;default:return null}}var Xy={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function ds(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!Xy[l.type]:t==="textarea"}function os(l,t,a,u){Ia?Pa?Pa.push(u):Pa=[u]:Ia=u,t=Dn(t,"onChange"),0<t.length&&(a=new qe("onChange","change",null,a,u),l.push({event:a,listeners:t}))}var Zu=null,Vu=null;function Qy(l){w0(l,0)}function Ge(l){var t=ju(l);if(Jc(t))return l}function ys(l,t){if(l==="change")return t}var vs=!1;if(qt){var Ef;if(qt){var Af="oninput"in document;if(!Af){var ms=document.createElement("div");ms.setAttribute("oninput","return;"),Af=typeof ms.oninput=="function"}Ef=Af}else Ef=!1;vs=Ef&&(!document.documentMode||9<document.documentMode)}function hs(){Zu&&(Zu.detachEvent("onpropertychange",gs),Vu=Zu=null)}function gs(l){if(l.propertyName==="value"&&Ge(Vu)){var t=[];os(t,Vu,l,vf(l)),Pc(Qy,t)}}function Zy(l,t,a){l==="focusin"?(hs(),Zu=t,Vu=a,Zu.attachEvent("onpropertychange",gs)):l==="focusout"&&hs()}function Vy(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ge(Vu)}function Ly(l,t){if(l==="click")return Ge(t)}function Ky(l,t){if(l==="input"||l==="change")return Ge(t)}function Jy(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var st=typeof Object.is=="function"?Object.is:Jy;function Lu(l,t){if(st(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var a=Object.keys(l),u=Object.keys(t);if(a.length!==u.length)return!1;for(u=0;u<a.length;u++){var e=a[u];if(!Pn.call(t,e)||!st(l[e],t[e]))return!1}return!0}function Ss(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function rs(l,t){var a=Ss(l);l=0;for(var u;a;){if(a.nodeType===3){if(u=l+a.textContent.length,l<=t&&u>=t)return{node:a,offset:t-l};l=u}l:{for(;a;){if(a.nextSibling){a=a.nextSibling;break l}a=a.parentNode}a=void 0}a=Ss(a)}}function bs(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?bs(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function zs(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Re(l.document);t instanceof l.HTMLIFrameElement;){try{var a=typeof t.contentWindow.location.href=="string"}catch{a=!1}if(a)l=t.contentWindow;else break;t=Re(l.document)}return t}function pf(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var wy=qt&&"documentMode"in document&&11>=document.documentMode,tu=null,_f=null,Ku=null,Of=!1;function Ts(l,t,a){var u=a.window===a?a.document:a.nodeType===9?a:a.ownerDocument;Of||tu==null||tu!==Re(u)||(u=tu,"selectionStart"in u&&pf(u)?u={start:u.selectionStart,end:u.selectionEnd}:(u=(u.ownerDocument&&u.ownerDocument.defaultView||window).getSelection(),u={anchorNode:u.anchorNode,anchorOffset:u.anchorOffset,focusNode:u.focusNode,focusOffset:u.focusOffset}),Ku&&Lu(Ku,u)||(Ku=u,u=Dn(_f,"onSelect"),0<u.length&&(t=new qe("onSelect","select",null,t,a),l.push({event:t,listeners:u}),t.target=tu)))}function Ua(l,t){var a={};return a[l.toLowerCase()]=t.toLowerCase(),a["Webkit"+l]="webkit"+t,a["Moz"+l]="moz"+t,a}var au={animationend:Ua("Animation","AnimationEnd"),animationiteration:Ua("Animation","AnimationIteration"),animationstart:Ua("Animation","AnimationStart"),transitionrun:Ua("Transition","TransitionRun"),transitionstart:Ua("Transition","TransitionStart"),transitioncancel:Ua("Transition","TransitionCancel"),transitionend:Ua("Transition","TransitionEnd")},Mf={},Es={};qt&&(Es=document.createElement("div").style,"AnimationEvent"in window||(delete au.animationend.animation,delete au.animationiteration.animation,delete au.animationstart.animation),"TransitionEvent"in window||delete au.transitionend.transition);function xa(l){if(Mf[l])return Mf[l];if(!au[l])return l;var t=au[l],a;for(a in t)if(t.hasOwnProperty(a)&&a in Es)return Mf[l]=t[a];return l}var As=xa("animationend"),ps=xa("animationiteration"),_s=xa("animationstart"),Wy=xa("transitionrun"),$y=xa("transitionstart"),ky=xa("transitioncancel"),Os=xa("transitionend"),Ms=new Map,Df="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Df.push("scrollEnd");function Mt(l,t){Ms.set(l,t),Ma(t,[l])}var Xe=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},bt=[],uu=0,Uf=0;function Qe(){for(var l=uu,t=Uf=uu=0;t<l;){var a=bt[t];bt[t++]=null;var u=bt[t];bt[t++]=null;var e=bt[t];bt[t++]=null;var n=bt[t];if(bt[t++]=null,u!==null&&e!==null){var f=u.pending;f===null?e.next=e:(e.next=f.next,f.next=e),u.pending=e}n!==0&&Ds(a,e,n)}}function Ze(l,t,a,u){bt[uu++]=l,bt[uu++]=t,bt[uu++]=a,bt[uu++]=u,Uf|=u,l.lanes|=u,l=l.alternate,l!==null&&(l.lanes|=u)}function xf(l,t,a,u){return Ze(l,t,a,u),Ve(l)}function Ha(l,t){return Ze(l,null,null,t),Ve(l)}function Ds(l,t,a){l.lanes|=a;var u=l.alternate;u!==null&&(u.lanes|=a);for(var e=!1,n=l.return;n!==null;)n.childLanes|=a,u=n.alternate,u!==null&&(u.childLanes|=a),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-ct(a),l=n.hiddenUpdates,u=l[e],u===null?l[e]=[t]:u.push(t),t.lane=a|536870912),n):null}function Ve(l){if(50<ve)throw ve=0,Gi=null,Error(h(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var eu={};function Fy(l,t,a,u){this.tag=l,this.key=a,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=u,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function dt(l,t,a,u){return new Fy(l,t,a,u)}function Hf(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Yt(l,t){var a=l.alternate;return a===null?(a=dt(l.tag,t,l.key,l.mode),a.elementType=l.elementType,a.type=l.type,a.stateNode=l.stateNode,a.alternate=l,l.alternate=a):(a.pendingProps=t,a.type=l.type,a.flags=0,a.subtreeFlags=0,a.deletions=null),a.flags=l.flags&65011712,a.childLanes=l.childLanes,a.lanes=l.lanes,a.child=l.child,a.memoizedProps=l.memoizedProps,a.memoizedState=l.memoizedState,a.updateQueue=l.updateQueue,t=l.dependencies,a.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},a.sibling=l.sibling,a.index=l.index,a.ref=l.ref,a.refCleanup=l.refCleanup,a}function Us(l,t){l.flags&=65011714;var a=l.alternate;return a===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=a.childLanes,l.lanes=a.lanes,l.child=a.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=a.memoizedProps,l.memoizedState=a.memoizedState,l.updateQueue=a.updateQueue,l.type=a.type,t=a.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Le(l,t,a,u,e,n){var f=0;if(u=l,typeof l=="function")Hf(l)&&(f=1);else if(typeof l=="string")f=am(l,a,D.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case kl:return l=dt(31,a,t,e),l.elementType=kl,l.lanes=n,l;case Rl:return Ra(a.children,e,n,t);case gt:f=8,e|=24;break;case Kl:return l=dt(12,a,t,e|2),l.elementType=Kl,l.lanes=n,l;case nt:return l=dt(13,a,t,e),l.elementType=nt,l.lanes=n,l;case Jl:return l=dt(19,a,t,e),l.elementType=Jl,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case vl:f=10;break l;case et:f=9;break l;case El:f=11;break l;case V:f=14;break l;case wl:f=16,u=null;break l}f=29,a=Error(h(130,l===null?"null":typeof l,"")),u=null}return t=dt(f,a,t,e),t.elementType=l,t.type=u,t.lanes=n,t}function Ra(l,t,a,u){return l=dt(7,l,u,t),l.lanes=a,l}function Rf(l,t,a){return l=dt(6,l,null,t),l.lanes=a,l}function xs(l){var t=dt(18,null,null,0);return t.stateNode=l,t}function Nf(l,t,a){return t=dt(4,l.children!==null?l.children:[],l.key,t),t.lanes=a,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var Hs=new WeakMap;function zt(l,t){if(typeof l=="object"&&l!==null){var a=Hs.get(l);return a!==void 0?a:(t={value:l,source:t,stack:xc(t)},Hs.set(l,t),t)}return{value:l,source:t,stack:xc(t)}}var nu=[],fu=0,Ke=null,Ju=0,Tt=[],Et=0,ua=null,Ht=1,Rt="";function Gt(l,t){nu[fu++]=Ju,nu[fu++]=Ke,Ke=l,Ju=t}function Rs(l,t,a){Tt[Et++]=Ht,Tt[Et++]=Rt,Tt[Et++]=ua,ua=l;var u=Ht;l=Rt;var e=32-ct(u)-1;u&=~(1<<e),a+=1;var n=32-ct(t)+e;if(30<n){var f=e-e%5;n=(u&(1<<f)-1).toString(32),u>>=f,e-=f,Ht=1<<32-ct(t)+e|a<<e|u,Rt=n+l}else Ht=1<<n|a<<e|u,Rt=l}function Bf(l){l.return!==null&&(Gt(l,1),Rs(l,1,0))}function Cf(l){for(;l===Ke;)Ke=nu[--fu],nu[fu]=null,Ju=nu[--fu],nu[fu]=null;for(;l===ua;)ua=Tt[--Et],Tt[Et]=null,Rt=Tt[--Et],Tt[Et]=null,Ht=Tt[--Et],Tt[Et]=null}function Ns(l,t){Tt[Et++]=Ht,Tt[Et++]=Rt,Tt[Et++]=ua,Ht=t.id,Rt=t.overflow,ua=l}var Yl=null,ml=null,k=!1,ea=null,At=!1,jf=Error(h(519));function na(l){var t=Error(h(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw wu(zt(t,l)),jf}function Bs(l){var t=l.stateNode,a=l.type,u=l.memoizedProps;switch(t[ql]=l,t[Fl]=u,a){case"dialog":J("cancel",t),J("close",t);break;case"iframe":case"object":case"embed":J("load",t);break;case"video":case"audio":for(a=0;a<he.length;a++)J(he[a],t);break;case"source":J("error",t);break;case"img":case"image":case"link":J("error",t),J("load",t);break;case"details":J("toggle",t);break;case"input":J("invalid",t),wc(t,u.value,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name,!0);break;case"select":J("invalid",t);break;case"textarea":J("invalid",t),$c(t,u.value,u.defaultValue,u.children)}a=u.children,typeof a!="string"&&typeof a!="number"&&typeof a!="bigint"||t.textContent===""+a||u.suppressHydrationWarning===!0||F0(t.textContent,a)?(u.popover!=null&&(J("beforetoggle",t),J("toggle",t)),u.onScroll!=null&&J("scroll",t),u.onScrollEnd!=null&&J("scrollend",t),u.onClick!=null&&(t.onclick=jt),t=!0):t=!1,t||na(l,!0)}function Cs(l){for(Yl=l.return;Yl;)switch(Yl.tag){case 5:case 31:case 13:At=!1;return;case 27:case 3:At=!0;return;default:Yl=Yl.return}}function iu(l){if(l!==Yl)return!1;if(!k)return Cs(l),k=!0,!1;var t=l.tag,a;if((a=t!==3&&t!==27)&&((a=t===5)&&(a=l.type,a=!(a!=="form"&&a!=="button")||lc(l.type,l.memoizedProps)),a=!a),a&&ml&&na(l),Cs(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ml=fo(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(317));ml=fo(l)}else t===27?(t=ml,ba(l.type)?(l=nc,nc=null,ml=l):ml=t):ml=Yl?_t(l.stateNode.nextSibling):null;return!0}function Na(){ml=Yl=null,k=!1}function qf(){var l=ea;return l!==null&&(at===null?at=l:at.push.apply(at,l),ea=null),l}function wu(l){ea===null?ea=[l]:ea.push(l)}var Yf=d(null),Ba=null,Xt=null;function fa(l,t,a){_(Yf,t._currentValue),t._currentValue=a}function Qt(l){l._currentValue=Yf.current,T(Yf)}function Gf(l,t,a){for(;l!==null;){var u=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,u!==null&&(u.childLanes|=t)):u!==null&&(u.childLanes&t)!==t&&(u.childLanes|=t),l===a)break;l=l.return}}function Xf(l,t,a,u){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var f=e.child;n=n.firstContext;l:for(;n!==null;){var i=n;n=e;for(var c=0;c<t.length;c++)if(i.context===t[c]){n.lanes|=a,i=n.alternate,i!==null&&(i.lanes|=a),Gf(n.return,a,l),u||(f=null);break l}n=i.next}}else if(e.tag===18){if(f=e.return,f===null)throw Error(h(341));f.lanes|=a,n=f.alternate,n!==null&&(n.lanes|=a),Gf(f,a,l),f=null}else f=e.child;if(f!==null)f.return=e;else for(f=e;f!==null;){if(f===l){f=null;break}if(e=f.sibling,e!==null){e.return=f.return,f=e;break}f=f.return}e=f}}function cu(l,t,a,u){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var f=e.alternate;if(f===null)throw Error(h(387));if(f=f.memoizedProps,f!==null){var i=e.type;st(e.pendingProps.value,f.value)||(l!==null?l.push(i):l=[i])}}else if(e===el.current){if(f=e.alternate,f===null)throw Error(h(387));f.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(ze):l=[ze])}e=e.return}l!==null&&Xf(t,l,a,u),t.flags|=262144}function Je(l){for(l=l.firstContext;l!==null;){if(!st(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ca(l){Ba=l,Xt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Gl(l){return js(Ba,l)}function we(l,t){return Ba===null&&Ca(l),js(l,t)}function js(l,t){var a=t._currentValue;if(t={context:t,memoizedValue:a,next:null},Xt===null){if(l===null)throw Error(h(308));Xt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Xt=Xt.next=t;return a}var Iy=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(a,u){l.push(u)}};this.abort=function(){t.aborted=!0,l.forEach(function(a){return a()})}},Py=A.unstable_scheduleCallback,lv=A.unstable_NormalPriority,Ol={$$typeof:vl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Qf(){return{controller:new Iy,data:new Map,refCount:0}}function Wu(l){l.refCount--,l.refCount===0&&Py(lv,function(){l.controller.abort()})}var $u=null,Zf=0,su=0,du=null;function tv(l,t){if($u===null){var a=$u=[];Zf=0,su=Ki(),du={status:"pending",value:void 0,then:function(u){a.push(u)}}}return Zf++,t.then(qs,qs),t}function qs(){if(--Zf===0&&$u!==null){du!==null&&(du.status="fulfilled");var l=$u;$u=null,su=0,du=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function av(l,t){var a=[],u={status:"pending",value:null,reason:null,then:function(e){a.push(e)}};return l.then(function(){u.status="fulfilled",u.value=t;for(var e=0;e<a.length;e++)(0,a[e])(t)},function(e){for(u.status="rejected",u.reason=e,e=0;e<a.length;e++)(0,a[e])(void 0)}),u}var Ys=S.S;S.S=function(l,t){T0=ft(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&tv(l,t),Ys!==null&&Ys(l,t)};var ja=d(null);function Vf(){var l=ja.current;return l!==null?l:yl.pooledCache}function We(l,t){t===null?_(ja,ja.current):_(ja,t.pool)}function Gs(){var l=Vf();return l===null?null:{parent:Ol._currentValue,pool:l}}var ou=Error(h(460)),Lf=Error(h(474)),$e=Error(h(542)),ke={then:function(){}};function Xs(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Qs(l,t,a){switch(a=l[a],a===void 0?l.push(t):a!==t&&(t.then(jt,jt),t=a),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l;default:if(typeof t.status=="string")t.then(jt,jt);else{if(l=yl,l!==null&&100<l.shellSuspendCounter)throw Error(h(482));l=t,l.status="pending",l.then(function(u){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=u}},function(u){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=u}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,Vs(l),l}throw Ya=t,ou}}function qa(l){try{var t=l._init;return t(l._payload)}catch(a){throw a!==null&&typeof a=="object"&&typeof a.then=="function"?(Ya=a,ou):a}}var Ya=null;function Zs(){if(Ya===null)throw Error(h(459));var l=Ya;return Ya=null,l}function Vs(l){if(l===ou||l===$e)throw Error(h(483))}var yu=null,ku=0;function Fe(l){var t=ku;return ku+=1,yu===null&&(yu=[]),Qs(yu,l,t)}function Fu(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function Ie(l,t){throw t.$$typeof===il?Error(h(525)):(l=Object.prototype.toString.call(t),Error(h(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function Ls(l){function t(o,s){if(l){var y=o.deletions;y===null?(o.deletions=[s],o.flags|=16):y.push(s)}}function a(o,s){if(!l)return null;for(;s!==null;)t(o,s),s=s.sibling;return null}function u(o){for(var s=new Map;o!==null;)o.key!==null?s.set(o.key,o):s.set(o.index,o),o=o.sibling;return s}function e(o,s){return o=Yt(o,s),o.index=0,o.sibling=null,o}function n(o,s,y){return o.index=y,l?(y=o.alternate,y!==null?(y=y.index,y<s?(o.flags|=67108866,s):y):(o.flags|=67108866,s)):(o.flags|=1048576,s)}function f(o){return l&&o.alternate===null&&(o.flags|=67108866),o}function i(o,s,y,b){return s===null||s.tag!==6?(s=Rf(y,o.mode,b),s.return=o,s):(s=e(s,y),s.return=o,s)}function c(o,s,y,b){var N=y.type;return N===Rl?r(o,s,y.props.children,b,y.key):s!==null&&(s.elementType===N||typeof N=="object"&&N!==null&&N.$$typeof===wl&&qa(N)===s.type)?(s=e(s,y.props),Fu(s,y),s.return=o,s):(s=Le(y.type,y.key,y.props,null,o.mode,b),Fu(s,y),s.return=o,s)}function v(o,s,y,b){return s===null||s.tag!==4||s.stateNode.containerInfo!==y.containerInfo||s.stateNode.implementation!==y.implementation?(s=Nf(y,o.mode,b),s.return=o,s):(s=e(s,y.children||[]),s.return=o,s)}function r(o,s,y,b,N){return s===null||s.tag!==7?(s=Ra(y,o.mode,b,N),s.return=o,s):(s=e(s,y),s.return=o,s)}function z(o,s,y){if(typeof s=="string"&&s!==""||typeof s=="number"||typeof s=="bigint")return s=Rf(""+s,o.mode,y),s.return=o,s;if(typeof s=="object"&&s!==null){switch(s.$$typeof){case Ll:return y=Le(s.type,s.key,s.props,null,o.mode,y),Fu(y,s),y.return=o,y;case Cl:return s=Nf(s,o.mode,y),s.return=o,s;case wl:return s=qa(s),z(o,s,y)}if($(s)||jl(s))return s=Ra(s,o.mode,y,null),s.return=o,s;if(typeof s.then=="function")return z(o,Fe(s),y);if(s.$$typeof===vl)return z(o,we(o,s),y);Ie(o,s)}return null}function m(o,s,y,b){var N=s!==null?s.key:null;if(typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint")return N!==null?null:i(o,s,""+y,b);if(typeof y=="object"&&y!==null){switch(y.$$typeof){case Ll:return y.key===N?c(o,s,y,b):null;case Cl:return y.key===N?v(o,s,y,b):null;case wl:return y=qa(y),m(o,s,y,b)}if($(y)||jl(y))return N!==null?null:r(o,s,y,b,null);if(typeof y.then=="function")return m(o,s,Fe(y),b);if(y.$$typeof===vl)return m(o,s,we(o,y),b);Ie(o,y)}return null}function g(o,s,y,b,N){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return o=o.get(y)||null,i(s,o,""+b,N);if(typeof b=="object"&&b!==null){switch(b.$$typeof){case Ll:return o=o.get(b.key===null?y:b.key)||null,c(s,o,b,N);case Cl:return o=o.get(b.key===null?y:b.key)||null,v(s,o,b,N);case wl:return b=qa(b),g(o,s,y,b,N)}if($(b)||jl(b))return o=o.get(y)||null,r(s,o,b,N,null);if(typeof b.then=="function")return g(o,s,y,Fe(b),N);if(b.$$typeof===vl)return g(o,s,y,we(s,b),N);Ie(s,b)}return null}function M(o,s,y,b){for(var N=null,I=null,U=s,Z=s=0,W=null;U!==null&&Z<y.length;Z++){U.index>Z?(W=U,U=null):W=U.sibling;var P=m(o,U,y[Z],b);if(P===null){U===null&&(U=W);break}l&&U&&P.alternate===null&&t(o,U),s=n(P,s,Z),I===null?N=P:I.sibling=P,I=P,U=W}if(Z===y.length)return a(o,U),k&&Gt(o,Z),N;if(U===null){for(;Z<y.length;Z++)U=z(o,y[Z],b),U!==null&&(s=n(U,s,Z),I===null?N=U:I.sibling=U,I=U);return k&&Gt(o,Z),N}for(U=u(U);Z<y.length;Z++)W=g(U,o,Z,y[Z],b),W!==null&&(l&&W.alternate!==null&&U.delete(W.key===null?Z:W.key),s=n(W,s,Z),I===null?N=W:I.sibling=W,I=W);return l&&U.forEach(function(pa){return t(o,pa)}),k&&Gt(o,Z),N}function j(o,s,y,b){if(y==null)throw Error(h(151));for(var N=null,I=null,U=s,Z=s=0,W=null,P=y.next();U!==null&&!P.done;Z++,P=y.next()){U.index>Z?(W=U,U=null):W=U.sibling;var pa=m(o,U,P.value,b);if(pa===null){U===null&&(U=W);break}l&&U&&pa.alternate===null&&t(o,U),s=n(pa,s,Z),I===null?N=pa:I.sibling=pa,I=pa,U=W}if(P.done)return a(o,U),k&&Gt(o,Z),N;if(U===null){for(;!P.done;Z++,P=y.next())P=z(o,P.value,b),P!==null&&(s=n(P,s,Z),I===null?N=P:I.sibling=P,I=P);return k&&Gt(o,Z),N}for(U=u(U);!P.done;Z++,P=y.next())P=g(U,o,Z,P.value,b),P!==null&&(l&&P.alternate!==null&&U.delete(P.key===null?Z:P.key),s=n(P,s,Z),I===null?N=P:I.sibling=P,I=P);return l&&U.forEach(function(vm){return t(o,vm)}),k&&Gt(o,Z),N}function dl(o,s,y,b){if(typeof y=="object"&&y!==null&&y.type===Rl&&y.key===null&&(y=y.props.children),typeof y=="object"&&y!==null){switch(y.$$typeof){case Ll:l:{for(var N=y.key;s!==null;){if(s.key===N){if(N=y.type,N===Rl){if(s.tag===7){a(o,s.sibling),b=e(s,y.props.children),b.return=o,o=b;break l}}else if(s.elementType===N||typeof N=="object"&&N!==null&&N.$$typeof===wl&&qa(N)===s.type){a(o,s.sibling),b=e(s,y.props),Fu(b,y),b.return=o,o=b;break l}a(o,s);break}else t(o,s);s=s.sibling}y.type===Rl?(b=Ra(y.props.children,o.mode,b,y.key),b.return=o,o=b):(b=Le(y.type,y.key,y.props,null,o.mode,b),Fu(b,y),b.return=o,o=b)}return f(o);case Cl:l:{for(N=y.key;s!==null;){if(s.key===N)if(s.tag===4&&s.stateNode.containerInfo===y.containerInfo&&s.stateNode.implementation===y.implementation){a(o,s.sibling),b=e(s,y.children||[]),b.return=o,o=b;break l}else{a(o,s);break}else t(o,s);s=s.sibling}b=Nf(y,o.mode,b),b.return=o,o=b}return f(o);case wl:return y=qa(y),dl(o,s,y,b)}if($(y))return M(o,s,y,b);if(jl(y)){if(N=jl(y),typeof N!="function")throw Error(h(150));return y=N.call(y),j(o,s,y,b)}if(typeof y.then=="function")return dl(o,s,Fe(y),b);if(y.$$typeof===vl)return dl(o,s,we(o,y),b);Ie(o,y)}return typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint"?(y=""+y,s!==null&&s.tag===6?(a(o,s.sibling),b=e(s,y),b.return=o,o=b):(a(o,s),b=Rf(y,o.mode,b),b.return=o,o=b),f(o)):a(o,s)}return function(o,s,y,b){try{ku=0;var N=dl(o,s,y,b);return yu=null,N}catch(U){if(U===ou||U===$e)throw U;var I=dt(29,U,null,o.mode);return I.lanes=b,I.return=o,I}finally{}}}var Ga=Ls(!0),Ks=Ls(!1),ia=!1;function Kf(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Jf(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function ca(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function sa(l,t,a){var u=l.updateQueue;if(u===null)return null;if(u=u.shared,(ll&2)!==0){var e=u.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),u.pending=t,t=Ve(l),Ds(l,null,a),t}return Ze(l,u,t,a),Ve(l)}function Iu(l,t,a){if(t=t.updateQueue,t!==null&&(t=t.shared,(a&4194048)!==0)){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,jc(l,a)}}function wf(l,t){var a=l.updateQueue,u=l.alternate;if(u!==null&&(u=u.updateQueue,a===u)){var e=null,n=null;if(a=a.firstBaseUpdate,a!==null){do{var f={lane:a.lane,tag:a.tag,payload:a.payload,callback:null,next:null};n===null?e=n=f:n=n.next=f,a=a.next}while(a!==null);n===null?e=n=t:n=n.next=t}else e=n=t;a={baseState:u.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:u.shared,callbacks:u.callbacks},l.updateQueue=a;return}l=a.lastBaseUpdate,l===null?a.firstBaseUpdate=t:l.next=t,a.lastBaseUpdate=t}var Wf=!1;function Pu(){if(Wf){var l=du;if(l!==null)throw l}}function le(l,t,a,u){Wf=!1;var e=l.updateQueue;ia=!1;var n=e.firstBaseUpdate,f=e.lastBaseUpdate,i=e.shared.pending;if(i!==null){e.shared.pending=null;var c=i,v=c.next;c.next=null,f===null?n=v:f.next=v,f=c;var r=l.alternate;r!==null&&(r=r.updateQueue,i=r.lastBaseUpdate,i!==f&&(i===null?r.firstBaseUpdate=v:i.next=v,r.lastBaseUpdate=c))}if(n!==null){var z=e.baseState;f=0,r=v=c=null,i=n;do{var m=i.lane&-536870913,g=m!==i.lane;if(g?(w&m)===m:(u&m)===m){m!==0&&m===su&&(Wf=!0),r!==null&&(r=r.next={lane:0,tag:i.tag,payload:i.payload,callback:null,next:null});l:{var M=l,j=i;m=t;var dl=a;switch(j.tag){case 1:if(M=j.payload,typeof M=="function"){z=M.call(dl,z,m);break l}z=M;break l;case 3:M.flags=M.flags&-65537|128;case 0:if(M=j.payload,m=typeof M=="function"?M.call(dl,z,m):M,m==null)break l;z=C({},z,m);break l;case 2:ia=!0}}m=i.callback,m!==null&&(l.flags|=64,g&&(l.flags|=8192),g=e.callbacks,g===null?e.callbacks=[m]:g.push(m))}else g={lane:m,tag:i.tag,payload:i.payload,callback:i.callback,next:null},r===null?(v=r=g,c=z):r=r.next=g,f|=m;if(i=i.next,i===null){if(i=e.shared.pending,i===null)break;g=i,i=g.next,g.next=null,e.lastBaseUpdate=g,e.shared.pending=null}}while(!0);r===null&&(c=z),e.baseState=c,e.firstBaseUpdate=v,e.lastBaseUpdate=r,n===null&&(e.shared.lanes=0),ma|=f,l.lanes=f,l.memoizedState=z}}function Js(l,t){if(typeof l!="function")throw Error(h(191,l));l.call(t)}function ws(l,t){var a=l.callbacks;if(a!==null)for(l.callbacks=null,l=0;l<a.length;l++)Js(a[l],t)}var vu=d(null),Pe=d(0);function Ws(l,t){l=kt,_(Pe,l),_(vu,t),kt=l|t.baseLanes}function $f(){_(Pe,kt),_(vu,vu.current)}function kf(){kt=Pe.current,T(vu),T(Pe)}var ot=d(null),pt=null;function da(l){var t=l.alternate;_(pl,pl.current&1),_(ot,l),pt===null&&(t===null||vu.current!==null||t.memoizedState!==null)&&(pt=l)}function Ff(l){_(pl,pl.current),_(ot,l),pt===null&&(pt=l)}function $s(l){l.tag===22?(_(pl,pl.current),_(ot,l),pt===null&&(pt=l)):oa()}function oa(){_(pl,pl.current),_(ot,ot.current)}function yt(l){T(ot),pt===l&&(pt=null),T(pl)}var pl=d(0);function ln(l){for(var t=l;t!==null;){if(t.tag===13){var a=t.memoizedState;if(a!==null&&(a=a.dehydrated,a===null||uc(a)||ec(a)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Zt=0,Q=null,cl=null,Ml=null,tn=!1,mu=!1,Xa=!1,an=0,te=0,hu=null,uv=0;function bl(){throw Error(h(321))}function If(l,t){if(t===null)return!1;for(var a=0;a<t.length&&a<l.length;a++)if(!st(l[a],t[a]))return!1;return!0}function Pf(l,t,a,u,e,n){return Zt=n,Q=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,S.H=l===null||l.memoizedState===null?Rd:mi,Xa=!1,n=a(u,e),Xa=!1,mu&&(n=Fs(t,a,u,e)),ks(l),n}function ks(l){S.H=ee;var t=cl!==null&&cl.next!==null;if(Zt=0,Ml=cl=Q=null,tn=!1,te=0,hu=null,t)throw Error(h(300));l===null||Dl||(l=l.dependencies,l!==null&&Je(l)&&(Dl=!0))}function Fs(l,t,a,u){Q=l;var e=0;do{if(mu&&(hu=null),te=0,mu=!1,25<=e)throw Error(h(301));if(e+=1,Ml=cl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}S.H=Nd,n=t(a,u)}while(mu);return n}function ev(){var l=S.H,t=l.useState()[0];return t=typeof t.then=="function"?ae(t):t,l=l.useState()[0],(cl!==null?cl.memoizedState:null)!==l&&(Q.flags|=1024),t}function li(){var l=an!==0;return an=0,l}function ti(l,t,a){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~a}function ai(l){if(tn){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}tn=!1}Zt=0,Ml=cl=Q=null,mu=!1,te=an=0,hu=null}function $l(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Ml===null?Q.memoizedState=Ml=l:Ml=Ml.next=l,Ml}function _l(){if(cl===null){var l=Q.alternate;l=l!==null?l.memoizedState:null}else l=cl.next;var t=Ml===null?Q.memoizedState:Ml.next;if(t!==null)Ml=t,cl=l;else{if(l===null)throw Q.alternate===null?Error(h(467)):Error(h(310));cl=l,l={memoizedState:cl.memoizedState,baseState:cl.baseState,baseQueue:cl.baseQueue,queue:cl.queue,next:null},Ml===null?Q.memoizedState=Ml=l:Ml=Ml.next=l}return Ml}function un(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function ae(l){var t=te;return te+=1,hu===null&&(hu=[]),l=Qs(hu,l,t),t=Q,(Ml===null?t.memoizedState:Ml.next)===null&&(t=t.alternate,S.H=t===null||t.memoizedState===null?Rd:mi),l}function en(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return ae(l);if(l.$$typeof===vl)return Gl(l)}throw Error(h(438,String(l)))}function ui(l){var t=null,a=Q.updateQueue;if(a!==null&&(t=a.memoCache),t==null){var u=Q.alternate;u!==null&&(u=u.updateQueue,u!==null&&(u=u.memoCache,u!=null&&(t={data:u.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),a===null&&(a=un(),Q.updateQueue=a),a.memoCache=t,a=t.data[t.index],a===void 0)for(a=t.data[t.index]=Array(l),u=0;u<l;u++)a[u]=Pt;return t.index++,a}function Vt(l,t){return typeof t=="function"?t(l):t}function nn(l){var t=_l();return ei(t,cl,l)}function ei(l,t,a){var u=l.queue;if(u===null)throw Error(h(311));u.lastRenderedReducer=a;var e=l.baseQueue,n=u.pending;if(n!==null){if(e!==null){var f=e.next;e.next=n.next,n.next=f}t.baseQueue=e=n,u.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var i=f=null,c=null,v=t,r=!1;do{var z=v.lane&-536870913;if(z!==v.lane?(w&z)===z:(Zt&z)===z){var m=v.revertLane;if(m===0)c!==null&&(c=c.next={lane:0,revertLane:0,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null}),z===su&&(r=!0);else if((Zt&m)===m){v=v.next,m===su&&(r=!0);continue}else z={lane:0,revertLane:v.revertLane,gesture:null,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=z,f=n):c=c.next=z,Q.lanes|=m,ma|=m;z=v.action,Xa&&a(n,z),n=v.hasEagerState?v.eagerState:a(n,z)}else m={lane:z,revertLane:v.revertLane,gesture:v.gesture,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},c===null?(i=c=m,f=n):c=c.next=m,Q.lanes|=z,ma|=z;v=v.next}while(v!==null&&v!==t);if(c===null?f=n:c.next=i,!st(n,l.memoizedState)&&(Dl=!0,r&&(a=du,a!==null)))throw a;l.memoizedState=n,l.baseState=f,l.baseQueue=c,u.lastRenderedState=n}return e===null&&(u.lanes=0),[l.memoizedState,u.dispatch]}function ni(l){var t=_l(),a=t.queue;if(a===null)throw Error(h(311));a.lastRenderedReducer=l;var u=a.dispatch,e=a.pending,n=t.memoizedState;if(e!==null){a.pending=null;var f=e=e.next;do n=l(n,f.action),f=f.next;while(f!==e);st(n,t.memoizedState)||(Dl=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),a.lastRenderedState=n}return[n,u]}function Is(l,t,a){var u=Q,e=_l(),n=k;if(n){if(a===void 0)throw Error(h(407));a=a()}else a=t();var f=!st((cl||e).memoizedState,a);if(f&&(e.memoizedState=a,Dl=!0),e=e.queue,ci(td.bind(null,u,e,l),[l]),e.getSnapshot!==t||f||Ml!==null&&Ml.memoizedState.tag&1){if(u.flags|=2048,gu(9,{destroy:void 0},ld.bind(null,u,e,a,t),null),yl===null)throw Error(h(349));n||(Zt&127)!==0||Ps(u,t,a)}return a}function Ps(l,t,a){l.flags|=16384,l={getSnapshot:t,value:a},t=Q.updateQueue,t===null?(t=un(),Q.updateQueue=t,t.stores=[l]):(a=t.stores,a===null?t.stores=[l]:a.push(l))}function ld(l,t,a,u){t.value=a,t.getSnapshot=u,ad(t)&&ud(l)}function td(l,t,a){return a(function(){ad(t)&&ud(l)})}function ad(l){var t=l.getSnapshot;l=l.value;try{var a=t();return!st(l,a)}catch{return!0}}function ud(l){var t=Ha(l,2);t!==null&&ut(t,l,2)}function fi(l){var t=$l();if(typeof l=="function"){var a=l;if(l=a(),Xa){la(!0);try{a()}finally{la(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Vt,lastRenderedState:l},t}function ed(l,t,a,u){return l.baseState=a,ei(l,cl,typeof u=="function"?u:Vt)}function nv(l,t,a,u,e){if(sn(l))throw Error(h(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(f){n.listeners.push(f)}};S.T!==null?a(!0):n.isTransition=!1,u(n),a=t.pending,a===null?(n.next=t.pending=n,nd(t,n)):(n.next=a.next,t.pending=a.next=n)}}function nd(l,t){var a=t.action,u=t.payload,e=l.state;if(t.isTransition){var n=S.T,f={};S.T=f;try{var i=a(e,u),c=S.S;c!==null&&c(f,i),fd(l,t,i)}catch(v){ii(l,t,v)}finally{n!==null&&f.types!==null&&(n.types=f.types),S.T=n}}else try{n=a(e,u),fd(l,t,n)}catch(v){ii(l,t,v)}}function fd(l,t,a){a!==null&&typeof a=="object"&&typeof a.then=="function"?a.then(function(u){id(l,t,u)},function(u){return ii(l,t,u)}):id(l,t,a)}function id(l,t,a){t.status="fulfilled",t.value=a,cd(t),l.state=a,t=l.pending,t!==null&&(a=t.next,a===t?l.pending=null:(a=a.next,t.next=a,nd(l,a)))}function ii(l,t,a){var u=l.pending;if(l.pending=null,u!==null){u=u.next;do t.status="rejected",t.reason=a,cd(t),t=t.next;while(t!==u)}l.action=null}function cd(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function sd(l,t){return t}function dd(l,t){if(k){var a=yl.formState;if(a!==null){l:{var u=Q;if(k){if(ml){t:{for(var e=ml,n=At;e.nodeType!==8;){if(!n){e=null;break t}if(e=_t(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){ml=_t(e.nextSibling),u=e.data==="F!";break l}}na(u)}u=!1}u&&(t=a[0])}}return a=$l(),a.memoizedState=a.baseState=t,u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:sd,lastRenderedState:t},a.queue=u,a=Ud.bind(null,Q,u),u.dispatch=a,u=fi(!1),n=vi.bind(null,Q,!1,u.queue),u=$l(),e={state:t,dispatch:null,action:l,pending:null},u.queue=e,a=nv.bind(null,Q,e,n,a),e.dispatch=a,u.memoizedState=l,[t,a,!1]}function od(l){var t=_l();return yd(t,cl,l)}function yd(l,t,a){if(t=ei(l,t,sd)[0],l=nn(Vt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var u=ae(t)}catch(f){throw f===ou?$e:f}else u=t;t=_l();var e=t.queue,n=e.dispatch;return a!==t.memoizedState&&(Q.flags|=2048,gu(9,{destroy:void 0},fv.bind(null,e,a),null)),[u,n,l]}function fv(l,t){l.action=t}function vd(l){var t=_l(),a=cl;if(a!==null)return yd(t,a,l);_l(),t=t.memoizedState,a=_l();var u=a.queue.dispatch;return a.memoizedState=l,[t,u,!1]}function gu(l,t,a,u){return l={tag:l,create:a,deps:u,inst:t,next:null},t=Q.updateQueue,t===null&&(t=un(),Q.updateQueue=t),a=t.lastEffect,a===null?t.lastEffect=l.next=l:(u=a.next,a.next=l,l.next=u,t.lastEffect=l),l}function md(){return _l().memoizedState}function fn(l,t,a,u){var e=$l();Q.flags|=l,e.memoizedState=gu(1|t,{destroy:void 0},a,u===void 0?null:u)}function cn(l,t,a,u){var e=_l();u=u===void 0?null:u;var n=e.memoizedState.inst;cl!==null&&u!==null&&If(u,cl.memoizedState.deps)?e.memoizedState=gu(t,n,a,u):(Q.flags|=l,e.memoizedState=gu(1|t,n,a,u))}function hd(l,t){fn(8390656,8,l,t)}function ci(l,t){cn(2048,8,l,t)}function iv(l){Q.flags|=4;var t=Q.updateQueue;if(t===null)t=un(),Q.updateQueue=t,t.events=[l];else{var a=t.events;a===null?t.events=[l]:a.push(l)}}function gd(l){var t=_l().memoizedState;return iv({ref:t,nextImpl:l}),function(){if((ll&2)!==0)throw Error(h(440));return t.impl.apply(void 0,arguments)}}function Sd(l,t){return cn(4,2,l,t)}function rd(l,t){return cn(4,4,l,t)}function bd(l,t){if(typeof t=="function"){l=l();var a=t(l);return function(){typeof a=="function"?a():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function zd(l,t,a){a=a!=null?a.concat([l]):null,cn(4,4,bd.bind(null,t,l),a)}function si(){}function Td(l,t){var a=_l();t=t===void 0?null:t;var u=a.memoizedState;return t!==null&&If(t,u[1])?u[0]:(a.memoizedState=[l,t],l)}function Ed(l,t){var a=_l();t=t===void 0?null:t;var u=a.memoizedState;if(t!==null&&If(t,u[1]))return u[0];if(u=l(),Xa){la(!0);try{l()}finally{la(!1)}}return a.memoizedState=[u,t],u}function di(l,t,a){return a===void 0||(Zt&1073741824)!==0&&(w&261930)===0?l.memoizedState=t:(l.memoizedState=a,l=A0(),Q.lanes|=l,ma|=l,a)}function Ad(l,t,a,u){return st(a,t)?a:vu.current!==null?(l=di(l,a,u),st(l,t)||(Dl=!0),l):(Zt&42)===0||(Zt&1073741824)!==0&&(w&261930)===0?(Dl=!0,l.memoizedState=a):(l=A0(),Q.lanes|=l,ma|=l,t)}function pd(l,t,a,u,e){var n=p.p;p.p=n!==0&&8>n?n:8;var f=S.T,i={};S.T=i,vi(l,!1,t,a);try{var c=e(),v=S.S;if(v!==null&&v(i,c),c!==null&&typeof c=="object"&&typeof c.then=="function"){var r=av(c,u);ue(l,t,r,ht(l))}else ue(l,t,u,ht(l))}catch(z){ue(l,t,{then:function(){},status:"rejected",reason:z},ht())}finally{p.p=n,f!==null&&i.types!==null&&(f.types=i.types),S.T=f}}function cv(){}function oi(l,t,a,u){if(l.tag!==5)throw Error(h(476));var e=_d(l).queue;pd(l,e,t,H,a===null?cv:function(){return Od(l),a(u)})}function _d(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:H,baseState:H,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Vt,lastRenderedState:H},next:null};var a={};return t.next={memoizedState:a,baseState:a,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Vt,lastRenderedState:a},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function Od(l){var t=_d(l);t.next===null&&(t=l.alternate.memoizedState),ue(l,t.next.queue,{},ht())}function yi(){return Gl(ze)}function Md(){return _l().memoizedState}function Dd(){return _l().memoizedState}function sv(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var a=ht();l=ca(a);var u=sa(t,l,a);u!==null&&(ut(u,t,a),Iu(u,t,a)),t={cache:Qf()},l.payload=t;return}t=t.return}}function dv(l,t,a){var u=ht();a={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},sn(l)?xd(t,a):(a=xf(l,t,a,u),a!==null&&(ut(a,l,u),Hd(a,t,u)))}function Ud(l,t,a){var u=ht();ue(l,t,a,u)}function ue(l,t,a,u){var e={lane:u,revertLane:0,gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null};if(sn(l))xd(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var f=t.lastRenderedState,i=n(f,a);if(e.hasEagerState=!0,e.eagerState=i,st(i,f))return Ze(l,t,e,0),yl===null&&Qe(),!1}catch{}finally{}if(a=xf(l,t,e,u),a!==null)return ut(a,l,u),Hd(a,t,u),!0}return!1}function vi(l,t,a,u){if(u={lane:2,revertLane:Ki(),gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null},sn(l)){if(t)throw Error(h(479))}else t=xf(l,a,u,2),t!==null&&ut(t,l,2)}function sn(l){var t=l.alternate;return l===Q||t!==null&&t===Q}function xd(l,t){mu=tn=!0;var a=l.pending;a===null?t.next=t:(t.next=a.next,a.next=t),l.pending=t}function Hd(l,t,a){if((a&4194048)!==0){var u=t.lanes;u&=l.pendingLanes,a|=u,t.lanes=a,jc(l,a)}}var ee={readContext:Gl,use:en,useCallback:bl,useContext:bl,useEffect:bl,useImperativeHandle:bl,useLayoutEffect:bl,useInsertionEffect:bl,useMemo:bl,useReducer:bl,useRef:bl,useState:bl,useDebugValue:bl,useDeferredValue:bl,useTransition:bl,useSyncExternalStore:bl,useId:bl,useHostTransitionStatus:bl,useFormState:bl,useActionState:bl,useOptimistic:bl,useMemoCache:bl,useCacheRefresh:bl};ee.useEffectEvent=bl;var Rd={readContext:Gl,use:en,useCallback:function(l,t){return $l().memoizedState=[l,t===void 0?null:t],l},useContext:Gl,useEffect:hd,useImperativeHandle:function(l,t,a){a=a!=null?a.concat([l]):null,fn(4194308,4,bd.bind(null,t,l),a)},useLayoutEffect:function(l,t){return fn(4194308,4,l,t)},useInsertionEffect:function(l,t){fn(4,2,l,t)},useMemo:function(l,t){var a=$l();t=t===void 0?null:t;var u=l();if(Xa){la(!0);try{l()}finally{la(!1)}}return a.memoizedState=[u,t],u},useReducer:function(l,t,a){var u=$l();if(a!==void 0){var e=a(t);if(Xa){la(!0);try{a(t)}finally{la(!1)}}}else e=t;return u.memoizedState=u.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},u.queue=l,l=l.dispatch=dv.bind(null,Q,l),[u.memoizedState,l]},useRef:function(l){var t=$l();return l={current:l},t.memoizedState=l},useState:function(l){l=fi(l);var t=l.queue,a=Ud.bind(null,Q,t);return t.dispatch=a,[l.memoizedState,a]},useDebugValue:si,useDeferredValue:function(l,t){var a=$l();return di(a,l,t)},useTransition:function(){var l=fi(!1);return l=pd.bind(null,Q,l.queue,!0,!1),$l().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,a){var u=Q,e=$l();if(k){if(a===void 0)throw Error(h(407));a=a()}else{if(a=t(),yl===null)throw Error(h(349));(w&127)!==0||Ps(u,t,a)}e.memoizedState=a;var n={value:a,getSnapshot:t};return e.queue=n,hd(td.bind(null,u,n,l),[l]),u.flags|=2048,gu(9,{destroy:void 0},ld.bind(null,u,n,a,t),null),a},useId:function(){var l=$l(),t=yl.identifierPrefix;if(k){var a=Rt,u=Ht;a=(u&~(1<<32-ct(u)-1)).toString(32)+a,t="_"+t+"R_"+a,a=an++,0<a&&(t+="H"+a.toString(32)),t+="_"}else a=uv++,t="_"+t+"r_"+a.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:yi,useFormState:dd,useActionState:dd,useOptimistic:function(l){var t=$l();t.memoizedState=t.baseState=l;var a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=a,t=vi.bind(null,Q,!0,a),a.dispatch=t,[l,t]},useMemoCache:ui,useCacheRefresh:function(){return $l().memoizedState=sv.bind(null,Q)},useEffectEvent:function(l){var t=$l(),a={impl:l};return t.memoizedState=a,function(){if((ll&2)!==0)throw Error(h(440));return a.impl.apply(void 0,arguments)}}},mi={readContext:Gl,use:en,useCallback:Td,useContext:Gl,useEffect:ci,useImperativeHandle:zd,useInsertionEffect:Sd,useLayoutEffect:rd,useMemo:Ed,useReducer:nn,useRef:md,useState:function(){return nn(Vt)},useDebugValue:si,useDeferredValue:function(l,t){var a=_l();return Ad(a,cl.memoizedState,l,t)},useTransition:function(){var l=nn(Vt)[0],t=_l().memoizedState;return[typeof l=="boolean"?l:ae(l),t]},useSyncExternalStore:Is,useId:Md,useHostTransitionStatus:yi,useFormState:od,useActionState:od,useOptimistic:function(l,t){var a=_l();return ed(a,cl,l,t)},useMemoCache:ui,useCacheRefresh:Dd};mi.useEffectEvent=gd;var Nd={readContext:Gl,use:en,useCallback:Td,useContext:Gl,useEffect:ci,useImperativeHandle:zd,useInsertionEffect:Sd,useLayoutEffect:rd,useMemo:Ed,useReducer:ni,useRef:md,useState:function(){return ni(Vt)},useDebugValue:si,useDeferredValue:function(l,t){var a=_l();return cl===null?di(a,l,t):Ad(a,cl.memoizedState,l,t)},useTransition:function(){var l=ni(Vt)[0],t=_l().memoizedState;return[typeof l=="boolean"?l:ae(l),t]},useSyncExternalStore:Is,useId:Md,useHostTransitionStatus:yi,useFormState:vd,useActionState:vd,useOptimistic:function(l,t){var a=_l();return cl!==null?ed(a,cl,l,t):(a.baseState=l,[l,a.queue.dispatch])},useMemoCache:ui,useCacheRefresh:Dd};Nd.useEffectEvent=gd;function hi(l,t,a,u){t=l.memoizedState,a=a(u,t),a=a==null?t:C({},t,a),l.memoizedState=a,l.lanes===0&&(l.updateQueue.baseState=a)}var gi={enqueueSetState:function(l,t,a){l=l._reactInternals;var u=ht(),e=ca(u);e.payload=t,a!=null&&(e.callback=a),t=sa(l,e,u),t!==null&&(ut(t,l,u),Iu(t,l,u))},enqueueReplaceState:function(l,t,a){l=l._reactInternals;var u=ht(),e=ca(u);e.tag=1,e.payload=t,a!=null&&(e.callback=a),t=sa(l,e,u),t!==null&&(ut(t,l,u),Iu(t,l,u))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var a=ht(),u=ca(a);u.tag=2,t!=null&&(u.callback=t),t=sa(l,u,a),t!==null&&(ut(t,l,a),Iu(t,l,a))}};function Bd(l,t,a,u,e,n,f){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(u,n,f):t.prototype&&t.prototype.isPureReactComponent?!Lu(a,u)||!Lu(e,n):!0}function Cd(l,t,a,u){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(a,u),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(a,u),t.state!==l&&gi.enqueueReplaceState(t,t.state,null)}function Qa(l,t){var a=t;if("ref"in t){a={};for(var u in t)u!=="ref"&&(a[u]=t[u])}if(l=l.defaultProps){a===t&&(a=C({},a));for(var e in l)a[e]===void 0&&(a[e]=l[e])}return a}function jd(l){Xe(l)}function qd(l){console.error(l)}function Yd(l){Xe(l)}function dn(l,t){try{var a=l.onUncaughtError;a(t.value,{componentStack:t.stack})}catch(u){setTimeout(function(){throw u})}}function Gd(l,t,a){try{var u=l.onCaughtError;u(a.value,{componentStack:a.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function Si(l,t,a){return a=ca(a),a.tag=3,a.payload={element:null},a.callback=function(){dn(l,t)},a}function Xd(l){return l=ca(l),l.tag=3,l}function Qd(l,t,a,u){var e=a.type.getDerivedStateFromError;if(typeof e=="function"){var n=u.value;l.payload=function(){return e(n)},l.callback=function(){Gd(t,a,u)}}var f=a.stateNode;f!==null&&typeof f.componentDidCatch=="function"&&(l.callback=function(){Gd(t,a,u),typeof e!="function"&&(ha===null?ha=new Set([this]):ha.add(this));var i=u.stack;this.componentDidCatch(u.value,{componentStack:i!==null?i:""})})}function ov(l,t,a,u,e){if(a.flags|=32768,u!==null&&typeof u=="object"&&typeof u.then=="function"){if(t=a.alternate,t!==null&&cu(t,a,e,!0),a=ot.current,a!==null){switch(a.tag){case 31:case 13:return pt===null?En():a.alternate===null&&zl===0&&(zl=3),a.flags&=-257,a.flags|=65536,a.lanes=e,u===ke?a.flags|=16384:(t=a.updateQueue,t===null?a.updateQueue=new Set([u]):t.add(u),Zi(l,u,e)),!1;case 22:return a.flags|=65536,u===ke?a.flags|=16384:(t=a.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([u])},a.updateQueue=t):(a=t.retryQueue,a===null?t.retryQueue=new Set([u]):a.add(u)),Zi(l,u,e)),!1}throw Error(h(435,a.tag))}return Zi(l,u,e),En(),!1}if(k)return t=ot.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,u!==jf&&(l=Error(h(422),{cause:u}),wu(zt(l,a)))):(u!==jf&&(t=Error(h(423),{cause:u}),wu(zt(t,a))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,u=zt(u,a),e=Si(l.stateNode,u,e),wf(l,e),zl!==4&&(zl=2)),!1;var n=Error(h(520),{cause:u});if(n=zt(n,a),ye===null?ye=[n]:ye.push(n),zl!==4&&(zl=2),t===null)return!0;u=zt(u,a),a=t;do{switch(a.tag){case 3:return a.flags|=65536,l=e&-e,a.lanes|=l,l=Si(a.stateNode,u,l),wf(a,l),!1;case 1:if(t=a.type,n=a.stateNode,(a.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(ha===null||!ha.has(n))))return a.flags|=65536,e&=-e,a.lanes|=e,e=Xd(e),Qd(e,l,a,u),wf(a,e),!1}a=a.return}while(a!==null);return!1}var ri=Error(h(461)),Dl=!1;function Xl(l,t,a,u){t.child=l===null?Ks(t,null,a,u):Ga(t,l.child,a,u)}function Zd(l,t,a,u,e){a=a.render;var n=t.ref;if("ref"in u){var f={};for(var i in u)i!=="ref"&&(f[i]=u[i])}else f=u;return Ca(t),u=Pf(l,t,a,f,n,e),i=li(),l!==null&&!Dl?(ti(l,t,e),Lt(l,t,e)):(k&&i&&Bf(t),t.flags|=1,Xl(l,t,u,e),t.child)}function Vd(l,t,a,u,e){if(l===null){var n=a.type;return typeof n=="function"&&!Hf(n)&&n.defaultProps===void 0&&a.compare===null?(t.tag=15,t.type=n,Ld(l,t,n,u,e)):(l=Le(a.type,null,u,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!Oi(l,e)){var f=n.memoizedProps;if(a=a.compare,a=a!==null?a:Lu,a(f,u)&&l.ref===t.ref)return Lt(l,t,e)}return t.flags|=1,l=Yt(n,u),l.ref=t.ref,l.return=t,t.child=l}function Ld(l,t,a,u,e){if(l!==null){var n=l.memoizedProps;if(Lu(n,u)&&l.ref===t.ref)if(Dl=!1,t.pendingProps=u=n,Oi(l,e))(l.flags&131072)!==0&&(Dl=!0);else return t.lanes=l.lanes,Lt(l,t,e)}return bi(l,t,a,u,e)}function Kd(l,t,a,u){var e=u.children,n=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),u.mode==="hidden"){if((t.flags&128)!==0){if(n=n!==null?n.baseLanes|a:a,l!==null){for(u=t.child=l.child,e=0;u!==null;)e=e|u.lanes|u.childLanes,u=u.sibling;u=e&~n}else u=0,t.child=null;return Jd(l,t,n,a,u)}if((a&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&We(t,n!==null?n.cachePool:null),n!==null?Ws(t,n):$f(),$s(t);else return u=t.lanes=536870912,Jd(l,t,n!==null?n.baseLanes|a:a,a,u)}else n!==null?(We(t,n.cachePool),Ws(t,n),oa(),t.memoizedState=null):(l!==null&&We(t,null),$f(),oa());return Xl(l,t,e,a),t.child}function ne(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function Jd(l,t,a,u,e){var n=Vf();return n=n===null?null:{parent:Ol._currentValue,pool:n},t.memoizedState={baseLanes:a,cachePool:n},l!==null&&We(t,null),$f(),$s(t),l!==null&&cu(l,t,u,!0),t.childLanes=e,null}function on(l,t){return t=vn({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function wd(l,t,a){return Ga(t,l.child,null,a),l=on(t,t.pendingProps),l.flags|=2,yt(t),t.memoizedState=null,l}function yv(l,t,a){var u=t.pendingProps,e=(t.flags&128)!==0;if(t.flags&=-129,l===null){if(k){if(u.mode==="hidden")return l=on(t,u),t.lanes=536870912,ne(null,l);if(Ff(t),(l=ml)?(l=no(l,At),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ua!==null?{id:Ht,overflow:Rt}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Yl=t,ml=null)):l=null,l===null)throw na(t);return t.lanes=536870912,null}return on(t,u)}var n=l.memoizedState;if(n!==null){var f=n.dehydrated;if(Ff(t),e)if(t.flags&256)t.flags&=-257,t=wd(l,t,a);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(h(558));else if(Dl||cu(l,t,a,!1),e=(a&l.childLanes)!==0,Dl||e){if(u=yl,u!==null&&(f=qc(u,a),f!==0&&f!==n.retryLane))throw n.retryLane=f,Ha(l,f),ut(u,l,f),ri;En(),t=wd(l,t,a)}else l=n.treeContext,ml=_t(f.nextSibling),Yl=t,k=!0,ea=null,At=!1,l!==null&&Ns(t,l),t=on(t,u),t.flags|=4096;return t}return l=Yt(l.child,{mode:u.mode,children:u.children}),l.ref=t.ref,t.child=l,l.return=t,l}function yn(l,t){var a=t.ref;if(a===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof a!="function"&&typeof a!="object")throw Error(h(284));(l===null||l.ref!==a)&&(t.flags|=4194816)}}function bi(l,t,a,u,e){return Ca(t),a=Pf(l,t,a,u,void 0,e),u=li(),l!==null&&!Dl?(ti(l,t,e),Lt(l,t,e)):(k&&u&&Bf(t),t.flags|=1,Xl(l,t,a,e),t.child)}function Wd(l,t,a,u,e,n){return Ca(t),t.updateQueue=null,a=Fs(t,u,a,e),ks(l),u=li(),l!==null&&!Dl?(ti(l,t,n),Lt(l,t,n)):(k&&u&&Bf(t),t.flags|=1,Xl(l,t,a,n),t.child)}function $d(l,t,a,u,e){if(Ca(t),t.stateNode===null){var n=eu,f=a.contextType;typeof f=="object"&&f!==null&&(n=Gl(f)),n=new a(u,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=gi,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=u,n.state=t.memoizedState,n.refs={},Kf(t),f=a.contextType,n.context=typeof f=="object"&&f!==null?Gl(f):eu,n.state=t.memoizedState,f=a.getDerivedStateFromProps,typeof f=="function"&&(hi(t,a,f,u),n.state=t.memoizedState),typeof a.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(f=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),f!==n.state&&gi.enqueueReplaceState(n,n.state,null),le(t,u,n,e),Pu(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!0}else if(l===null){n=t.stateNode;var i=t.memoizedProps,c=Qa(a,i);n.props=c;var v=n.context,r=a.contextType;f=eu,typeof r=="object"&&r!==null&&(f=Gl(r));var z=a.getDerivedStateFromProps;r=typeof z=="function"||typeof n.getSnapshotBeforeUpdate=="function",i=t.pendingProps!==i,r||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(i||v!==f)&&Cd(t,n,u,f),ia=!1;var m=t.memoizedState;n.state=m,le(t,u,n,e),Pu(),v=t.memoizedState,i||m!==v||ia?(typeof z=="function"&&(hi(t,a,z,u),v=t.memoizedState),(c=ia||Bd(t,a,c,u,m,v,f))?(r||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=u,t.memoizedState=v),n.props=u,n.state=v,n.context=f,u=c):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),u=!1)}else{n=t.stateNode,Jf(l,t),f=t.memoizedProps,r=Qa(a,f),n.props=r,z=t.pendingProps,m=n.context,v=a.contextType,c=eu,typeof v=="object"&&v!==null&&(c=Gl(v)),i=a.getDerivedStateFromProps,(v=typeof i=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f!==z||m!==c)&&Cd(t,n,u,c),ia=!1,m=t.memoizedState,n.state=m,le(t,u,n,e),Pu();var g=t.memoizedState;f!==z||m!==g||ia||l!==null&&l.dependencies!==null&&Je(l.dependencies)?(typeof i=="function"&&(hi(t,a,i,u),g=t.memoizedState),(r=ia||Bd(t,a,r,u,m,g,c)||l!==null&&l.dependencies!==null&&Je(l.dependencies))?(v||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(u,g,c),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(u,g,c)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),t.memoizedProps=u,t.memoizedState=g),n.props=u,n.state=g,n.context=c,u=r):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&m===l.memoizedState||(t.flags|=1024),u=!1)}return n=u,yn(l,t),u=(t.flags&128)!==0,n||u?(n=t.stateNode,a=u&&typeof a.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&u?(t.child=Ga(t,l.child,null,e),t.child=Ga(t,null,a,e)):Xl(l,t,a,e),t.memoizedState=n.state,l=t.child):l=Lt(l,t,e),l}function kd(l,t,a,u){return Na(),t.flags|=256,Xl(l,t,a,u),t.child}var zi={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Ti(l){return{baseLanes:l,cachePool:Gs()}}function Ei(l,t,a){return l=l!==null?l.childLanes&~a:0,t&&(l|=mt),l}function Fd(l,t,a){var u=t.pendingProps,e=!1,n=(t.flags&128)!==0,f;if((f=n)||(f=l!==null&&l.memoizedState===null?!1:(pl.current&2)!==0),f&&(e=!0,t.flags&=-129),f=(t.flags&32)!==0,t.flags&=-33,l===null){if(k){if(e?da(t):oa(),(l=ml)?(l=no(l,At),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:ua!==null?{id:Ht,overflow:Rt}:null,retryLane:536870912,hydrationErrors:null},a=xs(l),a.return=t,t.child=a,Yl=t,ml=null)):l=null,l===null)throw na(t);return ec(l)?t.lanes=32:t.lanes=536870912,null}var i=u.children;return u=u.fallback,e?(oa(),e=t.mode,i=vn({mode:"hidden",children:i},e),u=Ra(u,e,a,null),i.return=t,u.return=t,i.sibling=u,t.child=i,u=t.child,u.memoizedState=Ti(a),u.childLanes=Ei(l,f,a),t.memoizedState=zi,ne(null,u)):(da(t),Ai(t,i))}var c=l.memoizedState;if(c!==null&&(i=c.dehydrated,i!==null)){if(n)t.flags&256?(da(t),t.flags&=-257,t=pi(l,t,a)):t.memoizedState!==null?(oa(),t.child=l.child,t.flags|=128,t=null):(oa(),i=u.fallback,e=t.mode,u=vn({mode:"visible",children:u.children},e),i=Ra(i,e,a,null),i.flags|=2,u.return=t,i.return=t,u.sibling=i,t.child=u,Ga(t,l.child,null,a),u=t.child,u.memoizedState=Ti(a),u.childLanes=Ei(l,f,a),t.memoizedState=zi,t=ne(null,u));else if(da(t),ec(i)){if(f=i.nextSibling&&i.nextSibling.dataset,f)var v=f.dgst;f=v,u=Error(h(419)),u.stack="",u.digest=f,wu({value:u,source:null,stack:null}),t=pi(l,t,a)}else if(Dl||cu(l,t,a,!1),f=(a&l.childLanes)!==0,Dl||f){if(f=yl,f!==null&&(u=qc(f,a),u!==0&&u!==c.retryLane))throw c.retryLane=u,Ha(l,u),ut(f,l,u),ri;uc(i)||En(),t=pi(l,t,a)}else uc(i)?(t.flags|=192,t.child=l.child,t=null):(l=c.treeContext,ml=_t(i.nextSibling),Yl=t,k=!0,ea=null,At=!1,l!==null&&Ns(t,l),t=Ai(t,u.children),t.flags|=4096);return t}return e?(oa(),i=u.fallback,e=t.mode,c=l.child,v=c.sibling,u=Yt(c,{mode:"hidden",children:u.children}),u.subtreeFlags=c.subtreeFlags&65011712,v!==null?i=Yt(v,i):(i=Ra(i,e,a,null),i.flags|=2),i.return=t,u.return=t,u.sibling=i,t.child=u,ne(null,u),u=t.child,i=l.child.memoizedState,i===null?i=Ti(a):(e=i.cachePool,e!==null?(c=Ol._currentValue,e=e.parent!==c?{parent:c,pool:c}:e):e=Gs(),i={baseLanes:i.baseLanes|a,cachePool:e}),u.memoizedState=i,u.childLanes=Ei(l,f,a),t.memoizedState=zi,ne(l.child,u)):(da(t),a=l.child,l=a.sibling,a=Yt(a,{mode:"visible",children:u.children}),a.return=t,a.sibling=null,l!==null&&(f=t.deletions,f===null?(t.deletions=[l],t.flags|=16):f.push(l)),t.child=a,t.memoizedState=null,a)}function Ai(l,t){return t=vn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function vn(l,t){return l=dt(22,l,null,t),l.lanes=0,l}function pi(l,t,a){return Ga(t,l.child,null,a),l=Ai(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function Id(l,t,a){l.lanes|=t;var u=l.alternate;u!==null&&(u.lanes|=t),Gf(l.return,t,a)}function _i(l,t,a,u,e,n){var f=l.memoizedState;f===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:u,tail:a,tailMode:e,treeForkCount:n}:(f.isBackwards=t,f.rendering=null,f.renderingStartTime=0,f.last=u,f.tail=a,f.tailMode=e,f.treeForkCount=n)}function Pd(l,t,a){var u=t.pendingProps,e=u.revealOrder,n=u.tail;u=u.children;var f=pl.current,i=(f&2)!==0;if(i?(f=f&1|2,t.flags|=128):f&=1,_(pl,f),Xl(l,t,u,a),u=k?Ju:0,!i&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&Id(l,a,t);else if(l.tag===19)Id(l,a,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(e){case"forwards":for(a=t.child,e=null;a!==null;)l=a.alternate,l!==null&&ln(l)===null&&(e=a),a=a.sibling;a=e,a===null?(e=t.child,t.child=null):(e=a.sibling,a.sibling=null),_i(t,!1,e,a,n,u);break;case"backwards":case"unstable_legacy-backwards":for(a=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&ln(l)===null){t.child=e;break}l=e.sibling,e.sibling=a,a=e,e=l}_i(t,!0,a,null,n,u);break;case"together":_i(t,!1,null,null,void 0,u);break;default:t.memoizedState=null}return t.child}function Lt(l,t,a){if(l!==null&&(t.dependencies=l.dependencies),ma|=t.lanes,(a&t.childLanes)===0)if(l!==null){if(cu(l,t,a,!1),(a&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(h(153));if(t.child!==null){for(l=t.child,a=Yt(l,l.pendingProps),t.child=a,a.return=t;l.sibling!==null;)l=l.sibling,a=a.sibling=Yt(l,l.pendingProps),a.return=t;a.sibling=null}return t.child}function Oi(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Je(l)))}function vv(l,t,a){switch(t.tag){case 3:Wl(t,t.stateNode.containerInfo),fa(t,Ol,l.memoizedState.cache),Na();break;case 27:case 5:Hu(t);break;case 4:Wl(t,t.stateNode.containerInfo);break;case 10:fa(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,Ff(t),null;break;case 13:var u=t.memoizedState;if(u!==null)return u.dehydrated!==null?(da(t),t.flags|=128,null):(a&t.child.childLanes)!==0?Fd(l,t,a):(da(t),l=Lt(l,t,a),l!==null?l.sibling:null);da(t);break;case 19:var e=(l.flags&128)!==0;if(u=(a&t.childLanes)!==0,u||(cu(l,t,a,!1),u=(a&t.childLanes)!==0),e){if(u)return Pd(l,t,a);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(pl,pl.current),u)break;return null;case 22:return t.lanes=0,Kd(l,t,a,t.pendingProps);case 24:fa(t,Ol,l.memoizedState.cache)}return Lt(l,t,a)}function l0(l,t,a){if(l!==null)if(l.memoizedProps!==t.pendingProps)Dl=!0;else{if(!Oi(l,a)&&(t.flags&128)===0)return Dl=!1,vv(l,t,a);Dl=(l.flags&131072)!==0}else Dl=!1,k&&(t.flags&1048576)!==0&&Rs(t,Ju,t.index);switch(t.lanes=0,t.tag){case 16:l:{var u=t.pendingProps;if(l=qa(t.elementType),t.type=l,typeof l=="function")Hf(l)?(u=Qa(l,u),t.tag=1,t=$d(null,t,l,u,a)):(t.tag=0,t=bi(null,t,l,u,a));else{if(l!=null){var e=l.$$typeof;if(e===El){t.tag=11,t=Zd(null,t,l,u,a);break l}else if(e===V){t.tag=14,t=Vd(null,t,l,u,a);break l}}throw t=O(l)||l,Error(h(306,t,""))}}return t;case 0:return bi(l,t,t.type,t.pendingProps,a);case 1:return u=t.type,e=Qa(u,t.pendingProps),$d(l,t,u,e,a);case 3:l:{if(Wl(t,t.stateNode.containerInfo),l===null)throw Error(h(387));u=t.pendingProps;var n=t.memoizedState;e=n.element,Jf(l,t),le(t,u,null,a);var f=t.memoizedState;if(u=f.cache,fa(t,Ol,u),u!==n.cache&&Xf(t,[Ol],a,!0),Pu(),u=f.element,n.isDehydrated)if(n={element:u,isDehydrated:!1,cache:f.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=kd(l,t,u,a);break l}else if(u!==e){e=zt(Error(h(424)),t),wu(e),t=kd(l,t,u,a);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(ml=_t(l.firstChild),Yl=t,k=!0,ea=null,At=!0,a=Ks(t,null,u,a),t.child=a;a;)a.flags=a.flags&-3|4096,a=a.sibling}else{if(Na(),u===e){t=Lt(l,t,a);break l}Xl(l,t,u,a)}t=t.child}return t;case 26:return yn(l,t),l===null?(a=yo(t.type,null,t.pendingProps,null))?t.memoizedState=a:k||(a=t.type,l=t.pendingProps,u=Un(L.current).createElement(a),u[ql]=t,u[Fl]=l,Ql(u,a,l),Nl(u),t.stateNode=u):t.memoizedState=yo(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return Hu(t),l===null&&k&&(u=t.stateNode=co(t.type,t.pendingProps,L.current),Yl=t,At=!0,e=ml,ba(t.type)?(nc=e,ml=_t(u.firstChild)):ml=e),Xl(l,t,t.pendingProps.children,a),yn(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&k&&((e=u=ml)&&(u=Vv(u,t.type,t.pendingProps,At),u!==null?(t.stateNode=u,Yl=t,ml=_t(u.firstChild),At=!1,e=!0):e=!1),e||na(t)),Hu(t),e=t.type,n=t.pendingProps,f=l!==null?l.memoizedProps:null,u=n.children,lc(e,n)?u=null:f!==null&&lc(e,f)&&(t.flags|=32),t.memoizedState!==null&&(e=Pf(l,t,ev,null,null,a),ze._currentValue=e),yn(l,t),Xl(l,t,u,a),t.child;case 6:return l===null&&k&&((l=a=ml)&&(a=Lv(a,t.pendingProps,At),a!==null?(t.stateNode=a,Yl=t,ml=null,l=!0):l=!1),l||na(t)),null;case 13:return Fd(l,t,a);case 4:return Wl(t,t.stateNode.containerInfo),u=t.pendingProps,l===null?t.child=Ga(t,null,u,a):Xl(l,t,u,a),t.child;case 11:return Zd(l,t,t.type,t.pendingProps,a);case 7:return Xl(l,t,t.pendingProps,a),t.child;case 8:return Xl(l,t,t.pendingProps.children,a),t.child;case 12:return Xl(l,t,t.pendingProps.children,a),t.child;case 10:return u=t.pendingProps,fa(t,t.type,u.value),Xl(l,t,u.children,a),t.child;case 9:return e=t.type._context,u=t.pendingProps.children,Ca(t),e=Gl(e),u=u(e),t.flags|=1,Xl(l,t,u,a),t.child;case 14:return Vd(l,t,t.type,t.pendingProps,a);case 15:return Ld(l,t,t.type,t.pendingProps,a);case 19:return Pd(l,t,a);case 31:return yv(l,t,a);case 22:return Kd(l,t,a,t.pendingProps);case 24:return Ca(t),u=Gl(Ol),l===null?(e=Vf(),e===null&&(e=yl,n=Qf(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=a),e=n),t.memoizedState={parent:u,cache:e},Kf(t),fa(t,Ol,e)):((l.lanes&a)!==0&&(Jf(l,t),le(t,null,null,a),Pu()),e=l.memoizedState,n=t.memoizedState,e.parent!==u?(e={parent:u,cache:u},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),fa(t,Ol,u)):(u=n.cache,fa(t,Ol,u),u!==e.cache&&Xf(t,[Ol],a,!0))),Xl(l,t,t.pendingProps.children,a),t.child;case 29:throw t.pendingProps}throw Error(h(156,t.tag))}function Kt(l){l.flags|=4}function Mi(l,t,a,u,e){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(e&335544128)===e)if(l.stateNode.complete)l.flags|=8192;else if(M0())l.flags|=8192;else throw Ya=ke,Lf}else l.flags&=-16777217}function t0(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!So(t))if(M0())l.flags|=8192;else throw Ya=ke,Lf}function mn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Bc():536870912,l.lanes|=t,zu|=t)}function fe(l,t){if(!k)switch(l.tailMode){case"hidden":t=l.tail;for(var a=null;t!==null;)t.alternate!==null&&(a=t),t=t.sibling;a===null?l.tail=null:a.sibling=null;break;case"collapsed":a=l.tail;for(var u=null;a!==null;)a.alternate!==null&&(u=a),a=a.sibling;u===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:u.sibling=null}}function hl(l){var t=l.alternate!==null&&l.alternate.child===l.child,a=0,u=0;if(t)for(var e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags&65011712,u|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)a|=e.lanes|e.childLanes,u|=e.subtreeFlags,u|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=u,l.childLanes=a,t}function mv(l,t,a){var u=t.pendingProps;switch(Cf(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return hl(t),null;case 1:return hl(t),null;case 3:return a=t.stateNode,u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),Qt(Ol),Al(),a.pendingContext&&(a.context=a.pendingContext,a.pendingContext=null),(l===null||l.child===null)&&(iu(t)?Kt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,qf())),hl(t),null;case 26:var e=t.type,n=t.memoizedState;return l===null?(Kt(t),n!==null?(hl(t),t0(t,n)):(hl(t),Mi(t,e,null,u,a))):n?n!==l.memoizedState?(Kt(t),hl(t),t0(t,n)):(hl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==u&&Kt(t),hl(t),Mi(t,e,l,u,a)),null;case 27:if(pe(t),a=L.current,e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Kt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return hl(t),null}l=D.current,iu(t)?Bs(t):(l=co(e,u,a),t.stateNode=l,Kt(t))}return hl(t),null;case 5:if(pe(t),e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==u&&Kt(t);else{if(!u){if(t.stateNode===null)throw Error(h(166));return hl(t),null}if(n=D.current,iu(t))Bs(t);else{var f=Un(L.current);switch(n){case 1:n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case 2:n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;default:switch(e){case"svg":n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case"math":n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;case"script":n=f.createElement("div"),n.innerHTML="<script><\/script>",n=n.removeChild(n.firstChild);break;case"select":n=typeof u.is=="string"?f.createElement("select",{is:u.is}):f.createElement("select"),u.multiple?n.multiple=!0:u.size&&(n.size=u.size);break;default:n=typeof u.is=="string"?f.createElement(e,{is:u.is}):f.createElement(e)}}n[ql]=t,n[Fl]=u;l:for(f=t.child;f!==null;){if(f.tag===5||f.tag===6)n.appendChild(f.stateNode);else if(f.tag!==4&&f.tag!==27&&f.child!==null){f.child.return=f,f=f.child;continue}if(f===t)break l;for(;f.sibling===null;){if(f.return===null||f.return===t)break l;f=f.return}f.sibling.return=f.return,f=f.sibling}t.stateNode=n;l:switch(Ql(n,e,u),e){case"button":case"input":case"select":case"textarea":u=!!u.autoFocus;break l;case"img":u=!0;break l;default:u=!1}u&&Kt(t)}}return hl(t),Mi(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,a),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==u&&Kt(t);else{if(typeof u!="string"&&t.stateNode===null)throw Error(h(166));if(l=L.current,iu(t)){if(l=t.stateNode,a=t.memoizedProps,u=null,e=Yl,e!==null)switch(e.tag){case 27:case 5:u=e.memoizedProps}l[ql]=t,l=!!(l.nodeValue===a||u!==null&&u.suppressHydrationWarning===!0||F0(l.nodeValue,a)),l||na(t,!0)}else l=Un(l).createTextNode(u),l[ql]=t,t.stateNode=l}return hl(t),null;case 31:if(a=t.memoizedState,l===null||l.memoizedState!==null){if(u=iu(t),a!==null){if(l===null){if(!u)throw Error(h(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(h(557));l[ql]=t}else Na(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;hl(t),l=!1}else a=qf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=a),l=!0;if(!l)return t.flags&256?(yt(t),t):(yt(t),null);if((t.flags&128)!==0)throw Error(h(558))}return hl(t),null;case 13:if(u=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=iu(t),u!==null&&u.dehydrated!==null){if(l===null){if(!e)throw Error(h(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(h(317));e[ql]=t}else Na(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;hl(t),e=!1}else e=qf(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(yt(t),t):(yt(t),null)}return yt(t),(t.flags&128)!==0?(t.lanes=a,t):(a=u!==null,l=l!==null&&l.memoizedState!==null,a&&(u=t.child,e=null,u.alternate!==null&&u.alternate.memoizedState!==null&&u.alternate.memoizedState.cachePool!==null&&(e=u.alternate.memoizedState.cachePool.pool),n=null,u.memoizedState!==null&&u.memoizedState.cachePool!==null&&(n=u.memoizedState.cachePool.pool),n!==e&&(u.flags|=2048)),a!==l&&a&&(t.child.flags|=8192),mn(t,t.updateQueue),hl(t),null);case 4:return Al(),l===null&&$i(t.stateNode.containerInfo),hl(t),null;case 10:return Qt(t.type),hl(t),null;case 19:if(T(pl),u=t.memoizedState,u===null)return hl(t),null;if(e=(t.flags&128)!==0,n=u.rendering,n===null)if(e)fe(u,!1);else{if(zl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=ln(l),n!==null){for(t.flags|=128,fe(u,!1),l=n.updateQueue,t.updateQueue=l,mn(t,l),t.subtreeFlags=0,l=a,a=t.child;a!==null;)Us(a,l),a=a.sibling;return _(pl,pl.current&1|2),k&&Gt(t,u.treeForkCount),t.child}l=l.sibling}u.tail!==null&&ft()>bn&&(t.flags|=128,e=!0,fe(u,!1),t.lanes=4194304)}else{if(!e)if(l=ln(n),l!==null){if(t.flags|=128,e=!0,l=l.updateQueue,t.updateQueue=l,mn(t,l),fe(u,!0),u.tail===null&&u.tailMode==="hidden"&&!n.alternate&&!k)return hl(t),null}else 2*ft()-u.renderingStartTime>bn&&a!==536870912&&(t.flags|=128,e=!0,fe(u,!1),t.lanes=4194304);u.isBackwards?(n.sibling=t.child,t.child=n):(l=u.last,l!==null?l.sibling=n:t.child=n,u.last=n)}return u.tail!==null?(l=u.tail,u.rendering=l,u.tail=l.sibling,u.renderingStartTime=ft(),l.sibling=null,a=pl.current,_(pl,e?a&1|2:a&1),k&&Gt(t,u.treeForkCount),l):(hl(t),null);case 22:case 23:return yt(t),kf(),u=t.memoizedState!==null,l!==null?l.memoizedState!==null!==u&&(t.flags|=8192):u&&(t.flags|=8192),u?(a&536870912)!==0&&(t.flags&128)===0&&(hl(t),t.subtreeFlags&6&&(t.flags|=8192)):hl(t),a=t.updateQueue,a!==null&&mn(t,a.retryQueue),a=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),u=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(u=t.memoizedState.cachePool.pool),u!==a&&(t.flags|=2048),l!==null&&T(ja),null;case 24:return a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Qt(Ol),hl(t),null;case 25:return null;case 30:return null}throw Error(h(156,t.tag))}function hv(l,t){switch(Cf(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Qt(Ol),Al(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return pe(t),null;case 31:if(t.memoizedState!==null){if(yt(t),t.alternate===null)throw Error(h(340));Na()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(yt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(h(340));Na()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return T(pl),null;case 4:return Al(),null;case 10:return Qt(t.type),null;case 22:case 23:return yt(t),kf(),l!==null&&T(ja),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Qt(Ol),null;case 25:return null;default:return null}}function a0(l,t){switch(Cf(t),t.tag){case 3:Qt(Ol),Al();break;case 26:case 27:case 5:pe(t);break;case 4:Al();break;case 31:t.memoizedState!==null&&yt(t);break;case 13:yt(t);break;case 19:T(pl);break;case 10:Qt(t.type);break;case 22:case 23:yt(t),kf(),l!==null&&T(ja);break;case 24:Qt(Ol)}}function ie(l,t){try{var a=t.updateQueue,u=a!==null?a.lastEffect:null;if(u!==null){var e=u.next;a=e;do{if((a.tag&l)===l){u=void 0;var n=a.create,f=a.inst;u=n(),f.destroy=u}a=a.next}while(a!==e)}}catch(i){fl(t,t.return,i)}}function ya(l,t,a){try{var u=t.updateQueue,e=u!==null?u.lastEffect:null;if(e!==null){var n=e.next;u=n;do{if((u.tag&l)===l){var f=u.inst,i=f.destroy;if(i!==void 0){f.destroy=void 0,e=t;var c=a,v=i;try{v()}catch(r){fl(e,c,r)}}}u=u.next}while(u!==n)}}catch(r){fl(t,t.return,r)}}function u0(l){var t=l.updateQueue;if(t!==null){var a=l.stateNode;try{ws(t,a)}catch(u){fl(l,l.return,u)}}}function e0(l,t,a){a.props=Qa(l.type,l.memoizedProps),a.state=l.memoizedState;try{a.componentWillUnmount()}catch(u){fl(l,t,u)}}function ce(l,t){try{var a=l.ref;if(a!==null){switch(l.tag){case 26:case 27:case 5:var u=l.stateNode;break;case 30:u=l.stateNode;break;default:u=l.stateNode}typeof a=="function"?l.refCleanup=a(u):a.current=u}}catch(e){fl(l,t,e)}}function Nt(l,t){var a=l.ref,u=l.refCleanup;if(a!==null)if(typeof u=="function")try{u()}catch(e){fl(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof a=="function")try{a(null)}catch(e){fl(l,t,e)}else a.current=null}function n0(l){var t=l.type,a=l.memoizedProps,u=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":a.autoFocus&&u.focus();break l;case"img":a.src?u.src=a.src:a.srcSet&&(u.srcset=a.srcSet)}}catch(e){fl(l,l.return,e)}}function Di(l,t,a){try{var u=l.stateNode;qv(u,l.type,a,t),u[Fl]=t}catch(e){fl(l,l.return,e)}}function f0(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&ba(l.type)||l.tag===4}function Ui(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||f0(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&ba(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function xi(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?(a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a).insertBefore(l,t):(t=a.nodeType===9?a.body:a.nodeName==="HTML"?a.ownerDocument.body:a,t.appendChild(l),a=a._reactRootContainer,a!=null||t.onclick!==null||(t.onclick=jt));else if(u!==4&&(u===27&&ba(l.type)&&(a=l.stateNode,t=null),l=l.child,l!==null))for(xi(l,t,a),l=l.sibling;l!==null;)xi(l,t,a),l=l.sibling}function hn(l,t,a){var u=l.tag;if(u===5||u===6)l=l.stateNode,t?a.insertBefore(l,t):a.appendChild(l);else if(u!==4&&(u===27&&ba(l.type)&&(a=l.stateNode),l=l.child,l!==null))for(hn(l,t,a),l=l.sibling;l!==null;)hn(l,t,a),l=l.sibling}function i0(l){var t=l.stateNode,a=l.memoizedProps;try{for(var u=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);Ql(t,u,a),t[ql]=l,t[Fl]=a}catch(n){fl(l,l.return,n)}}var Jt=!1,Ul=!1,Hi=!1,c0=typeof WeakSet=="function"?WeakSet:Set,Bl=null;function gv(l,t){if(l=l.containerInfo,Ii=jn,l=zs(l),pf(l)){if("selectionStart"in l)var a={start:l.selectionStart,end:l.selectionEnd};else l:{a=(a=l.ownerDocument)&&a.defaultView||window;var u=a.getSelection&&a.getSelection();if(u&&u.rangeCount!==0){a=u.anchorNode;var e=u.anchorOffset,n=u.focusNode;u=u.focusOffset;try{a.nodeType,n.nodeType}catch{a=null;break l}var f=0,i=-1,c=-1,v=0,r=0,z=l,m=null;t:for(;;){for(var g;z!==a||e!==0&&z.nodeType!==3||(i=f+e),z!==n||u!==0&&z.nodeType!==3||(c=f+u),z.nodeType===3&&(f+=z.nodeValue.length),(g=z.firstChild)!==null;)m=z,z=g;for(;;){if(z===l)break t;if(m===a&&++v===e&&(i=f),m===n&&++r===u&&(c=f),(g=z.nextSibling)!==null)break;z=m,m=z.parentNode}z=g}a=i===-1||c===-1?null:{start:i,end:c}}else a=null}a=a||{start:0,end:0}}else a=null;for(Pi={focusedElem:l,selectionRange:a},jn=!1,Bl=t;Bl!==null;)if(t=Bl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Bl=l;else for(;Bl!==null;){switch(t=Bl,n=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(a=0;a<l.length;a++)e=l[a],e.ref.impl=e.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,a=t,e=n.memoizedProps,n=n.memoizedState,u=a.stateNode;try{var M=Qa(a.type,e);l=u.getSnapshotBeforeUpdate(M,n),u.__reactInternalSnapshotBeforeUpdate=l}catch(j){fl(a,a.return,j)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,a=l.nodeType,a===9)ac(l);else if(a===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":ac(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(h(163))}if(l=t.sibling,l!==null){l.return=t.return,Bl=l;break}Bl=t.return}}function s0(l,t,a){var u=a.flags;switch(a.tag){case 0:case 11:case 15:Wt(l,a),u&4&&ie(5,a);break;case 1:if(Wt(l,a),u&4)if(l=a.stateNode,t===null)try{l.componentDidMount()}catch(f){fl(a,a.return,f)}else{var e=Qa(a.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(f){fl(a,a.return,f)}}u&64&&u0(a),u&512&&ce(a,a.return);break;case 3:if(Wt(l,a),u&64&&(l=a.updateQueue,l!==null)){if(t=null,a.child!==null)switch(a.child.tag){case 27:case 5:t=a.child.stateNode;break;case 1:t=a.child.stateNode}try{ws(l,t)}catch(f){fl(a,a.return,f)}}break;case 27:t===null&&u&4&&i0(a);case 26:case 5:Wt(l,a),t===null&&u&4&&n0(a),u&512&&ce(a,a.return);break;case 12:Wt(l,a);break;case 31:Wt(l,a),u&4&&y0(l,a);break;case 13:Wt(l,a),u&4&&v0(l,a),u&64&&(l=a.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(a=_v.bind(null,a),Kv(l,a))));break;case 22:if(u=a.memoizedState!==null||Jt,!u){t=t!==null&&t.memoizedState!==null||Ul,e=Jt;var n=Ul;Jt=u,(Ul=t)&&!n?$t(l,a,(a.subtreeFlags&8772)!==0):Wt(l,a),Jt=e,Ul=n}break;case 30:break;default:Wt(l,a)}}function d0(l){var t=l.alternate;t!==null&&(l.alternate=null,d0(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&ff(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var gl=null,Pl=!1;function wt(l,t,a){for(a=a.child;a!==null;)o0(l,t,a),a=a.sibling}function o0(l,t,a){if(it&&typeof it.onCommitFiberUnmount=="function")try{it.onCommitFiberUnmount(Ru,a)}catch{}switch(a.tag){case 26:Ul||Nt(a,t),wt(l,t,a),a.memoizedState?a.memoizedState.count--:a.stateNode&&(a=a.stateNode,a.parentNode.removeChild(a));break;case 27:Ul||Nt(a,t);var u=gl,e=Pl;ba(a.type)&&(gl=a.stateNode,Pl=!1),wt(l,t,a),Se(a.stateNode),gl=u,Pl=e;break;case 5:Ul||Nt(a,t);case 6:if(u=gl,e=Pl,gl=null,wt(l,t,a),gl=u,Pl=e,gl!==null)if(Pl)try{(gl.nodeType===9?gl.body:gl.nodeName==="HTML"?gl.ownerDocument.body:gl).removeChild(a.stateNode)}catch(n){fl(a,t,n)}else try{gl.removeChild(a.stateNode)}catch(n){fl(a,t,n)}break;case 18:gl!==null&&(Pl?(l=gl,uo(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,a.stateNode),Du(l)):uo(gl,a.stateNode));break;case 4:u=gl,e=Pl,gl=a.stateNode.containerInfo,Pl=!0,wt(l,t,a),gl=u,Pl=e;break;case 0:case 11:case 14:case 15:ya(2,a,t),Ul||ya(4,a,t),wt(l,t,a);break;case 1:Ul||(Nt(a,t),u=a.stateNode,typeof u.componentWillUnmount=="function"&&e0(a,t,u)),wt(l,t,a);break;case 21:wt(l,t,a);break;case 22:Ul=(u=Ul)||a.memoizedState!==null,wt(l,t,a),Ul=u;break;default:wt(l,t,a)}}function y0(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{Du(l)}catch(a){fl(t,t.return,a)}}}function v0(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Du(l)}catch(a){fl(t,t.return,a)}}function Sv(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new c0),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new c0),t;default:throw Error(h(435,l.tag))}}function gn(l,t){var a=Sv(l);t.forEach(function(u){if(!a.has(u)){a.add(u);var e=Ov.bind(null,l,u);u.then(e,e)}})}function lt(l,t){var a=t.deletions;if(a!==null)for(var u=0;u<a.length;u++){var e=a[u],n=l,f=t,i=f;l:for(;i!==null;){switch(i.tag){case 27:if(ba(i.type)){gl=i.stateNode,Pl=!1;break l}break;case 5:gl=i.stateNode,Pl=!1;break l;case 3:case 4:gl=i.stateNode.containerInfo,Pl=!0;break l}i=i.return}if(gl===null)throw Error(h(160));o0(n,f,e),gl=null,Pl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)m0(t,l),t=t.sibling}var Dt=null;function m0(l,t){var a=l.alternate,u=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:lt(t,l),tt(l),u&4&&(ya(3,l,l.return),ie(3,l),ya(5,l,l.return));break;case 1:lt(t,l),tt(l),u&512&&(Ul||a===null||Nt(a,a.return)),u&64&&Jt&&(l=l.updateQueue,l!==null&&(u=l.callbacks,u!==null&&(a=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=a===null?u:a.concat(u))));break;case 26:var e=Dt;if(lt(t,l),tt(l),u&512&&(Ul||a===null||Nt(a,a.return)),u&4){var n=a!==null?a.memoizedState:null;if(u=l.memoizedState,a===null)if(u===null)if(l.stateNode===null){l:{u=l.type,a=l.memoizedProps,e=e.ownerDocument||e;t:switch(u){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Cu]||n[ql]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(u),e.head.insertBefore(n,e.querySelector("head > title"))),Ql(n,u,a),n[ql]=l,Nl(n),u=n;break l;case"link":var f=ho("link","href",e).get(u+(a.href||""));if(f){for(var i=0;i<f.length;i++)if(n=f[i],n.getAttribute("href")===(a.href==null||a.href===""?null:a.href)&&n.getAttribute("rel")===(a.rel==null?null:a.rel)&&n.getAttribute("title")===(a.title==null?null:a.title)&&n.getAttribute("crossorigin")===(a.crossOrigin==null?null:a.crossOrigin)){f.splice(i,1);break t}}n=e.createElement(u),Ql(n,u,a),e.head.appendChild(n);break;case"meta":if(f=ho("meta","content",e).get(u+(a.content||""))){for(i=0;i<f.length;i++)if(n=f[i],n.getAttribute("content")===(a.content==null?null:""+a.content)&&n.getAttribute("name")===(a.name==null?null:a.name)&&n.getAttribute("property")===(a.property==null?null:a.property)&&n.getAttribute("http-equiv")===(a.httpEquiv==null?null:a.httpEquiv)&&n.getAttribute("charset")===(a.charSet==null?null:a.charSet)){f.splice(i,1);break t}}n=e.createElement(u),Ql(n,u,a),e.head.appendChild(n);break;default:throw Error(h(468,u))}n[ql]=l,Nl(n),u=n}l.stateNode=u}else go(e,l.type,l.stateNode);else l.stateNode=mo(e,u,l.memoizedProps);else n!==u?(n===null?a.stateNode!==null&&(a=a.stateNode,a.parentNode.removeChild(a)):n.count--,u===null?go(e,l.type,l.stateNode):mo(e,u,l.memoizedProps)):u===null&&l.stateNode!==null&&Di(l,l.memoizedProps,a.memoizedProps)}break;case 27:lt(t,l),tt(l),u&512&&(Ul||a===null||Nt(a,a.return)),a!==null&&u&4&&Di(l,l.memoizedProps,a.memoizedProps);break;case 5:if(lt(t,l),tt(l),u&512&&(Ul||a===null||Nt(a,a.return)),l.flags&32){e=l.stateNode;try{Fa(e,"")}catch(M){fl(l,l.return,M)}}u&4&&l.stateNode!=null&&(e=l.memoizedProps,Di(l,e,a!==null?a.memoizedProps:e)),u&1024&&(Hi=!0);break;case 6:if(lt(t,l),tt(l),u&4){if(l.stateNode===null)throw Error(h(162));u=l.memoizedProps,a=l.stateNode;try{a.nodeValue=u}catch(M){fl(l,l.return,M)}}break;case 3:if(Rn=null,e=Dt,Dt=xn(t.containerInfo),lt(t,l),Dt=e,tt(l),u&4&&a!==null&&a.memoizedState.isDehydrated)try{Du(t.containerInfo)}catch(M){fl(l,l.return,M)}Hi&&(Hi=!1,h0(l));break;case 4:u=Dt,Dt=xn(l.stateNode.containerInfo),lt(t,l),tt(l),Dt=u;break;case 12:lt(t,l),tt(l);break;case 31:lt(t,l),tt(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 13:lt(t,l),tt(l),l.child.flags&8192&&l.memoizedState!==null!=(a!==null&&a.memoizedState!==null)&&(rn=ft()),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 22:e=l.memoizedState!==null;var c=a!==null&&a.memoizedState!==null,v=Jt,r=Ul;if(Jt=v||e,Ul=r||c,lt(t,l),Ul=r,Jt=v,tt(l),u&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(a===null||c||Jt||Ul||Za(l)),a=null,t=l;;){if(t.tag===5||t.tag===26){if(a===null){c=a=t;try{if(n=c.stateNode,e)f=n.style,typeof f.setProperty=="function"?f.setProperty("display","none","important"):f.display="none";else{i=c.stateNode;var z=c.memoizedProps.style,m=z!=null&&z.hasOwnProperty("display")?z.display:null;i.style.display=m==null||typeof m=="boolean"?"":(""+m).trim()}}catch(M){fl(c,c.return,M)}}}else if(t.tag===6){if(a===null){c=t;try{c.stateNode.nodeValue=e?"":c.memoizedProps}catch(M){fl(c,c.return,M)}}}else if(t.tag===18){if(a===null){c=t;try{var g=c.stateNode;e?eo(g,!0):eo(c.stateNode,!1)}catch(M){fl(c,c.return,M)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;a===t&&(a=null),t=t.return}a===t&&(a=null),t.sibling.return=t.return,t=t.sibling}u&4&&(u=l.updateQueue,u!==null&&(a=u.retryQueue,a!==null&&(u.retryQueue=null,gn(l,a))));break;case 19:lt(t,l),tt(l),u&4&&(u=l.updateQueue,u!==null&&(l.updateQueue=null,gn(l,u)));break;case 30:break;case 21:break;default:lt(t,l),tt(l)}}function tt(l){var t=l.flags;if(t&2){try{for(var a,u=l.return;u!==null;){if(f0(u)){a=u;break}u=u.return}if(a==null)throw Error(h(160));switch(a.tag){case 27:var e=a.stateNode,n=Ui(l);hn(l,n,e);break;case 5:var f=a.stateNode;a.flags&32&&(Fa(f,""),a.flags&=-33);var i=Ui(l);hn(l,i,f);break;case 3:case 4:var c=a.stateNode.containerInfo,v=Ui(l);xi(l,v,c);break;default:throw Error(h(161))}}catch(r){fl(l,l.return,r)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function h0(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;h0(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function Wt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)s0(l,t.alternate,t),t=t.sibling}function Za(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:ya(4,t,t.return),Za(t);break;case 1:Nt(t,t.return);var a=t.stateNode;typeof a.componentWillUnmount=="function"&&e0(t,t.return,a),Za(t);break;case 27:Se(t.stateNode);case 26:case 5:Nt(t,t.return),Za(t);break;case 22:t.memoizedState===null&&Za(t);break;case 30:Za(t);break;default:Za(t)}l=l.sibling}}function $t(l,t,a){for(a=a&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var u=t.alternate,e=l,n=t,f=n.flags;switch(n.tag){case 0:case 11:case 15:$t(e,n,a),ie(4,n);break;case 1:if($t(e,n,a),u=n,e=u.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(v){fl(u,u.return,v)}if(u=n,e=u.updateQueue,e!==null){var i=u.stateNode;try{var c=e.shared.hiddenCallbacks;if(c!==null)for(e.shared.hiddenCallbacks=null,e=0;e<c.length;e++)Js(c[e],i)}catch(v){fl(u,u.return,v)}}a&&f&64&&u0(n),ce(n,n.return);break;case 27:i0(n);case 26:case 5:$t(e,n,a),a&&u===null&&f&4&&n0(n),ce(n,n.return);break;case 12:$t(e,n,a);break;case 31:$t(e,n,a),a&&f&4&&y0(e,n);break;case 13:$t(e,n,a),a&&f&4&&v0(e,n);break;case 22:n.memoizedState===null&&$t(e,n,a),ce(n,n.return);break;case 30:break;default:$t(e,n,a)}t=t.sibling}}function Ri(l,t){var a=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(a=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==a&&(l!=null&&l.refCount++,a!=null&&Wu(a))}function Ni(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Wu(l))}function Ut(l,t,a,u){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)g0(l,t,a,u),t=t.sibling}function g0(l,t,a,u){var e=t.flags;switch(t.tag){case 0:case 11:case 15:Ut(l,t,a,u),e&2048&&ie(9,t);break;case 1:Ut(l,t,a,u);break;case 3:Ut(l,t,a,u),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Wu(l)));break;case 12:if(e&2048){Ut(l,t,a,u),l=t.stateNode;try{var n=t.memoizedProps,f=n.id,i=n.onPostCommit;typeof i=="function"&&i(f,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(c){fl(t,t.return,c)}}else Ut(l,t,a,u);break;case 31:Ut(l,t,a,u);break;case 13:Ut(l,t,a,u);break;case 23:break;case 22:n=t.stateNode,f=t.alternate,t.memoizedState!==null?n._visibility&2?Ut(l,t,a,u):se(l,t):n._visibility&2?Ut(l,t,a,u):(n._visibility|=2,Su(l,t,a,u,(t.subtreeFlags&10256)!==0||!1)),e&2048&&Ri(f,t);break;case 24:Ut(l,t,a,u),e&2048&&Ni(t.alternate,t);break;default:Ut(l,t,a,u)}}function Su(l,t,a,u,e){for(e=e&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var n=l,f=t,i=a,c=u,v=f.flags;switch(f.tag){case 0:case 11:case 15:Su(n,f,i,c,e),ie(8,f);break;case 23:break;case 22:var r=f.stateNode;f.memoizedState!==null?r._visibility&2?Su(n,f,i,c,e):se(n,f):(r._visibility|=2,Su(n,f,i,c,e)),e&&v&2048&&Ri(f.alternate,f);break;case 24:Su(n,f,i,c,e),e&&v&2048&&Ni(f.alternate,f);break;default:Su(n,f,i,c,e)}t=t.sibling}}function se(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var a=l,u=t,e=u.flags;switch(u.tag){case 22:se(a,u),e&2048&&Ri(u.alternate,u);break;case 24:se(a,u),e&2048&&Ni(u.alternate,u);break;default:se(a,u)}t=t.sibling}}var de=8192;function ru(l,t,a){if(l.subtreeFlags&de)for(l=l.child;l!==null;)S0(l,t,a),l=l.sibling}function S0(l,t,a){switch(l.tag){case 26:ru(l,t,a),l.flags&de&&l.memoizedState!==null&&um(a,Dt,l.memoizedState,l.memoizedProps);break;case 5:ru(l,t,a);break;case 3:case 4:var u=Dt;Dt=xn(l.stateNode.containerInfo),ru(l,t,a),Dt=u;break;case 22:l.memoizedState===null&&(u=l.alternate,u!==null&&u.memoizedState!==null?(u=de,de=16777216,ru(l,t,a),de=u):ru(l,t,a));break;default:ru(l,t,a)}}function r0(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function oe(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];Bl=u,z0(u,l)}r0(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)b0(l),l=l.sibling}function b0(l){switch(l.tag){case 0:case 11:case 15:oe(l),l.flags&2048&&ya(9,l,l.return);break;case 3:oe(l);break;case 12:oe(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,Sn(l)):oe(l);break;default:oe(l)}}function Sn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var a=0;a<t.length;a++){var u=t[a];Bl=u,z0(u,l)}r0(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:ya(8,t,t.return),Sn(t);break;case 22:a=t.stateNode,a._visibility&2&&(a._visibility&=-3,Sn(t));break;default:Sn(t)}l=l.sibling}}function z0(l,t){for(;Bl!==null;){var a=Bl;switch(a.tag){case 0:case 11:case 15:ya(8,a,t);break;case 23:case 22:if(a.memoizedState!==null&&a.memoizedState.cachePool!==null){var u=a.memoizedState.cachePool.pool;u!=null&&u.refCount++}break;case 24:Wu(a.memoizedState.cache)}if(u=a.child,u!==null)u.return=a,Bl=u;else l:for(a=l;Bl!==null;){u=Bl;var e=u.sibling,n=u.return;if(d0(u),u===a){Bl=null;break l}if(e!==null){e.return=n,Bl=e;break l}Bl=n}}}var rv={getCacheForType:function(l){var t=Gl(Ol),a=t.data.get(l);return a===void 0&&(a=l(),t.data.set(l,a)),a},cacheSignal:function(){return Gl(Ol).controller.signal}},bv=typeof WeakMap=="function"?WeakMap:Map,ll=0,yl=null,K=null,w=0,nl=0,vt=null,va=!1,bu=!1,Bi=!1,kt=0,zl=0,ma=0,Va=0,Ci=0,mt=0,zu=0,ye=null,at=null,ji=!1,rn=0,T0=0,bn=1/0,zn=null,ha=null,xl=0,ga=null,Tu=null,Ft=0,qi=0,Yi=null,E0=null,ve=0,Gi=null;function ht(){return(ll&2)!==0&&w!==0?w&-w:S.T!==null?Ki():Yc()}function A0(){if(mt===0)if((w&536870912)===0||k){var l=Me;Me<<=1,(Me&3932160)===0&&(Me=262144),mt=l}else mt=536870912;return l=ot.current,l!==null&&(l.flags|=32),mt}function ut(l,t,a){(l===yl&&(nl===2||nl===9)||l.cancelPendingCommit!==null)&&(Eu(l,0),Sa(l,w,mt,!1)),Bu(l,a),((ll&2)===0||l!==yl)&&(l===yl&&((ll&2)===0&&(Va|=a),zl===4&&Sa(l,w,mt,!1)),Bt(l))}function p0(l,t,a){if((ll&6)!==0)throw Error(h(327));var u=!a&&(t&127)===0&&(t&l.expiredLanes)===0||Nu(l,t),e=u?Ev(l,t):Qi(l,t,!0),n=u;do{if(e===0){bu&&!u&&Sa(l,t,0,!1);break}else{if(a=l.current.alternate,n&&!zv(a)){e=Qi(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var f=0;else f=l.pendingLanes&-536870913,f=f!==0?f:f&536870912?536870912:0;if(f!==0){t=f;l:{var i=l;e=ye;var c=i.current.memoizedState.isDehydrated;if(c&&(Eu(i,f).flags|=256),f=Qi(i,f,!1),f!==2){if(Bi&&!c){i.errorRecoveryDisabledLanes|=n,Va|=n,e=4;break l}n=at,at=e,n!==null&&(at===null?at=n:at.push.apply(at,n))}e=f}if(n=!1,e!==2)continue}}if(e===1){Eu(l,0),Sa(l,t,0,!0);break}l:{switch(u=l,n=e,n){case 0:case 1:throw Error(h(345));case 4:if((t&4194048)!==t)break;case 6:Sa(u,t,mt,!va);break l;case 2:at=null;break;case 3:case 5:break;default:throw Error(h(329))}if((t&62914560)===t&&(e=rn+300-ft(),10<e)){if(Sa(u,t,mt,!va),Ue(u,0,!0)!==0)break l;Ft=t,u.timeoutHandle=to(_0.bind(null,u,a,at,zn,ji,t,mt,Va,zu,va,n,"Throttled",-0,0),e);break l}_0(u,a,at,zn,ji,t,mt,Va,zu,va,n,null,-0,0)}}break}while(!0);Bt(l)}function _0(l,t,a,u,e,n,f,i,c,v,r,z,m,g){if(l.timeoutHandle=-1,z=t.subtreeFlags,z&8192||(z&16785408)===16785408){z={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:jt},S0(t,n,z);var M=(n&62914560)===n?rn-ft():(n&4194048)===n?T0-ft():0;if(M=em(z,M),M!==null){Ft=n,l.cancelPendingCommit=M(N0.bind(null,l,t,n,a,u,e,f,i,c,r,z,null,m,g)),Sa(l,n,f,!v);return}}N0(l,t,n,a,u,e,f,i,c)}function zv(l){for(var t=l;;){var a=t.tag;if((a===0||a===11||a===15)&&t.flags&16384&&(a=t.updateQueue,a!==null&&(a=a.stores,a!==null)))for(var u=0;u<a.length;u++){var e=a[u],n=e.getSnapshot;e=e.value;try{if(!st(n(),e))return!1}catch{return!1}}if(a=t.child,t.subtreeFlags&16384&&a!==null)a.return=t,t=a;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function Sa(l,t,a,u){t&=~Ci,t&=~Va,l.suspendedLanes|=t,l.pingedLanes&=~t,u&&(l.warmLanes|=t),u=l.expirationTimes;for(var e=t;0<e;){var n=31-ct(e),f=1<<n;u[n]=-1,e&=~f}a!==0&&Cc(l,a,t)}function Tn(){return(ll&6)===0?(me(0),!1):!0}function Xi(){if(K!==null){if(nl===0)var l=K.return;else l=K,Xt=Ba=null,ai(l),yu=null,ku=0,l=K;for(;l!==null;)a0(l.alternate,l),l=l.return;K=null}}function Eu(l,t){var a=l.timeoutHandle;a!==-1&&(l.timeoutHandle=-1,Xv(a)),a=l.cancelPendingCommit,a!==null&&(l.cancelPendingCommit=null,a()),Ft=0,Xi(),yl=l,K=a=Yt(l.current,null),w=t,nl=0,vt=null,va=!1,bu=Nu(l,t),Bi=!1,zu=mt=Ci=Va=ma=zl=0,at=ye=null,ji=!1,(t&8)!==0&&(t|=t&32);var u=l.entangledLanes;if(u!==0)for(l=l.entanglements,u&=t;0<u;){var e=31-ct(u),n=1<<e;t|=l[e],u&=~n}return kt=t,Qe(),a}function O0(l,t){Q=null,S.H=ee,t===ou||t===$e?(t=Zs(),nl=3):t===Lf?(t=Zs(),nl=4):nl=t===ri?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,vt=t,K===null&&(zl=1,dn(l,zt(t,l.current)))}function M0(){var l=ot.current;return l===null?!0:(w&4194048)===w?pt===null:(w&62914560)===w||(w&536870912)!==0?l===pt:!1}function D0(){var l=S.H;return S.H=ee,l===null?ee:l}function U0(){var l=S.A;return S.A=rv,l}function En(){zl=4,va||(w&4194048)!==w&&ot.current!==null||(bu=!0),(ma&134217727)===0&&(Va&134217727)===0||yl===null||Sa(yl,w,mt,!1)}function Qi(l,t,a){var u=ll;ll|=2;var e=D0(),n=U0();(yl!==l||w!==t)&&(zn=null,Eu(l,t)),t=!1;var f=zl;l:do try{if(nl!==0&&K!==null){var i=K,c=vt;switch(nl){case 8:Xi(),f=6;break l;case 3:case 2:case 9:case 6:ot.current===null&&(t=!0);var v=nl;if(nl=0,vt=null,Au(l,i,c,v),a&&bu){f=0;break l}break;default:v=nl,nl=0,vt=null,Au(l,i,c,v)}}Tv(),f=zl;break}catch(r){O0(l,r)}while(!0);return t&&l.shellSuspendCounter++,Xt=Ba=null,ll=u,S.H=e,S.A=n,K===null&&(yl=null,w=0,Qe()),f}function Tv(){for(;K!==null;)x0(K)}function Ev(l,t){var a=ll;ll|=2;var u=D0(),e=U0();yl!==l||w!==t?(zn=null,bn=ft()+500,Eu(l,t)):bu=Nu(l,t);l:do try{if(nl!==0&&K!==null){t=K;var n=vt;t:switch(nl){case 1:nl=0,vt=null,Au(l,t,n,1);break;case 2:case 9:if(Xs(n)){nl=0,vt=null,H0(t);break}t=function(){nl!==2&&nl!==9||yl!==l||(nl=7),Bt(l)},n.then(t,t);break l;case 3:nl=7;break l;case 4:nl=5;break l;case 7:Xs(n)?(nl=0,vt=null,H0(t)):(nl=0,vt=null,Au(l,t,n,7));break;case 5:var f=null;switch(K.tag){case 26:f=K.memoizedState;case 5:case 27:var i=K;if(f?So(f):i.stateNode.complete){nl=0,vt=null;var c=i.sibling;if(c!==null)K=c;else{var v=i.return;v!==null?(K=v,An(v)):K=null}break t}}nl=0,vt=null,Au(l,t,n,5);break;case 6:nl=0,vt=null,Au(l,t,n,6);break;case 8:Xi(),zl=6;break l;default:throw Error(h(462))}}Av();break}catch(r){O0(l,r)}while(!0);return Xt=Ba=null,S.H=u,S.A=e,ll=a,K!==null?0:(yl=null,w=0,Qe(),zl)}function Av(){for(;K!==null&&!Jo();)x0(K)}function x0(l){var t=l0(l.alternate,l,kt);l.memoizedProps=l.pendingProps,t===null?An(l):K=t}function H0(l){var t=l,a=t.alternate;switch(t.tag){case 15:case 0:t=Wd(a,t,t.pendingProps,t.type,void 0,w);break;case 11:t=Wd(a,t,t.pendingProps,t.type.render,t.ref,w);break;case 5:ai(t);default:a0(a,t),t=K=Us(t,kt),t=l0(a,t,kt)}l.memoizedProps=l.pendingProps,t===null?An(l):K=t}function Au(l,t,a,u){Xt=Ba=null,ai(t),yu=null,ku=0;var e=t.return;try{if(ov(l,e,t,a,w)){zl=1,dn(l,zt(a,l.current)),K=null;return}}catch(n){if(e!==null)throw K=e,n;zl=1,dn(l,zt(a,l.current)),K=null;return}t.flags&32768?(k||u===1?l=!0:bu||(w&536870912)!==0?l=!1:(va=l=!0,(u===2||u===9||u===3||u===6)&&(u=ot.current,u!==null&&u.tag===13&&(u.flags|=16384))),R0(t,l)):An(t)}function An(l){var t=l;do{if((t.flags&32768)!==0){R0(t,va);return}l=t.return;var a=mv(t.alternate,t,kt);if(a!==null){K=a;return}if(t=t.sibling,t!==null){K=t;return}K=t=l}while(t!==null);zl===0&&(zl=5)}function R0(l,t){do{var a=hv(l.alternate,l);if(a!==null){a.flags&=32767,K=a;return}if(a=l.return,a!==null&&(a.flags|=32768,a.subtreeFlags=0,a.deletions=null),!t&&(l=l.sibling,l!==null)){K=l;return}K=l=a}while(l!==null);zl=6,K=null}function N0(l,t,a,u,e,n,f,i,c){l.cancelPendingCommit=null;do pn();while(xl!==0);if((ll&6)!==0)throw Error(h(327));if(t!==null){if(t===l.current)throw Error(h(177));if(n=t.lanes|t.childLanes,n|=Uf,ay(l,a,n,f,i,c),l===yl&&(K=yl=null,w=0),Tu=t,ga=l,Ft=a,qi=n,Yi=e,E0=u,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,Mv(_e,function(){return Y0(),null})):(l.callbackNode=null,l.callbackPriority=0),u=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||u){u=S.T,S.T=null,e=p.p,p.p=2,f=ll,ll|=4;try{gv(l,t,a)}finally{ll=f,p.p=e,S.T=u}}xl=1,B0(),C0(),j0()}}function B0(){if(xl===1){xl=0;var l=ga,t=Tu,a=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||a){a=S.T,S.T=null;var u=p.p;p.p=2;var e=ll;ll|=4;try{m0(t,l);var n=Pi,f=zs(l.containerInfo),i=n.focusedElem,c=n.selectionRange;if(f!==i&&i&&i.ownerDocument&&bs(i.ownerDocument.documentElement,i)){if(c!==null&&pf(i)){var v=c.start,r=c.end;if(r===void 0&&(r=v),"selectionStart"in i)i.selectionStart=v,i.selectionEnd=Math.min(r,i.value.length);else{var z=i.ownerDocument||document,m=z&&z.defaultView||window;if(m.getSelection){var g=m.getSelection(),M=i.textContent.length,j=Math.min(c.start,M),dl=c.end===void 0?j:Math.min(c.end,M);!g.extend&&j>dl&&(f=dl,dl=j,j=f);var o=rs(i,j),s=rs(i,dl);if(o&&s&&(g.rangeCount!==1||g.anchorNode!==o.node||g.anchorOffset!==o.offset||g.focusNode!==s.node||g.focusOffset!==s.offset)){var y=z.createRange();y.setStart(o.node,o.offset),g.removeAllRanges(),j>dl?(g.addRange(y),g.extend(s.node,s.offset)):(y.setEnd(s.node,s.offset),g.addRange(y))}}}}for(z=[],g=i;g=g.parentNode;)g.nodeType===1&&z.push({element:g,left:g.scrollLeft,top:g.scrollTop});for(typeof i.focus=="function"&&i.focus(),i=0;i<z.length;i++){var b=z[i];b.element.scrollLeft=b.left,b.element.scrollTop=b.top}}jn=!!Ii,Pi=Ii=null}finally{ll=e,p.p=u,S.T=a}}l.current=t,xl=2}}function C0(){if(xl===2){xl=0;var l=ga,t=Tu,a=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||a){a=S.T,S.T=null;var u=p.p;p.p=2;var e=ll;ll|=4;try{s0(l,t.alternate,t)}finally{ll=e,p.p=u,S.T=a}}xl=3}}function j0(){if(xl===4||xl===3){xl=0,wo();var l=ga,t=Tu,a=Ft,u=E0;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?xl=5:(xl=0,Tu=ga=null,q0(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(ha=null),ef(a),t=t.stateNode,it&&typeof it.onCommitFiberRoot=="function")try{it.onCommitFiberRoot(Ru,t,void 0,(t.current.flags&128)===128)}catch{}if(u!==null){t=S.T,e=p.p,p.p=2,S.T=null;try{for(var n=l.onRecoverableError,f=0;f<u.length;f++){var i=u[f];n(i.value,{componentStack:i.stack})}}finally{S.T=t,p.p=e}}(Ft&3)!==0&&pn(),Bt(l),e=l.pendingLanes,(a&261930)!==0&&(e&42)!==0?l===Gi?ve++:(ve=0,Gi=l):ve=0,me(0)}}function q0(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Wu(t)))}function pn(){return B0(),C0(),j0(),Y0()}function Y0(){if(xl!==5)return!1;var l=ga,t=qi;qi=0;var a=ef(Ft),u=S.T,e=p.p;try{p.p=32>a?32:a,S.T=null,a=Yi,Yi=null;var n=ga,f=Ft;if(xl=0,Tu=ga=null,Ft=0,(ll&6)!==0)throw Error(h(331));var i=ll;if(ll|=4,b0(n.current),g0(n,n.current,f,a),ll=i,me(0,!1),it&&typeof it.onPostCommitFiberRoot=="function")try{it.onPostCommitFiberRoot(Ru,n)}catch{}return!0}finally{p.p=e,S.T=u,q0(l,t)}}function G0(l,t,a){t=zt(a,t),t=Si(l.stateNode,t,2),l=sa(l,t,2),l!==null&&(Bu(l,2),Bt(l))}function fl(l,t,a){if(l.tag===3)G0(l,l,a);else for(;t!==null;){if(t.tag===3){G0(t,l,a);break}else if(t.tag===1){var u=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof u.componentDidCatch=="function"&&(ha===null||!ha.has(u))){l=zt(a,l),a=Xd(2),u=sa(t,a,2),u!==null&&(Qd(a,u,t,l),Bu(u,2),Bt(u));break}}t=t.return}}function Zi(l,t,a){var u=l.pingCache;if(u===null){u=l.pingCache=new bv;var e=new Set;u.set(t,e)}else e=u.get(t),e===void 0&&(e=new Set,u.set(t,e));e.has(a)||(Bi=!0,e.add(a),l=pv.bind(null,l,t,a),t.then(l,l))}function pv(l,t,a){var u=l.pingCache;u!==null&&u.delete(t),l.pingedLanes|=l.suspendedLanes&a,l.warmLanes&=~a,yl===l&&(w&a)===a&&(zl===4||zl===3&&(w&62914560)===w&&300>ft()-rn?(ll&2)===0&&Eu(l,0):Ci|=a,zu===w&&(zu=0)),Bt(l)}function X0(l,t){t===0&&(t=Bc()),l=Ha(l,t),l!==null&&(Bu(l,t),Bt(l))}function _v(l){var t=l.memoizedState,a=0;t!==null&&(a=t.retryLane),X0(l,a)}function Ov(l,t){var a=0;switch(l.tag){case 31:case 13:var u=l.stateNode,e=l.memoizedState;e!==null&&(a=e.retryLane);break;case 19:u=l.stateNode;break;case 22:u=l.stateNode._retryCache;break;default:throw Error(h(314))}u!==null&&u.delete(t),X0(l,a)}function Mv(l,t){return lf(l,t)}var _n=null,pu=null,Vi=!1,On=!1,Li=!1,ra=0;function Bt(l){l!==pu&&l.next===null&&(pu===null?_n=pu=l:pu=pu.next=l),On=!0,Vi||(Vi=!0,Uv())}function me(l,t){if(!Li&&On){Li=!0;do for(var a=!1,u=_n;u!==null;){if(l!==0){var e=u.pendingLanes;if(e===0)var n=0;else{var f=u.suspendedLanes,i=u.pingedLanes;n=(1<<31-ct(42|l)+1)-1,n&=e&~(f&~i),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(a=!0,L0(u,n))}else n=w,n=Ue(u,u===yl?n:0,u.cancelPendingCommit!==null||u.timeoutHandle!==-1),(n&3)===0||Nu(u,n)||(a=!0,L0(u,n));u=u.next}while(a);Li=!1}}function Dv(){Q0()}function Q0(){On=Vi=!1;var l=0;ra!==0&&Gv()&&(l=ra);for(var t=ft(),a=null,u=_n;u!==null;){var e=u.next,n=Z0(u,t);n===0?(u.next=null,a===null?_n=e:a.next=e,e===null&&(pu=a)):(a=u,(l!==0||(n&3)!==0)&&(On=!0)),u=e}xl!==0&&xl!==5||me(l),ra!==0&&(ra=0)}function Z0(l,t){for(var a=l.suspendedLanes,u=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var f=31-ct(n),i=1<<f,c=e[f];c===-1?((i&a)===0||(i&u)!==0)&&(e[f]=ty(i,t)):c<=t&&(l.expiredLanes|=i),n&=~i}if(t=yl,a=w,a=Ue(l,l===t?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u=l.callbackNode,a===0||l===t&&(nl===2||nl===9)||l.cancelPendingCommit!==null)return u!==null&&u!==null&&tf(u),l.callbackNode=null,l.callbackPriority=0;if((a&3)===0||Nu(l,a)){if(t=a&-a,t===l.callbackPriority)return t;switch(u!==null&&tf(u),ef(a)){case 2:case 8:a=Rc;break;case 32:a=_e;break;case 268435456:a=Nc;break;default:a=_e}return u=V0.bind(null,l),a=lf(a,u),l.callbackPriority=t,l.callbackNode=a,t}return u!==null&&u!==null&&tf(u),l.callbackPriority=2,l.callbackNode=null,2}function V0(l,t){if(xl!==0&&xl!==5)return l.callbackNode=null,l.callbackPriority=0,null;var a=l.callbackNode;if(pn()&&l.callbackNode!==a)return null;var u=w;return u=Ue(l,l===yl?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),u===0?null:(p0(l,u,t),Z0(l,ft()),l.callbackNode!=null&&l.callbackNode===a?V0.bind(null,l):null)}function L0(l,t){if(pn())return null;p0(l,t,!0)}function Uv(){Qv(function(){(ll&6)!==0?lf(Hc,Dv):Q0()})}function Ki(){if(ra===0){var l=su;l===0&&(l=Oe,Oe<<=1,(Oe&261888)===0&&(Oe=256)),ra=l}return ra}function K0(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Ne(""+l)}function J0(l,t){var a=t.ownerDocument.createElement("input");return a.name=t.name,a.value=t.value,l.id&&a.setAttribute("form",l.id),t.parentNode.insertBefore(a,t),l=new FormData(l),a.parentNode.removeChild(a),l}function xv(l,t,a,u,e){if(t==="submit"&&a&&a.stateNode===e){var n=K0((e[Fl]||null).action),f=u.submitter;f&&(t=(t=f[Fl]||null)?K0(t.formAction):f.getAttribute("formAction"),t!==null&&(n=t,f=null));var i=new qe("action","action",null,u,e);l.push({event:i,listeners:[{instance:null,listener:function(){if(u.defaultPrevented){if(ra!==0){var c=f?J0(e,f):new FormData(e);oi(a,{pending:!0,data:c,method:e.method,action:n},null,c)}}else typeof n=="function"&&(i.preventDefault(),c=f?J0(e,f):new FormData(e),oi(a,{pending:!0,data:c,method:e.method,action:n},n,c))},currentTarget:e}]})}}for(var Ji=0;Ji<Df.length;Ji++){var wi=Df[Ji],Hv=wi.toLowerCase(),Rv=wi[0].toUpperCase()+wi.slice(1);Mt(Hv,"on"+Rv)}Mt(As,"onAnimationEnd"),Mt(ps,"onAnimationIteration"),Mt(_s,"onAnimationStart"),Mt("dblclick","onDoubleClick"),Mt("focusin","onFocus"),Mt("focusout","onBlur"),Mt(Wy,"onTransitionRun"),Mt($y,"onTransitionStart"),Mt(ky,"onTransitionCancel"),Mt(Os,"onTransitionEnd"),$a("onMouseEnter",["mouseout","mouseover"]),$a("onMouseLeave",["mouseout","mouseover"]),$a("onPointerEnter",["pointerout","pointerover"]),$a("onPointerLeave",["pointerout","pointerover"]),Ma("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Ma("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Ma("onBeforeInput",["compositionend","keypress","textInput","paste"]),Ma("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Ma("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Ma("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var he="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Nv=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(he));function w0(l,t){t=(t&4)!==0;for(var a=0;a<l.length;a++){var u=l[a],e=u.event;u=u.listeners;l:{var n=void 0;if(t)for(var f=u.length-1;0<=f;f--){var i=u[f],c=i.instance,v=i.currentTarget;if(i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(r){Xe(r)}e.currentTarget=null,n=c}else for(f=0;f<u.length;f++){if(i=u[f],c=i.instance,v=i.currentTarget,i=i.listener,c!==n&&e.isPropagationStopped())break l;n=i,e.currentTarget=v;try{n(e)}catch(r){Xe(r)}e.currentTarget=null,n=c}}}}function J(l,t){var a=t[nf];a===void 0&&(a=t[nf]=new Set);var u=l+"__bubble";a.has(u)||(W0(t,l,2,!1),a.add(u))}function Wi(l,t,a){var u=0;t&&(u|=4),W0(a,l,u,t)}var Mn="_reactListening"+Math.random().toString(36).slice(2);function $i(l){if(!l[Mn]){l[Mn]=!0,Qc.forEach(function(a){a!=="selectionchange"&&(Nv.has(a)||Wi(a,!1,l),Wi(a,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Mn]||(t[Mn]=!0,Wi("selectionchange",!1,t))}}function W0(l,t,a,u){switch(po(t)){case 2:var e=im;break;case 8:e=cm;break;default:e=dc}a=e.bind(null,t,a,l),e=void 0,!hf||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),u?e!==void 0?l.addEventListener(t,a,{capture:!0,passive:e}):l.addEventListener(t,a,!0):e!==void 0?l.addEventListener(t,a,{passive:e}):l.addEventListener(t,a,!1)}function ki(l,t,a,u,e){var n=u;if((t&1)===0&&(t&2)===0&&u!==null)l:for(;;){if(u===null)return;var f=u.tag;if(f===3||f===4){var i=u.stateNode.containerInfo;if(i===e)break;if(f===4)for(f=u.return;f!==null;){var c=f.tag;if((c===3||c===4)&&f.stateNode.containerInfo===e)return;f=f.return}for(;i!==null;){if(f=Ja(i),f===null)return;if(c=f.tag,c===5||c===6||c===26||c===27){u=n=f;continue l}i=i.parentNode}}u=u.return}Pc(function(){var v=n,r=vf(a),z=[];l:{var m=Ms.get(l);if(m!==void 0){var g=qe,M=l;switch(l){case"keypress":if(Ce(a)===0)break l;case"keydown":case"keyup":g=Oy;break;case"focusin":M="focus",g=bf;break;case"focusout":M="blur",g=bf;break;case"beforeblur":case"afterblur":g=bf;break;case"click":if(a.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":g=as;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":g=my;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":g=Uy;break;case As:case ps:case _s:g=Sy;break;case Os:g=Hy;break;case"scroll":case"scrollend":g=yy;break;case"wheel":g=Ny;break;case"copy":case"cut":case"paste":g=by;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":g=es;break;case"toggle":case"beforetoggle":g=Cy}var j=(t&4)!==0,dl=!j&&(l==="scroll"||l==="scrollend"),o=j?m!==null?m+"Capture":null:m;j=[];for(var s=v,y;s!==null;){var b=s;if(y=b.stateNode,b=b.tag,b!==5&&b!==26&&b!==27||y===null||o===null||(b=qu(s,o),b!=null&&j.push(ge(s,b,y))),dl)break;s=s.return}0<j.length&&(m=new g(m,M,null,a,r),z.push({event:m,listeners:j}))}}if((t&7)===0){l:{if(m=l==="mouseover"||l==="pointerover",g=l==="mouseout"||l==="pointerout",m&&a!==yf&&(M=a.relatedTarget||a.fromElement)&&(Ja(M)||M[Ka]))break l;if((g||m)&&(m=r.window===r?r:(m=r.ownerDocument)?m.defaultView||m.parentWindow:window,g?(M=a.relatedTarget||a.toElement,g=v,M=M?Ja(M):null,M!==null&&(dl=Tl(M),j=M.tag,M!==dl||j!==5&&j!==27&&j!==6)&&(M=null)):(g=null,M=v),g!==M)){if(j=as,b="onMouseLeave",o="onMouseEnter",s="mouse",(l==="pointerout"||l==="pointerover")&&(j=es,b="onPointerLeave",o="onPointerEnter",s="pointer"),dl=g==null?m:ju(g),y=M==null?m:ju(M),m=new j(b,s+"leave",g,a,r),m.target=dl,m.relatedTarget=y,b=null,Ja(r)===v&&(j=new j(o,s+"enter",M,a,r),j.target=y,j.relatedTarget=dl,b=j),dl=b,g&&M)t:{for(j=Bv,o=g,s=M,y=0,b=o;b;b=j(b))y++;b=0;for(var N=s;N;N=j(N))b++;for(;0<y-b;)o=j(o),y--;for(;0<b-y;)s=j(s),b--;for(;y--;){if(o===s||s!==null&&o===s.alternate){j=o;break t}o=j(o),s=j(s)}j=null}else j=null;g!==null&&$0(z,m,g,j,!1),M!==null&&dl!==null&&$0(z,dl,M,j,!0)}}l:{if(m=v?ju(v):window,g=m.nodeName&&m.nodeName.toLowerCase(),g==="select"||g==="input"&&m.type==="file")var I=ys;else if(ds(m))if(vs)I=Ky;else{I=Vy;var U=Zy}else g=m.nodeName,!g||g.toLowerCase()!=="input"||m.type!=="checkbox"&&m.type!=="radio"?v&&of(v.elementType)&&(I=ys):I=Ly;if(I&&(I=I(l,v))){os(z,I,a,r);break l}U&&U(l,m,v),l==="focusout"&&v&&m.type==="number"&&v.memoizedProps.value!=null&&df(m,"number",m.value)}switch(U=v?ju(v):window,l){case"focusin":(ds(U)||U.contentEditable==="true")&&(tu=U,_f=v,Ku=null);break;case"focusout":Ku=_f=tu=null;break;case"mousedown":Of=!0;break;case"contextmenu":case"mouseup":case"dragend":Of=!1,Ts(z,a,r);break;case"selectionchange":if(wy)break;case"keydown":case"keyup":Ts(z,a,r)}var Z;if(Tf)l:{switch(l){case"compositionstart":var W="onCompositionStart";break l;case"compositionend":W="onCompositionEnd";break l;case"compositionupdate":W="onCompositionUpdate";break l}W=void 0}else lu?cs(l,a)&&(W="onCompositionEnd"):l==="keydown"&&a.keyCode===229&&(W="onCompositionStart");W&&(ns&&a.locale!=="ko"&&(lu||W!=="onCompositionStart"?W==="onCompositionEnd"&&lu&&(Z=ls()):(aa=r,gf="value"in aa?aa.value:aa.textContent,lu=!0)),U=Dn(v,W),0<U.length&&(W=new us(W,l,null,a,r),z.push({event:W,listeners:U}),Z?W.data=Z:(Z=ss(a),Z!==null&&(W.data=Z)))),(Z=qy?Yy(l,a):Gy(l,a))&&(W=Dn(v,"onBeforeInput"),0<W.length&&(U=new us("onBeforeInput","beforeinput",null,a,r),z.push({event:U,listeners:W}),U.data=Z)),xv(z,l,v,a,r)}w0(z,t)})}function ge(l,t,a){return{instance:l,listener:t,currentTarget:a}}function Dn(l,t){for(var a=t+"Capture",u=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=qu(l,a),e!=null&&u.unshift(ge(l,e,n)),e=qu(l,t),e!=null&&u.push(ge(l,e,n))),l.tag===3)return u;l=l.return}return[]}function Bv(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function $0(l,t,a,u,e){for(var n=t._reactName,f=[];a!==null&&a!==u;){var i=a,c=i.alternate,v=i.stateNode;if(i=i.tag,c!==null&&c===u)break;i!==5&&i!==26&&i!==27||v===null||(c=v,e?(v=qu(a,n),v!=null&&f.unshift(ge(a,v,c))):e||(v=qu(a,n),v!=null&&f.push(ge(a,v,c)))),a=a.return}f.length!==0&&l.push({event:t,listeners:f})}var Cv=/\r\n?/g,jv=/\u0000|\uFFFD/g;function k0(l){return(typeof l=="string"?l:""+l).replace(Cv,`
`).replace(jv,"")}function F0(l,t){return t=k0(t),k0(l)===t}function sl(l,t,a,u,e,n){switch(a){case"children":typeof u=="string"?t==="body"||t==="textarea"&&u===""||Fa(l,u):(typeof u=="number"||typeof u=="bigint")&&t!=="body"&&Fa(l,""+u);break;case"className":He(l,"class",u);break;case"tabIndex":He(l,"tabindex",u);break;case"dir":case"role":case"viewBox":case"width":case"height":He(l,a,u);break;case"style":Fc(l,u,n);break;case"data":if(t!=="object"){He(l,"data",u);break}case"src":case"href":if(u===""&&(t!=="a"||a!=="href")){l.removeAttribute(a);break}if(u==null||typeof u=="function"||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Ne(""+u),l.setAttribute(a,u);break;case"action":case"formAction":if(typeof u=="function"){l.setAttribute(a,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(a==="formAction"?(t!=="input"&&sl(l,t,"name",e.name,e,null),sl(l,t,"formEncType",e.formEncType,e,null),sl(l,t,"formMethod",e.formMethod,e,null),sl(l,t,"formTarget",e.formTarget,e,null)):(sl(l,t,"encType",e.encType,e,null),sl(l,t,"method",e.method,e,null),sl(l,t,"target",e.target,e,null)));if(u==null||typeof u=="symbol"||typeof u=="boolean"){l.removeAttribute(a);break}u=Ne(""+u),l.setAttribute(a,u);break;case"onClick":u!=null&&(l.onclick=jt);break;case"onScroll":u!=null&&J("scroll",l);break;case"onScrollEnd":u!=null&&J("scrollend",l);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"multiple":l.multiple=u&&typeof u!="function"&&typeof u!="symbol";break;case"muted":l.muted=u&&typeof u!="function"&&typeof u!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(u==null||typeof u=="function"||typeof u=="boolean"||typeof u=="symbol"){l.removeAttribute("xlink:href");break}a=Ne(""+u),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",a);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""+u):l.removeAttribute(a);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":u&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,""):l.removeAttribute(a);break;case"capture":case"download":u===!0?l.setAttribute(a,""):u!==!1&&u!=null&&typeof u!="function"&&typeof u!="symbol"?l.setAttribute(a,u):l.removeAttribute(a);break;case"cols":case"rows":case"size":case"span":u!=null&&typeof u!="function"&&typeof u!="symbol"&&!isNaN(u)&&1<=u?l.setAttribute(a,u):l.removeAttribute(a);break;case"rowSpan":case"start":u==null||typeof u=="function"||typeof u=="symbol"||isNaN(u)?l.removeAttribute(a):l.setAttribute(a,u);break;case"popover":J("beforetoggle",l),J("toggle",l),xe(l,"popover",u);break;case"xlinkActuate":Ct(l,"http://www.w3.org/1999/xlink","xlink:actuate",u);break;case"xlinkArcrole":Ct(l,"http://www.w3.org/1999/xlink","xlink:arcrole",u);break;case"xlinkRole":Ct(l,"http://www.w3.org/1999/xlink","xlink:role",u);break;case"xlinkShow":Ct(l,"http://www.w3.org/1999/xlink","xlink:show",u);break;case"xlinkTitle":Ct(l,"http://www.w3.org/1999/xlink","xlink:title",u);break;case"xlinkType":Ct(l,"http://www.w3.org/1999/xlink","xlink:type",u);break;case"xmlBase":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:base",u);break;case"xmlLang":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:lang",u);break;case"xmlSpace":Ct(l,"http://www.w3.org/XML/1998/namespace","xml:space",u);break;case"is":xe(l,"is",u);break;case"innerText":case"textContent":break;default:(!(2<a.length)||a[0]!=="o"&&a[0]!=="O"||a[1]!=="n"&&a[1]!=="N")&&(a=dy.get(a)||a,xe(l,a,u))}}function Fi(l,t,a,u,e,n){switch(a){case"style":Fc(l,u,n);break;case"dangerouslySetInnerHTML":if(u!=null){if(typeof u!="object"||!("__html"in u))throw Error(h(61));if(a=u.__html,a!=null){if(e.children!=null)throw Error(h(60));l.innerHTML=a}}break;case"children":typeof u=="string"?Fa(l,u):(typeof u=="number"||typeof u=="bigint")&&Fa(l,""+u);break;case"onScroll":u!=null&&J("scroll",l);break;case"onScrollEnd":u!=null&&J("scrollend",l);break;case"onClick":u!=null&&(l.onclick=jt);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Zc.hasOwnProperty(a))l:{if(a[0]==="o"&&a[1]==="n"&&(e=a.endsWith("Capture"),t=a.slice(2,e?a.length-7:void 0),n=l[Fl]||null,n=n!=null?n[a]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof u=="function")){typeof n!="function"&&n!==null&&(a in l?l[a]=null:l.hasAttribute(a)&&l.removeAttribute(a)),l.addEventListener(t,u,e);break l}a in l?l[a]=u:u===!0?l.setAttribute(a,""):xe(l,a,u)}}}function Ql(l,t,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":J("error",l),J("load",l);var u=!1,e=!1,n;for(n in a)if(a.hasOwnProperty(n)){var f=a[n];if(f!=null)switch(n){case"src":u=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:sl(l,t,n,f,a,null)}}e&&sl(l,t,"srcSet",a.srcSet,a,null),u&&sl(l,t,"src",a.src,a,null);return;case"input":J("invalid",l);var i=n=f=e=null,c=null,v=null;for(u in a)if(a.hasOwnProperty(u)){var r=a[u];if(r!=null)switch(u){case"name":e=r;break;case"type":f=r;break;case"checked":c=r;break;case"defaultChecked":v=r;break;case"value":n=r;break;case"defaultValue":i=r;break;case"children":case"dangerouslySetInnerHTML":if(r!=null)throw Error(h(137,t));break;default:sl(l,t,u,r,a,null)}}wc(l,n,i,c,v,f,e,!1);return;case"select":J("invalid",l),u=f=n=null;for(e in a)if(a.hasOwnProperty(e)&&(i=a[e],i!=null))switch(e){case"value":n=i;break;case"defaultValue":f=i;break;case"multiple":u=i;default:sl(l,t,e,i,a,null)}t=n,a=f,l.multiple=!!u,t!=null?ka(l,!!u,t,!1):a!=null&&ka(l,!!u,a,!0);return;case"textarea":J("invalid",l),n=e=u=null;for(f in a)if(a.hasOwnProperty(f)&&(i=a[f],i!=null))switch(f){case"value":u=i;break;case"defaultValue":e=i;break;case"children":n=i;break;case"dangerouslySetInnerHTML":if(i!=null)throw Error(h(91));break;default:sl(l,t,f,i,a,null)}$c(l,u,e,n);return;case"option":for(c in a)if(a.hasOwnProperty(c)&&(u=a[c],u!=null))switch(c){case"selected":l.selected=u&&typeof u!="function"&&typeof u!="symbol";break;default:sl(l,t,c,u,a,null)}return;case"dialog":J("beforetoggle",l),J("toggle",l),J("cancel",l),J("close",l);break;case"iframe":case"object":J("load",l);break;case"video":case"audio":for(u=0;u<he.length;u++)J(he[u],l);break;case"image":J("error",l),J("load",l);break;case"details":J("toggle",l);break;case"embed":case"source":case"link":J("error",l),J("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(v in a)if(a.hasOwnProperty(v)&&(u=a[v],u!=null))switch(v){case"children":case"dangerouslySetInnerHTML":throw Error(h(137,t));default:sl(l,t,v,u,a,null)}return;default:if(of(t)){for(r in a)a.hasOwnProperty(r)&&(u=a[r],u!==void 0&&Fi(l,t,r,u,a,void 0));return}}for(i in a)a.hasOwnProperty(i)&&(u=a[i],u!=null&&sl(l,t,i,u,a,null))}function qv(l,t,a,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,f=null,i=null,c=null,v=null,r=null;for(g in a){var z=a[g];if(a.hasOwnProperty(g)&&z!=null)switch(g){case"checked":break;case"value":break;case"defaultValue":c=z;default:u.hasOwnProperty(g)||sl(l,t,g,null,u,z)}}for(var m in u){var g=u[m];if(z=a[m],u.hasOwnProperty(m)&&(g!=null||z!=null))switch(m){case"type":n=g;break;case"name":e=g;break;case"checked":v=g;break;case"defaultChecked":r=g;break;case"value":f=g;break;case"defaultValue":i=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(h(137,t));break;default:g!==z&&sl(l,t,m,g,u,z)}}sf(l,f,i,c,v,r,n,e);return;case"select":g=f=i=m=null;for(n in a)if(c=a[n],a.hasOwnProperty(n)&&c!=null)switch(n){case"value":break;case"multiple":g=c;default:u.hasOwnProperty(n)||sl(l,t,n,null,u,c)}for(e in u)if(n=u[e],c=a[e],u.hasOwnProperty(e)&&(n!=null||c!=null))switch(e){case"value":m=n;break;case"defaultValue":i=n;break;case"multiple":f=n;default:n!==c&&sl(l,t,e,n,u,c)}t=i,a=f,u=g,m!=null?ka(l,!!a,m,!1):!!u!=!!a&&(t!=null?ka(l,!!a,t,!0):ka(l,!!a,a?[]:"",!1));return;case"textarea":g=m=null;for(i in a)if(e=a[i],a.hasOwnProperty(i)&&e!=null&&!u.hasOwnProperty(i))switch(i){case"value":break;case"children":break;default:sl(l,t,i,null,u,e)}for(f in u)if(e=u[f],n=a[f],u.hasOwnProperty(f)&&(e!=null||n!=null))switch(f){case"value":m=e;break;case"defaultValue":g=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(h(91));break;default:e!==n&&sl(l,t,f,e,u,n)}Wc(l,m,g);return;case"option":for(var M in a)if(m=a[M],a.hasOwnProperty(M)&&m!=null&&!u.hasOwnProperty(M))switch(M){case"selected":l.selected=!1;break;default:sl(l,t,M,null,u,m)}for(c in u)if(m=u[c],g=a[c],u.hasOwnProperty(c)&&m!==g&&(m!=null||g!=null))switch(c){case"selected":l.selected=m&&typeof m!="function"&&typeof m!="symbol";break;default:sl(l,t,c,m,u,g)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var j in a)m=a[j],a.hasOwnProperty(j)&&m!=null&&!u.hasOwnProperty(j)&&sl(l,t,j,null,u,m);for(v in u)if(m=u[v],g=a[v],u.hasOwnProperty(v)&&m!==g&&(m!=null||g!=null))switch(v){case"children":case"dangerouslySetInnerHTML":if(m!=null)throw Error(h(137,t));break;default:sl(l,t,v,m,u,g)}return;default:if(of(t)){for(var dl in a)m=a[dl],a.hasOwnProperty(dl)&&m!==void 0&&!u.hasOwnProperty(dl)&&Fi(l,t,dl,void 0,u,m);for(r in u)m=u[r],g=a[r],!u.hasOwnProperty(r)||m===g||m===void 0&&g===void 0||Fi(l,t,r,m,u,g);return}}for(var o in a)m=a[o],a.hasOwnProperty(o)&&m!=null&&!u.hasOwnProperty(o)&&sl(l,t,o,null,u,m);for(z in u)m=u[z],g=a[z],!u.hasOwnProperty(z)||m===g||m==null&&g==null||sl(l,t,z,m,u,g)}function I0(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Yv(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,a=performance.getEntriesByType("resource"),u=0;u<a.length;u++){var e=a[u],n=e.transferSize,f=e.initiatorType,i=e.duration;if(n&&i&&I0(f)){for(f=0,i=e.responseEnd,u+=1;u<a.length;u++){var c=a[u],v=c.startTime;if(v>i)break;var r=c.transferSize,z=c.initiatorType;r&&I0(z)&&(c=c.responseEnd,f+=r*(c<i?1:(i-v)/(c-v)))}if(--u,t+=8*(n+f)/(e.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var Ii=null,Pi=null;function Un(l){return l.nodeType===9?l:l.ownerDocument}function P0(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function lo(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function lc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var tc=null;function Gv(){var l=window.event;return l&&l.type==="popstate"?l===tc?!1:(tc=l,!0):(tc=null,!1)}var to=typeof setTimeout=="function"?setTimeout:void 0,Xv=typeof clearTimeout=="function"?clearTimeout:void 0,ao=typeof Promise=="function"?Promise:void 0,Qv=typeof queueMicrotask=="function"?queueMicrotask:typeof ao<"u"?function(l){return ao.resolve(null).then(l).catch(Zv)}:to;function Zv(l){setTimeout(function(){throw l})}function ba(l){return l==="head"}function uo(l,t){var a=t,u=0;do{var e=a.nextSibling;if(l.removeChild(a),e&&e.nodeType===8)if(a=e.data,a==="/$"||a==="/&"){if(u===0){l.removeChild(e),Du(t);return}u--}else if(a==="$"||a==="$?"||a==="$~"||a==="$!"||a==="&")u++;else if(a==="html")Se(l.ownerDocument.documentElement);else if(a==="head"){a=l.ownerDocument.head,Se(a);for(var n=a.firstChild;n;){var f=n.nextSibling,i=n.nodeName;n[Cu]||i==="SCRIPT"||i==="STYLE"||i==="LINK"&&n.rel.toLowerCase()==="stylesheet"||a.removeChild(n),n=f}}else a==="body"&&Se(l.ownerDocument.body);a=e}while(a);Du(t)}function eo(l,t){var a=l;l=0;do{var u=a.nextSibling;if(a.nodeType===1?t?(a._stashedDisplay=a.style.display,a.style.display="none"):(a.style.display=a._stashedDisplay||"",a.getAttribute("style")===""&&a.removeAttribute("style")):a.nodeType===3&&(t?(a._stashedText=a.nodeValue,a.nodeValue=""):a.nodeValue=a._stashedText||""),u&&u.nodeType===8)if(a=u.data,a==="/$"){if(l===0)break;l--}else a!=="$"&&a!=="$?"&&a!=="$~"&&a!=="$!"||l++;a=u}while(a)}function ac(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var a=t;switch(t=t.nextSibling,a.nodeName){case"HTML":case"HEAD":case"BODY":ac(a),ff(a);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(a.rel.toLowerCase()==="stylesheet")continue}l.removeChild(a)}}function Vv(l,t,a,u){for(;l.nodeType===1;){var e=a;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!u&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(u){if(!l[Cu])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=_t(l.nextSibling),l===null)break}return null}function Lv(l,t,a){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!a||(l=_t(l.nextSibling),l===null))return null;return l}function no(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=_t(l.nextSibling),l===null))return null;return l}function uc(l){return l.data==="$?"||l.data==="$~"}function ec(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function Kv(l,t){var a=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||a.readyState!=="loading")t();else{var u=function(){t(),a.removeEventListener("DOMContentLoaded",u)};a.addEventListener("DOMContentLoaded",u),l._reactRetry=u}}function _t(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var nc=null;function fo(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="/$"||a==="/&"){if(t===0)return _t(l.nextSibling);t--}else a!=="$"&&a!=="$!"&&a!=="$?"&&a!=="$~"&&a!=="&"||t++}l=l.nextSibling}return null}function io(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var a=l.data;if(a==="$"||a==="$!"||a==="$?"||a==="$~"||a==="&"){if(t===0)return l;t--}else a!=="/$"&&a!=="/&"||t++}l=l.previousSibling}return null}function co(l,t,a){switch(t=Un(a),l){case"html":if(l=t.documentElement,!l)throw Error(h(452));return l;case"head":if(l=t.head,!l)throw Error(h(453));return l;case"body":if(l=t.body,!l)throw Error(h(454));return l;default:throw Error(h(451))}}function Se(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);ff(l)}var Ot=new Map,so=new Set;function xn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var It=p.d;p.d={f:Jv,r:wv,D:Wv,C:$v,L:kv,m:Fv,X:Pv,S:Iv,M:lm};function Jv(){var l=It.f(),t=Tn();return l||t}function wv(l){var t=wa(l);t!==null&&t.tag===5&&t.type==="form"?Od(t):It.r(l)}var _u=typeof document>"u"?null:document;function oo(l,t,a){var u=_u;if(u&&typeof t=="string"&&t){var e=rt(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof a=="string"&&(e+='[crossorigin="'+a+'"]'),so.has(e)||(so.add(e),l={rel:l,crossOrigin:a,href:t},u.querySelector(e)===null&&(t=u.createElement("link"),Ql(t,"link",l),Nl(t),u.head.appendChild(t)))}}function Wv(l){It.D(l),oo("dns-prefetch",l,null)}function $v(l,t){It.C(l,t),oo("preconnect",l,t)}function kv(l,t,a){It.L(l,t,a);var u=_u;if(u&&l&&t){var e='link[rel="preload"][as="'+rt(t)+'"]';t==="image"&&a&&a.imageSrcSet?(e+='[imagesrcset="'+rt(a.imageSrcSet)+'"]',typeof a.imageSizes=="string"&&(e+='[imagesizes="'+rt(a.imageSizes)+'"]')):e+='[href="'+rt(l)+'"]';var n=e;switch(t){case"style":n=Ou(l);break;case"script":n=Mu(l)}Ot.has(n)||(l=C({rel:"preload",href:t==="image"&&a&&a.imageSrcSet?void 0:l,as:t},a),Ot.set(n,l),u.querySelector(e)!==null||t==="style"&&u.querySelector(re(n))||t==="script"&&u.querySelector(be(n))||(t=u.createElement("link"),Ql(t,"link",l),Nl(t),u.head.appendChild(t)))}}function Fv(l,t){It.m(l,t);var a=_u;if(a&&l){var u=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+rt(u)+'"][href="'+rt(l)+'"]',n=e;switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Mu(l)}if(!Ot.has(n)&&(l=C({rel:"modulepreload",href:l},t),Ot.set(n,l),a.querySelector(e)===null)){switch(u){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(a.querySelector(be(n)))return}u=a.createElement("link"),Ql(u,"link",l),Nl(u),a.head.appendChild(u)}}}function Iv(l,t,a){It.S(l,t,a);var u=_u;if(u&&l){var e=Wa(u).hoistableStyles,n=Ou(l);t=t||"default";var f=e.get(n);if(!f){var i={loading:0,preload:null};if(f=u.querySelector(re(n)))i.loading=5;else{l=C({rel:"stylesheet",href:l,"data-precedence":t},a),(a=Ot.get(n))&&fc(l,a);var c=f=u.createElement("link");Nl(c),Ql(c,"link",l),c._p=new Promise(function(v,r){c.onload=v,c.onerror=r}),c.addEventListener("load",function(){i.loading|=1}),c.addEventListener("error",function(){i.loading|=2}),i.loading|=4,Hn(f,t,u)}f={type:"stylesheet",instance:f,count:1,state:i},e.set(n,f)}}}function Pv(l,t){It.X(l,t);var a=_u;if(a&&l){var u=Wa(a).hoistableScripts,e=Mu(l),n=u.get(e);n||(n=a.querySelector(be(e)),n||(l=C({src:l,async:!0},t),(t=Ot.get(e))&&ic(l,t),n=a.createElement("script"),Nl(n),Ql(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function lm(l,t){It.M(l,t);var a=_u;if(a&&l){var u=Wa(a).hoistableScripts,e=Mu(l),n=u.get(e);n||(n=a.querySelector(be(e)),n||(l=C({src:l,async:!0,type:"module"},t),(t=Ot.get(e))&&ic(l,t),n=a.createElement("script"),Nl(n),Ql(n,"link",l),a.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},u.set(e,n))}}function yo(l,t,a,u){var e=(e=L.current)?xn(e):null;if(!e)throw Error(h(446));switch(l){case"meta":case"title":return null;case"style":return typeof a.precedence=="string"&&typeof a.href=="string"?(t=Ou(a.href),a=Wa(e).hoistableStyles,u=a.get(t),u||(u={type:"style",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};case"link":if(a.rel==="stylesheet"&&typeof a.href=="string"&&typeof a.precedence=="string"){l=Ou(a.href);var n=Wa(e).hoistableStyles,f=n.get(l);if(f||(e=e.ownerDocument||e,f={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,f),(n=e.querySelector(re(l)))&&!n._p&&(f.instance=n,f.state.loading=5),Ot.has(l)||(a={rel:"preload",as:"style",href:a.href,crossOrigin:a.crossOrigin,integrity:a.integrity,media:a.media,hrefLang:a.hrefLang,referrerPolicy:a.referrerPolicy},Ot.set(l,a),n||tm(e,l,a,f.state))),t&&u===null)throw Error(h(528,""));return f}if(t&&u!==null)throw Error(h(529,""));return null;case"script":return t=a.async,a=a.src,typeof a=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Mu(a),a=Wa(e).hoistableScripts,u=a.get(t),u||(u={type:"script",instance:null,count:0,state:null},a.set(t,u)),u):{type:"void",instance:null,count:0,state:null};default:throw Error(h(444,l))}}function Ou(l){return'href="'+rt(l)+'"'}function re(l){return'link[rel="stylesheet"]['+l+"]"}function vo(l){return C({},l,{"data-precedence":l.precedence,precedence:null})}function tm(l,t,a,u){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?u.loading=1:(t=l.createElement("link"),u.preload=t,t.addEventListener("load",function(){return u.loading|=1}),t.addEventListener("error",function(){return u.loading|=2}),Ql(t,"link",a),Nl(t),l.head.appendChild(t))}function Mu(l){return'[src="'+rt(l)+'"]'}function be(l){return"script[async]"+l}function mo(l,t,a){if(t.count++,t.instance===null)switch(t.type){case"style":var u=l.querySelector('style[data-href~="'+rt(a.href)+'"]');if(u)return t.instance=u,Nl(u),u;var e=C({},a,{"data-href":a.href,"data-precedence":a.precedence,href:null,precedence:null});return u=(l.ownerDocument||l).createElement("style"),Nl(u),Ql(u,"style",e),Hn(u,a.precedence,l),t.instance=u;case"stylesheet":e=Ou(a.href);var n=l.querySelector(re(e));if(n)return t.state.loading|=4,t.instance=n,Nl(n),n;u=vo(a),(e=Ot.get(e))&&fc(u,e),n=(l.ownerDocument||l).createElement("link"),Nl(n);var f=n;return f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),Ql(n,"link",u),t.state.loading|=4,Hn(n,a.precedence,l),t.instance=n;case"script":return n=Mu(a.src),(e=l.querySelector(be(n)))?(t.instance=e,Nl(e),e):(u=a,(e=Ot.get(n))&&(u=C({},a),ic(u,e)),l=l.ownerDocument||l,e=l.createElement("script"),Nl(e),Ql(e,"link",u),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(h(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(u=t.instance,t.state.loading|=4,Hn(u,a.precedence,l));return t.instance}function Hn(l,t,a){for(var u=a.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=u.length?u[u.length-1]:null,n=e,f=0;f<u.length;f++){var i=u[f];if(i.dataset.precedence===t)n=i;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=a.nodeType===9?a.head:a,t.insertBefore(l,t.firstChild))}function fc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function ic(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Rn=null;function ho(l,t,a){if(Rn===null){var u=new Map,e=Rn=new Map;e.set(a,u)}else e=Rn,u=e.get(a),u||(u=new Map,e.set(a,u));if(u.has(l))return u;for(u.set(l,null),a=a.getElementsByTagName(l),e=0;e<a.length;e++){var n=a[e];if(!(n[Cu]||n[ql]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var f=n.getAttribute(t)||"";f=l+f;var i=u.get(f);i?i.push(n):u.set(f,[n])}}return u}function go(l,t,a){l=l.ownerDocument||l,l.head.insertBefore(a,t==="title"?l.querySelector("head > title"):null)}function am(l,t,a){if(a===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function So(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function um(l,t,a,u){if(a.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(a.state.loading&4)===0){if(a.instance===null){var e=Ou(u.href),n=t.querySelector(re(e));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Nn.bind(l),t.then(l,l)),a.state.loading|=4,a.instance=n,Nl(n);return}n=t.ownerDocument||t,u=vo(u),(e=Ot.get(e))&&fc(u,e),n=n.createElement("link"),Nl(n);var f=n;f._p=new Promise(function(i,c){f.onload=i,f.onerror=c}),Ql(n,"link",u),a.instance=n}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(a,t),(t=a.state.preload)&&(a.state.loading&3)===0&&(l.count++,a=Nn.bind(l),t.addEventListener("load",a),t.addEventListener("error",a))}}var cc=0;function em(l,t){return l.stylesheets&&l.count===0&&Cn(l,l.stylesheets),0<l.count||0<l.imgCount?function(a){var u=setTimeout(function(){if(l.stylesheets&&Cn(l,l.stylesheets),l.unsuspend){var n=l.unsuspend;l.unsuspend=null,n()}},6e4+t);0<l.imgBytes&&cc===0&&(cc=62500*Yv());var e=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&Cn(l,l.stylesheets),l.unsuspend)){var n=l.unsuspend;l.unsuspend=null,n()}},(l.imgBytes>cc?50:800)+t);return l.unsuspend=a,function(){l.unsuspend=null,clearTimeout(u),clearTimeout(e)}}:null}function Nn(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Cn(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Bn=null;function Cn(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Bn=new Map,t.forEach(nm,l),Bn=null,Nn.call(l))}function nm(l,t){if(!(t.state.loading&4)){var a=Bn.get(l);if(a)var u=a.get(null);else{a=new Map,Bn.set(l,a);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var f=e[n];(f.nodeName==="LINK"||f.getAttribute("media")!=="not all")&&(a.set(f.dataset.precedence,f),u=f)}u&&a.set(null,u)}e=t.instance,f=e.getAttribute("data-precedence"),n=a.get(f)||u,n===u&&a.set(null,e),a.set(f,e),this.count++,u=Nn.bind(this),e.addEventListener("load",u),e.addEventListener("error",u),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var ze={$$typeof:vl,Provider:null,Consumer:null,_currentValue:H,_currentValue2:H,_threadCount:0};function fm(l,t,a,u,e,n,f,i,c){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=af(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=af(0),this.hiddenUpdates=af(null),this.identifierPrefix=u,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=f,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=c,this.incompleteTransitions=new Map}function ro(l,t,a,u,e,n,f,i,c,v,r,z){return l=new fm(l,t,a,f,c,v,r,z,i),t=1,n===!0&&(t|=24),n=dt(3,null,null,t),l.current=n,n.stateNode=l,t=Qf(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:u,isDehydrated:a,cache:t},Kf(n),l}function bo(l){return l?(l=eu,l):eu}function zo(l,t,a,u,e,n){e=bo(e),u.context===null?u.context=e:u.pendingContext=e,u=ca(t),u.payload={element:a},n=n===void 0?null:n,n!==null&&(u.callback=n),a=sa(l,u,t),a!==null&&(ut(a,l,t),Iu(a,l,t))}function To(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var a=l.retryLane;l.retryLane=a!==0&&a<t?a:t}}function sc(l,t){To(l,t),(l=l.alternate)&&To(l,t)}function Eo(l){if(l.tag===13||l.tag===31){var t=Ha(l,67108864);t!==null&&ut(t,l,67108864),sc(l,67108864)}}function Ao(l){if(l.tag===13||l.tag===31){var t=ht();t=uf(t);var a=Ha(l,t);a!==null&&ut(a,l,t),sc(l,t)}}var jn=!0;function im(l,t,a,u){var e=S.T;S.T=null;var n=p.p;try{p.p=2,dc(l,t,a,u)}finally{p.p=n,S.T=e}}function cm(l,t,a,u){var e=S.T;S.T=null;var n=p.p;try{p.p=8,dc(l,t,a,u)}finally{p.p=n,S.T=e}}function dc(l,t,a,u){if(jn){var e=oc(u);if(e===null)ki(l,t,u,qn,a),_o(l,u);else if(dm(e,l,t,a,u))u.stopPropagation();else if(_o(l,u),t&4&&-1<sm.indexOf(l)){for(;e!==null;){var n=wa(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var f=Oa(n.pendingLanes);if(f!==0){var i=n;for(i.pendingLanes|=2,i.entangledLanes|=2;f;){var c=1<<31-ct(f);i.entanglements[1]|=c,f&=~c}Bt(n),(ll&6)===0&&(bn=ft()+500,me(0))}}break;case 31:case 13:i=Ha(n,2),i!==null&&ut(i,n,2),Tn(),sc(n,2)}if(n=oc(u),n===null&&ki(l,t,u,qn,a),n===e)break;e=n}e!==null&&u.stopPropagation()}else ki(l,t,u,null,a)}}function oc(l){return l=vf(l),yc(l)}var qn=null;function yc(l){if(qn=null,l=Ja(l),l!==null){var t=Tl(l);if(t===null)l=null;else{var a=t.tag;if(a===13){if(l=rl(t),l!==null)return l;l=null}else if(a===31){if(l=Hl(t),l!==null)return l;l=null}else if(a===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return qn=l,null}function po(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Wo()){case Hc:return 2;case Rc:return 8;case _e:case $o:return 32;case Nc:return 268435456;default:return 32}default:return 32}}var vc=!1,za=null,Ta=null,Ea=null,Te=new Map,Ee=new Map,Aa=[],sm="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function _o(l,t){switch(l){case"focusin":case"focusout":za=null;break;case"dragenter":case"dragleave":Ta=null;break;case"mouseover":case"mouseout":Ea=null;break;case"pointerover":case"pointerout":Te.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Ee.delete(t.pointerId)}}function Ae(l,t,a,u,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:a,eventSystemFlags:u,nativeEvent:n,targetContainers:[e]},t!==null&&(t=wa(t),t!==null&&Eo(t)),l):(l.eventSystemFlags|=u,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function dm(l,t,a,u,e){switch(t){case"focusin":return za=Ae(za,l,t,a,u,e),!0;case"dragenter":return Ta=Ae(Ta,l,t,a,u,e),!0;case"mouseover":return Ea=Ae(Ea,l,t,a,u,e),!0;case"pointerover":var n=e.pointerId;return Te.set(n,Ae(Te.get(n)||null,l,t,a,u,e)),!0;case"gotpointercapture":return n=e.pointerId,Ee.set(n,Ae(Ee.get(n)||null,l,t,a,u,e)),!0}return!1}function Oo(l){var t=Ja(l.target);if(t!==null){var a=Tl(t);if(a!==null){if(t=a.tag,t===13){if(t=rl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){Ao(a)});return}}else if(t===31){if(t=Hl(a),t!==null){l.blockedOn=t,Gc(l.priority,function(){Ao(a)});return}}else if(t===3&&a.stateNode.current.memoizedState.isDehydrated){l.blockedOn=a.tag===3?a.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Yn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var a=oc(l.nativeEvent);if(a===null){a=l.nativeEvent;var u=new a.constructor(a.type,a);yf=u,a.target.dispatchEvent(u),yf=null}else return t=wa(a),t!==null&&Eo(t),l.blockedOn=a,!1;t.shift()}return!0}function Mo(l,t,a){Yn(l)&&a.delete(t)}function om(){vc=!1,za!==null&&Yn(za)&&(za=null),Ta!==null&&Yn(Ta)&&(Ta=null),Ea!==null&&Yn(Ea)&&(Ea=null),Te.forEach(Mo),Ee.forEach(Mo)}function Gn(l,t){l.blockedOn===t&&(l.blockedOn=null,vc||(vc=!0,A.unstable_scheduleCallback(A.unstable_NormalPriority,om)))}var Xn=null;function Do(l){Xn!==l&&(Xn=l,A.unstable_scheduleCallback(A.unstable_NormalPriority,function(){Xn===l&&(Xn=null);for(var t=0;t<l.length;t+=3){var a=l[t],u=l[t+1],e=l[t+2];if(typeof u!="function"){if(yc(u||a)===null)continue;break}var n=wa(a);n!==null&&(l.splice(t,3),t-=3,oi(n,{pending:!0,data:e,method:a.method,action:u},u,e))}}))}function Du(l){function t(c){return Gn(c,l)}za!==null&&Gn(za,l),Ta!==null&&Gn(Ta,l),Ea!==null&&Gn(Ea,l),Te.forEach(t),Ee.forEach(t);for(var a=0;a<Aa.length;a++){var u=Aa[a];u.blockedOn===l&&(u.blockedOn=null)}for(;0<Aa.length&&(a=Aa[0],a.blockedOn===null);)Oo(a),a.blockedOn===null&&Aa.shift();if(a=(l.ownerDocument||l).$$reactFormReplay,a!=null)for(u=0;u<a.length;u+=3){var e=a[u],n=a[u+1],f=e[Fl]||null;if(typeof n=="function")f||Do(a);else if(f){var i=null;if(n&&n.hasAttribute("formAction")){if(e=n,f=n[Fl]||null)i=f.formAction;else if(yc(e)!==null)continue}else i=f.action;typeof i=="function"?a[u+1]=i:(a.splice(u,3),u-=3),Do(a)}}}function Uo(){function l(n){n.canIntercept&&n.info==="react-transition"&&n.intercept({handler:function(){return new Promise(function(f){return e=f})},focusReset:"manual",scroll:"manual"})}function t(){e!==null&&(e(),e=null),u||setTimeout(a,20)}function a(){if(!u&&!navigation.transition){var n=navigation.currentEntry;n&&n.url!=null&&navigation.navigate(n.url,{state:n.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var u=!1,e=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(a,100),function(){u=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),e!==null&&(e(),e=null)}}}function mc(l){this._internalRoot=l}Qn.prototype.render=mc.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(h(409));var a=t.current,u=ht();zo(a,u,l,t,null,null)},Qn.prototype.unmount=mc.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;zo(l.current,2,null,l,null,null),Tn(),t[Ka]=null}};function Qn(l){this._internalRoot=l}Qn.prototype.unstable_scheduleHydration=function(l){if(l){var t=Yc();l={blockedOn:null,target:l,priority:t};for(var a=0;a<Aa.length&&t!==0&&t<Aa[a].priority;a++);Aa.splice(a,0,l),a===0&&Oo(l)}};var xo=Sl.version;if(xo!=="19.2.4")throw Error(h(527,xo,"19.2.4"));p.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(h(188)):(l=Object.keys(l).join(","),Error(h(268,l)));return l=E(t),l=l!==null?F(l):null,l=l===null?null:l.stateNode,l};var ym={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:S,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Zn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Zn.isDisabled&&Zn.supportsFiber)try{Ru=Zn.inject(ym),it=Zn}catch{}}return xu.createRoot=function(l,t){if(!tl(l))throw Error(h(299));var a=!1,u="",e=jd,n=qd,f=Yd;return t!=null&&(t.unstable_strictMode===!0&&(a=!0),t.identifierPrefix!==void 0&&(u=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(f=t.onRecoverableError)),t=ro(l,1,!1,null,null,a,u,null,e,n,f,Uo),l[Ka]=t.current,$i(l),new mc(t)},xu.hydrateRoot=function(l,t,a){if(!tl(l))throw Error(h(299));var u=!1,e="",n=jd,f=qd,i=Yd,c=null;return a!=null&&(a.unstable_strictMode===!0&&(u=!0),a.identifierPrefix!==void 0&&(e=a.identifierPrefix),a.onUncaughtError!==void 0&&(n=a.onUncaughtError),a.onCaughtError!==void 0&&(f=a.onCaughtError),a.onRecoverableError!==void 0&&(i=a.onRecoverableError),a.formState!==void 0&&(c=a.formState)),t=ro(l,1,!0,t,a??null,u,e,c,n,f,i,Uo),t.context=bo(null),a=t.current,u=ht(),u=uf(u),e=ca(u),e.callback=null,sa(a,e,u),a=u,t.current.lanes=a,Bu(t,a),Bt(t),l[Ka]=t.current,$i(l),new Qn(t)},xu.version="19.2.4",xu}var pc;function Go(){if(pc)return Ln.exports;pc=1;function A(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(A)}catch(Sl){console.error(Sl)}}return A(),Ln.exports=Yo(),Ln.exports}var Xo=Go(),Vl=Wn();const Qo=[{value:"",label:"⚡ auto (recommended)"},{value:"sonnet",label:"🌟 sonnet"},{value:"haiku",label:"🐦 haiku (fast)"},{value:"opus",label:"🏔️ opus (best)"},{value:"gemini3flash",label:"✨ gemini3flash (fast)"},{value:"gemini3pro",label:"✨ gemini3pro"},{value:"gemini2.5flash",label:"✨ gemini2.5flash"},{value:"gpt4.1",label:"🤖 gpt4.1"},{value:"gpt4.1mini",label:"🤖 gpt4.1mini"},{value:"grok4",label:"𝕏 grok4"},{value:"grok3",label:"𝕏 grok3"}];function Zo(){return localStorage.getItem("salmalm_token")||localStorage.getItem("auth_token")||sessionStorage.getItem("salmalm_token")||""}function La(){const A=Zo();return A?{"Content-Type":"application/json",Authorization:`Bearer ${A}`}:{"Content-Type":"application/json"}}function _c(A){return A<60?`${A}s`:`${Math.floor(A/60)}m ${Math.round(A%60)}s`}function Oc(A){return{running:"🟡",completed:"🟢",failed:"🔴",killed:"⚫",pending:"⚪"}[A]??"⚪"}const q={bg:"var(--bg)",bg2:"var(--bg2)",bg3:"var(--bg3, #1a1a2e)",border:"var(--border)",accent:"var(--accent)",text:"var(--text)",text2:"var(--text2)",red:"#f44336",yellow:"#ffc107"},G={root:{display:"flex",flex:1,minHeight:0,fontFamily:"'Inter','Segoe UI',system-ui,sans-serif",fontSize:14,color:q.text,background:q.bg,overflow:"hidden",borderRadius:8,border:`1px solid ${q.border}`},left:{width:320,minWidth:260,maxWidth:320,display:"flex",flexDirection:"column",borderRight:`1px solid ${q.border}`,background:q.bg,overflow:"hidden"},header:{display:"flex",alignItems:"center",justifyContent:"space-between",padding:"12px 14px",borderBottom:`1px solid ${q.border}`},title:{margin:0,fontSize:15,fontWeight:700},spawnForm:{padding:"12px 14px",borderBottom:`1px solid ${q.border}`,background:q.bg2,display:"flex",flexDirection:"column",gap:8},textarea:{width:"100%",background:q.bg,border:`1px solid ${q.border}`,borderRadius:6,color:q.text,padding:"7px 10px",fontSize:13,resize:"vertical",minHeight:64,boxSizing:"border-box",outline:"none"},row:{display:"flex",gap:8},input:{flex:1,background:q.bg,border:`1px solid ${q.border}`,borderRadius:6,color:q.text,padding:"5px 9px",fontSize:12,outline:"none"},btn:{background:q.accent,border:"none",color:"#fff",borderRadius:6,padding:"6px 14px",fontSize:13,fontWeight:600,cursor:"pointer"},btnSm:{background:"transparent",border:`1px solid ${q.border}`,color:q.text2,borderRadius:6,padding:"4px 10px",fontSize:12,cursor:"pointer"},taskList:{flex:1,overflowY:"auto",padding:"8px 0"},taskCard:{padding:"10px 14px",cursor:"pointer",borderBottom:`1px solid ${q.border}`,transition:"background .12s"},taskCardActive:{background:q.bg2},taskTop:{display:"flex",alignItems:"center",gap:6,marginBottom:3},taskLabel:{fontWeight:600,fontSize:13,flex:1,overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},taskMeta:{fontSize:11,color:q.text2},steerBar:{display:"flex",gap:6,marginTop:7},steerInput:{flex:1,background:q.bg,border:`1px solid ${q.border}`,borderRadius:6,color:q.text,padding:"4px 8px",fontSize:12,outline:"none"},steerBtn:{background:q.accent,border:"none",color:"#fff",borderRadius:6,padding:"4px 10px",fontSize:12,cursor:"pointer"},right:{flex:1,display:"flex",flexDirection:"column",overflow:"hidden"},rightHeader:{padding:"12px 16px",borderBottom:`1px solid ${q.border}`,display:"flex",alignItems:"center",gap:10},rightTitle:{margin:0,fontSize:14,fontWeight:600,flex:1},historyPane:{flex:1,overflowY:"auto",padding:"12px 16px",display:"flex",flexDirection:"column",gap:10},msgBubble:{borderRadius:8,padding:"8px 12px",fontSize:13,lineHeight:1.5,maxWidth:"90%",wordBreak:"break-word",whiteSpace:"pre-wrap"},msgUser:{background:q.accent,color:"#fff",alignSelf:"flex-end"},msgAssistant:{background:q.bg2,alignSelf:"flex-start"},msgTool:{background:q.bg3,color:q.text2,alignSelf:"flex-start",fontFamily:"monospace",fontSize:12},resultBox:{padding:"12px",background:q.bg2,borderRadius:8,border:`1px solid ${q.border}`,fontSize:13,lineHeight:1.6,whiteSpace:"pre-wrap",wordBreak:"break-word"},emptyRight:{flex:1,display:"flex",alignItems:"center",justifyContent:"center",color:q.text2,fontSize:13},toast:{position:"fixed",bottom:20,right:20,background:q.accent,color:"#fff",padding:"10px 18px",borderRadius:8,fontSize:13,fontWeight:600,zIndex:9999,boxShadow:"0 4px 12px rgba(0,0,0,.3)"}};function Vo(){var xt;const[A,Sl]=Vl.useState([]),[B,h]=Vl.useState(null),[tl,Tl]=Vl.useState(null),[rl,Hl]=Vl.useState(""),[R,E]=Vl.useState(""),[F,C]=Vl.useState(""),[il,Ll]=Vl.useState(!1),[Cl,Rl]=Vl.useState({}),[gt,Kl]=Vl.useState(""),et=Vl.useRef(null),vl=Vl.useCallback(async()=>{try{const O=await fetch("/api/subagents",{headers:La()});if(!O.ok)return;const $=await O.json();Sl($.tasks||[])}catch{}},[]),El=Vl.useCallback(async O=>{try{const $=await fetch(`/api/subagents/${O}`,{headers:La()});if(!$.ok)return;const S=await $.json();Tl(S.task||null)}catch{}},[]);Vl.useEffect(()=>{vl();const O=setInterval(()=>{vl(),B&&B.status==="running"&&El(B.task_id)},2500);return()=>clearInterval(O)},[vl,El,B]),Vl.useEffect(()=>{B&&El(B.task_id)},[B,El]),Vl.useEffect(()=>{et.current&&(et.current.scrollTop=et.current.scrollHeight)},[(xt=tl==null?void 0:tl.messages)==null?void 0:xt.length]),Vl.useEffect(()=>{const O=S=>{try{const p=typeof S.data=="string"?JSON.parse(S.data):S.data;if(p.type==="subagent_done"){vl();const H=p.task;kl(`${H.status==="completed"?"✅":"❌"} Sub-agent "${H.label}" ${H.status}`),(B==null?void 0:B.task_id)===H.task_id&&El(H.task_id)}}catch{}},$=window._ws;return $&&$.addEventListener("message",O),()=>{$&&$.removeEventListener("message",O)}},[vl,El,B]);const nt=async()=>{if(rl.trim()){Ll(!0);try{const $=await(await fetch("/api/subagents",{method:"POST",headers:La(),body:JSON.stringify({description:rl.trim(),label:R.trim()||void 0,model:F.trim()||void 0})})).json();$.task&&(Hl(""),E(""),C(""),await vl(),h($.task))}finally{Ll(!1)}}},Jl=async(O,$)=>{$.stopPropagation(),await fetch(`/api/subagents/${O}/kill`,{method:"POST",headers:La(),body:"{}"}),vl()},V=async O=>{var H;const $=(Cl[O]||"").trim();if(!$)return;const p=await(await fetch(`/api/subagents/${O}/steer`,{method:"POST",headers:La(),body:JSON.stringify({message:$})})).json();kl(((H=p.result)==null?void 0:H.slice(0,80))||"📡 Steered"),Rl(ul=>({...ul,[O]:""})),(B==null?void 0:B.task_id)===O&&setTimeout(()=>El(O),1e3)},wl=async()=>{const $=await(await fetch("/api/subagents/clear",{method:"POST",headers:La(),body:"{}"})).json();kl(`🗑️ Removed ${$.removed} completed tasks`),B&&["completed","failed","killed"].includes(B.status)&&h(null),vl()},kl=O=>{Kl(O),setTimeout(()=>Kl(""),3500)},Pt=O=>{h(O),El(O.task_id)},al=tl&&B&&tl.task_id===B.task_id?tl:B,jl=A.filter(O=>O.status==="running").length;return x.jsxs("div",{style:G.root,children:[x.jsxs("div",{style:G.left,children:[x.jsxs("div",{style:G.header,children:[x.jsxs("h3",{style:G.title,children:["🤖 Sub-agents ",jl>0&&x.jsx("span",{style:{fontSize:12,background:q.yellow,color:"#000",borderRadius:10,padding:"1px 7px",marginLeft:6},children:jl})]}),x.jsxs("div",{style:{display:"flex",gap:6},children:[x.jsx("button",{style:G.btnSm,onClick:wl,children:"🗑️"}),x.jsx("button",{style:G.btnSm,onClick:vl,children:"↻"})]})]}),x.jsxs("div",{style:G.spawnForm,children:[x.jsx("textarea",{style:G.textarea,placeholder:"Task description…",value:rl,onChange:O=>Hl(O.target.value),onKeyDown:O=>{O.key==="Enter"&&O.metaKey&&nt()}}),x.jsxs("div",{style:G.row,children:[x.jsx("input",{style:G.input,placeholder:"Label (optional)",value:R,onChange:O=>E(O.target.value)}),x.jsx("select",{style:{...G.input,maxWidth:160,cursor:"pointer"},value:F,onChange:O=>C(O.target.value),children:Qo.map(O=>x.jsx("option",{value:O.value,children:O.label},O.value))})]}),x.jsx("button",{style:{...G.btn,opacity:il?.6:1},onClick:nt,disabled:il||!rl.trim(),children:il?"⏳ Spawning…":"⚡ Spawn"})]}),x.jsxs("div",{style:G.taskList,children:[A.length===0&&x.jsx("div",{style:{padding:"20px",textAlign:"center",color:q.text2,fontSize:13},children:"No tasks yet"}),A.map(O=>{const $=(B==null?void 0:B.task_id)===O.task_id;return x.jsxs("div",{style:{...G.taskCard,...$?G.taskCardActive:{}},onClick:()=>Pt(O),children:[x.jsxs("div",{style:G.taskTop,children:[x.jsx("span",{children:Oc(O.status)}),x.jsx("span",{style:G.taskLabel,children:O.label}),O.status==="running"&&x.jsx("button",{style:{...G.btnSm,padding:"2px 7px",fontSize:11,color:q.red},onClick:S=>Jl(O.task_id,S),children:"✕"})]}),x.jsxs("div",{style:G.taskMeta,children:[O.task_id," · ",_c(O.elapsed_s),O.turns_used>0&&` · ${O.turns_used} turns`,O.model&&` · ${O.model.split("/").pop()}`]}),O.status==="running"&&x.jsxs("div",{style:G.steerBar,onClick:S=>S.stopPropagation(),children:[x.jsx("input",{style:G.steerInput,placeholder:"Steer message…",value:Cl[O.task_id]||"",onChange:S=>Rl(p=>({...p,[O.task_id]:S.target.value})),onKeyDown:S=>{S.key==="Enter"&&V(O.task_id)}}),x.jsx("button",{style:G.steerBtn,onClick:()=>V(O.task_id),children:"📡"})]})]},O.task_id)})]})]}),x.jsx("div",{style:G.right,children:al?x.jsxs(x.Fragment,{children:[x.jsxs("div",{style:G.rightHeader,children:[x.jsx("span",{children:Oc(al.status)}),x.jsx("h4",{style:G.rightTitle,children:al.label}),x.jsxs("span",{style:{fontSize:12,color:q.text2},children:[_c(al.elapsed_s)," · ",al.turns_used," turns"]}),al.model&&x.jsx("span",{style:{fontSize:11,color:q.text2,background:q.bg2,padding:"2px 7px",borderRadius:10},children:al.model.split("/").pop()})]}),x.jsxs("div",{style:G.historyPane,ref:et,children:[al.messages&&al.messages.length>0?al.messages.map((O,$)=>x.jsx(Lo,{msg:O},$)):x.jsxs(x.Fragment,{children:[x.jsx("div",{style:{...G.msgBubble,...G.msgUser},children:al.description}),al.status==="running"&&x.jsxs("div",{style:{...G.msgBubble,...G.msgAssistant,color:q.text2},children:[x.jsx(Mc,{})," Working…"]})]}),al.status==="running"&&x.jsxs("div",{style:{...G.msgBubble,...G.msgAssistant,color:q.text2},children:[x.jsx(Mc,{})," Thinking…"]}),al.status==="completed"&&al.result&&x.jsxs("div",{style:G.resultBox,children:[x.jsx("div",{style:{fontSize:11,color:q.text2,marginBottom:6,fontWeight:600},children:"✅ RESULT"}),al.result]}),al.status==="failed"&&al.error&&x.jsxs("div",{style:{...G.resultBox,borderColor:q.red,color:q.red},children:[x.jsx("div",{style:{fontSize:11,marginBottom:6,fontWeight:600},children:"❌ ERROR"}),al.error]})]})]}):x.jsx("div",{style:G.emptyRight,children:"Select a task to view history"})}),gt&&x.jsx("div",{style:G.toast,children:gt})]})}function Lo({msg:A}){var Sl,B;return A.role==="user"?x.jsx("div",{style:{...G.msgBubble,...G.msgUser},children:A.content}):A.role==="tool"?x.jsxs("div",{style:{...G.msgBubble,...G.msgTool},children:["🔧 ",A.name||"tool",": ",(Sl=A.content)==null?void 0:Sl.slice(0,300),(((B=A.content)==null?void 0:B.length)??0)>300?"…":""]}):A.tool_calls&&A.tool_calls.length>0?x.jsxs("div",{style:{...G.msgBubble,...G.msgAssistant},children:[A.content&&x.jsx("div",{style:{marginBottom:6},children:A.content}),A.tool_calls.map((h,tl)=>x.jsxs("div",{style:{fontSize:12,color:q.text2,fontFamily:"monospace"},children:["⚡ ",h.name,"(",typeof h.arguments=="object"?JSON.stringify(h.arguments).slice(0,80):String(h.arguments).slice(0,80),")"]},tl))]}):x.jsx("div",{style:{...G.msgBubble,...G.msgAssistant},children:A.content})}function Mc(){return x.jsx("span",{style:{display:"inline-block",animation:"spin 1s linear infinite",marginRight:6},children:"⏳"})}const Dc=()=>{const A=document.getElementById("agent-panel-root");A&&Xo.createRoot(A).render(x.jsx(Vo,{}))};document.readyState==="loading"?document.addEventListener("DOMContentLoaded",Dc):Dc()})();
